@@ -1,5 +1,7 @@
 /*
 
+ $Id: arch.cpp,v 1.22 2000/05/30 21:09:46 ezust Exp $
+
  ark -- archiver for the KDE project
 
  Copyright (C)
@@ -27,7 +29,6 @@
 #include <kdebug.h>
 #include <kmessagebox.h>
 #include <klocale.h>
-
 #include <time.h>
 
 #define ABS(x) (x) < 0? -(x) : (x)
@@ -150,13 +151,13 @@ void Arch::slotExtractExited(KProcess *_kp)
     {
       if(stderrIsError())
 	{
-	  KMessageBox::error( (QWidget *) 0, i18n("Error"), i18n("Something bad happened when trying to extract...") );
+	  int ret = KMessageBox::warningYesNo( (QWidget *) 0, i18n("Sorry, the extract operation failed.\nDo you wish to view the shell output?"), i18n("Error"));
+	  if (ret == KMessageBox::Yes)
+	    m_gui->viewShellOutput();
 	}
       else
 	bSuccess = true;
     }
-  else
-    KMessageBox::sorry((QWidget *)0, i18n("Extraction failed"), i18n("Error"));
 
   emit sigExtract(bSuccess);
   delete _kp;
@@ -187,8 +188,11 @@ void Arch::slotAddExited(KProcess *_kp)
 	bSuccess = true;
     }
   else
-    KMessageBox::sorry((QWidget *)0, i18n("Sorry, the add operation failed.\nPlease see the last shell output for more information"), i18n("Error"));
-  
+    {
+      int ret = KMessageBox::warningYesNo( (QWidget *) 0, i18n("Sorry, the add operation failed.\nDo you wish to view the shell output?"), i18n("Error"));
+	  if (ret == KMessageBox::Yes)
+	    m_gui->viewShellOutput();
+    }  
   emit sigAdd(bSuccess);
   delete _kp;
   _kp = NULL;
