@@ -1,5 +1,7 @@
 /*
 
+ $Id: arkapp.cpp,v 1.13 2000/06/01 19:31:21 ezust Exp $
+
  ark -- archiver for the KDE project
 
  Copyright (C)
@@ -121,7 +123,8 @@ int ArkApplication::newInstance()
      {
         Zip = QFile::decodeName(arg);
      }
-     else
+     else if (QString(arg).left(7) != "http://" &&
+	      QString(arg).left(6) != "ftp://")
      {
         Zip = KCmdLineArgs::cwd() + "/" + QFile::decodeName(arg);
      }
