@@ -1,6 +1,6 @@
 /*
 
- $Id: arksettings.cpp,v 1.19 2000/05/04 21:20:46 ezust Exp $
+ $Id: arksettings.cpp,v 1.22 2000/06/01 19:31:21 ezust Exp $
 
  ark -- archiver for the KDE project
 
@@ -254,7 +254,7 @@ void ArkSettings::readZipProperties()
   m_zipExtractJunkPaths = kc->readBoolEntry( EXTRACT_JUNKPATHS, false );
   m_zipExtractOverwrite = kc->readBoolEntry( EXTRACT_LOWERCASE, false );
 
-  m_zipAddRecurseDirs = kc->readBoolEntry( ADD_RECURSEDIRS, false );
+  m_zipAddRecurseDirs = kc->readBoolEntry( ADD_RECURSEDIRS, true );
   m_zipAddJunkDirs = kc->readBoolEntry( ADD_JUNKDIRS, false );
   m_zipAddMSDOS = kc->readBoolEntry( ADD_MSDOS, false );
   m_zipAddConvertLF = kc->readBoolEntry( ADD_CONVERTLF, false );
@@ -523,7 +523,8 @@ const QString ArkSettings::getFilter()
 {
   return i18n(
 	      "*.zip *.tar.gz *.tar.Z *.tar.lzo *.tgz *.taz *.tzo *.tar.bz2 *.tar.bz *.tar *.lzh *.gz *.lzo *.Z *.bz *.bz2 *.zoo *.rar *.a|All valid archives\n"
-	      " *.tar.gz *.tar.Z *.tgz *.taz *.tzo *.tar.bz2 *.tar.bz *.tar.lzo *.tar |Compressed or Plain Tar archives\n"
+	      " *.tar.gz *.tar.Z *.tgz *.taz *.tzo *.tar.bz2 *.tar.bz *.tar.lzo *.tar |Tar archives (*.tar, *.tar.gz, *.tar.Z, *.tar.bz2, etc.)\n"
+	      "*.gz *.bz *.bz2 *.lzo *.Z|Compressed Files (*.gz *.bz *.bz2 *.lzo *.Z)\n"
 	      "*.zip|Zip archives (*.zip)\n"
 	      "*.lzh|Lha archives (*.lzh)\n"
 	      "*.zoo|Zoo archives (*.zoo)\n"
