@@ -1,6 +1,6 @@
 /*
 
- $Id: arkwidget.cc,v 1.77 2000/05/04 21:20:46 ezust Exp $
+ $Id: arkwidget.cc,v 1.84 2000/06/02 19:37:34 ezust Exp $
 
  ark -- archiver for the KDE project
 
@@ -34,7 +34,7 @@
 #include <qmessagebox.h>
 #include <qregexp.h>
 #include <qheader.h>
-
+#include <qwhatsthis.h>
 // KDE includes
 #include <kapp.h>
 #include <kconfig.h>
@@ -65,7 +65,6 @@
 #include "arkapp.h"
 
 #include "dirDlg.h"
-#include "generalOptDlg.h"
 #include "selectDlg.h"
 #include "shellOutputDlg.h"
 
@@ -174,21 +173,21 @@ void ArkWidget::setupActions()
 
   (void)KStdAction::keyBindings();
 
-  shellOutputAction  = new KAction(i18n("&View shell output..."), 0, this,
+  shellOutputAction  = new KAction(i18n("&View shell output"), 0, this,
 				   SLOT(edit_view_last_shell_output()),
 				   actionCollection(), "shell_output");
 
   KStdAction::quit(this, SLOT(window_close()), actionCollection());
 
-  addFileAction = new KAction(i18n("&Add File"), "ark_addfile", 0, this,
+  addFileAction = new KAction(i18n("&Add File..."), "ark_addfile", 0, this,
 				SLOT(action_add()),
 				actionCollection(), "addfile");
 
-  addDirAction = new KAction(i18n("Add Di&r"), "ark_adddir", 0, this,
+  addDirAction = new KAction(i18n("Add Di&r..."), "ark_adddir", 0, this,
 				SLOT(action_add_dir()),
 				actionCollection(), "adddir");
 
-  extractAction = new KAction(i18n("&Extract"), "ark_extract", 0, this,
+  extractAction = new KAction(i18n("&Extract..."), "ark_extract", 0, this,
 				SLOT(action_extract()),
 				actionCollection(), "extract");
 
@@ -196,7 +195,7 @@ void ArkWidget::setupActions()
 			     SLOT(action_delete()),
 			     actionCollection(), "delete");
 
-  selectAllAction = new KAction(i18n("Select All"), "ark_selectall", 0, this,
+  selectAllAction = new KAction(i18n("Select &All"), "ark_selectall", 0, this,
 			     SLOT(edit_selectAll()),
 			     actionCollection(), "select_all");
 
@@ -217,7 +216,7 @@ void ArkWidget::setupActions()
 			   actionCollection(), "popup_menu_open_with");
 
 
-  editAction = new KAction(i18n("&Edit with..."), 0, this,
+  editAction = new KAction(i18n("Edit &with..."), 0, this,
 			   SLOT(action_edit()),
 			   actionCollection(), "edit");
 
@@ -229,23 +228,18 @@ void ArkWidget::setupActions()
 			   SLOT(options_dirs()),
 			   actionCollection(), "settings");
  
-  selectAction =  new KAction(i18n("Select..."), 0, this,
+  selectAction =  new KAction(i18n("&Select..."), 0, this,
 			     SLOT(edit_select()),
 			     actionCollection(), "select");
-  deselectAllAction =  new KAction(i18n("Deselect All"), 0, this,
+  deselectAllAction =  new KAction(i18n("&Deselect All"), 0, this,
 			     SLOT(edit_deselectAll()),
 			     actionCollection(), "deselect_all");
 
-  invertSelectionAction  =  new KAction(i18n("Invert Selection"), 0, this,
+  invertSelectionAction  =  new KAction(i18n("&Invert Selection"), 0, this,
 					SLOT(edit_invertSel()),
 					actionCollection(),
 					"invert_selection");
 
-  (void)new KAction(i18n("&General..."), 0, this,
-		    SLOT(options_general()),
-		    actionCollection(),
-		    "general");
-
   (void)new KAction(i18n("&Directories..."), 0, this,
 		    SLOT(options_dirs()),
 		    actionCollection(),
@@ -257,6 +251,7 @@ void ArkWidget::setupActions()
   KStdAction::saveOptions(this, SLOT(options_saveNow()), actionCollection());
   KStdAction::keyBindings(this, SLOT(options_keys()), actionCollection());
 
+
   createGUI();
 }
 
@@ -288,6 +283,7 @@ void ArkWidget::toggleToolBar()
    toolBar()->hide();
  else
    toolBar()->show();
+
 }
 
 void ArkWidget::toggleStatusBar()
@@ -304,6 +300,8 @@ void ArkWidget::setupStatusBar()
 
   KStatusBar *sb = statusBar();
 
+  QWhatsThis::add(sb, i18n("The statusbar shows you how many files you have and how many you have selected. It also shows you total sizes for these groups of files."));
+
   m_pStatusLabelSelect = new QLabel(sb);
   m_pStatusLabelSelect->setFrameStyle(QFrame::Panel | QFrame::Sunken);
   m_pStatusLabelSelect->setFixedHeight(30);
@@ -383,12 +381,9 @@ void ArkWidget::updateStatusTotals()
   if (m_nNumFiles == 0)
     strInfo = i18n("Total: 0 Files");
   else if (m_nNumFiles == 1)
-    strInfo = i18n("Total: 1 File %1 KB")
-      .arg(KGlobal::locale()->formatNumber(m_nSizeOfFiles, 0));
+    strInfo = i18n("Total: 1 File %1 KB").arg(KGlobal::locale()->formatNumber(m_nSizeOfFiles, 0));
   else
-    strInfo = i18n("Total: %1 Files %1 KB")
-      .arg(KGlobal::locale()->formatNumber(m_nNumFiles, 0))
-      .arg(KGlobal::locale()->formatNumber(m_nSizeOfFiles, 0));
+    strInfo = i18n("Total: %1 Files %1 KB").arg(KGlobal::locale()->formatNumber(m_nNumFiles, 0)).arg(KGlobal::locale()->formatNumber(m_nSizeOfFiles, 0));
   
   m_pStatusLabelTotal->setText(strInfo);
 }
@@ -400,22 +395,23 @@ void ArkWidget::updateStatusTotals()
 
 void ArkWidget::file_open(const QString & strFile)
 {
+  //strFile has no protocol by now - it's a path.
   struct stat statbuffer;
   
-  if (stat(strFile, &statbuffer) == -1)
+  if (stat(strFile.local8Bit(), &statbuffer) == -1)
     {
       if (errno == ENOENT || errno == ENOTDIR || errno ==  EFAULT)
 	{
-	  QString x = "file:";
-	  QString errormesg = i18n("The archive ") + strFile +
-	    i18n(" does not exist");
-	  KMessageBox::error(this, errormesg);
+	  KMessageBox::error(this, i18n("The archive %1 does not exist.").arg(strFile.local8Bit()));
+	  recent->removeURL(strFile);
 	}
       else if (errno == EACCES)
 	{
-	  QString errormesg = i18n("Can't access the archive ") + strFile;
-	  KMessageBox::error(this, errormesg);
+	  KMessageBox::error(this, i18n("Can't access the archive %1").arg(strFile.local8Bit()));
+	  recent->removeURL(strFile);
 	}
+      else
+	KMessageBox::error(this, i18n("Unknown error."));
       return;
     }
   else
@@ -507,7 +503,8 @@ void ArkWidget::saveProperties()
 QString ArkWidget::getNewFileName()
 {
   KURL url = KFileDialog::getSaveURL(QString::null,
-				     m_settings->getFilter());
+				     m_settings->getFilter(),
+				     0, i18n("Create a New Archive"));
   QString strFile;
 
   if (!url.isEmpty())
@@ -562,13 +559,16 @@ QString ArkWidget::getCreateFilename()
   
   if (!strFile.isEmpty())
     {
+      kdDebug(1601) << "Trying to create an archive named " <<
+	strFile.local8Bit() << endl;
+
       while (true)
 	// keep asking for filenames as long as the user doesn't want to 
 	// overwrite existing ones; break if they agree to overwrite
 	// or if the file doesn't already exist. Return if they cancel.
 	// Also check for proper extensions.
 	{
-	  if (stat(strFile, &statbuffer) != -1)  // already exists!
+	  if (stat(strFile.local8Bit(), &statbuffer) != -1)  // already exists!
 	    {
 	      choice =
 		KMessageBox::warningYesNoCancel(0, i18n("Archive already exists. Do you wish to overwrite it?"), i18n("Archive already exists"));
@@ -591,6 +591,27 @@ QString ArkWidget::getCreateFilename()
 		}
 	    }
 	  // if we got here, the file does not already exist.
+	  QString dir = strFile.left(strFile.findRev('/'));
+	  stat(dir.local8Bit(), &statbuffer);
+	  unsigned int nFlag = 0;
+	  if (geteuid() == statbuffer.st_uid)
+	    {
+	      nFlag = S_IWUSR; // it's mine
+	    }
+	  else if (getegid() == statbuffer.st_gid)
+	    {
+	      nFlag = S_IWGRP; // it's my group's
+	    }
+	  else
+	    {
+	      nFlag = S_IWOTH;  // it's someone else's
+	    }
+	  if (! ((statbuffer.st_mode & nFlag) == nFlag))
+	    {
+	      KMessageBox::error(this, i18n("You don't have permission to write to the directory %1").arg(dir.local8Bit()));
+	      return "";
+	    }
+	  // if we made it here, it's a go.
 	  if (! strFile.contains('.'))
 	    {
 	      // if the filename has no dot in it, ask should we append ".zip"?
@@ -620,6 +641,7 @@ QString ArkWidget::getCreateFilename()
 void ArkWidget::file_new()
 {
   QString strFile = getCreateFilename();
+  m_settings->clearShellOutput();
   if (!strFile.isEmpty())
     createArchive( strFile );
 }
@@ -671,17 +693,14 @@ void ArkWidget::file_open()
   QString strFile;
   url = KFileDialog::getOpenURL(m_settings->getOpenDir(),
 				m_settings->getFilter(), this);
-
   qApp->processEvents();
 
-  // do I have to remove this later if it's a temporary from net?
-  // Needs work. XXX
   if (!url.isEmpty())
     {
       KIO::NetAccess::download(url, strFile); 
       m_settings->clearShellOutput();
       recent->addURL(url);
-      file_open(strFile);  // note: assumes it is local for now
+      file_open(strFile);
     }
   kdDebug(1601) << "-ArkWidget::file_open" << endl;
 }
@@ -693,9 +712,12 @@ void ArkWidget::file_openRecent(const KURL& url)
   {
     KIO::NetAccess::download(url, strFile); 
     m_settings->clearShellOutput();
+    kdDebug(1601) << "Recent open: " << strFile.local8Bit() << endl;
     file_open(strFile);
-    return;
   }
+  else
+    kdDebug(1601) << "Empty URL requested in file_openRecent()" << endl;
+      
 }
 
 void ArkWidget::showZip( QString _filename )
@@ -831,6 +853,8 @@ void ArkWidget::slotExtractDone()
       d->dragCopy();
       m_bDropSourceIsSelf = false;
     }
+  delete m_extractList;
+  m_extractList = NULL;
   archiveContent->setUpdatesEnabled(true);
   fixEnables();  
   kdDebug(1601) << "-ArkWidget::slotExtractDone" << endl;
@@ -973,7 +997,7 @@ void ArkWidget::file_reload()
     {
       QString filename = arch->fileName();
       file_close();
-      file_open( filename );
+      file_open(filename);
     }
 }
 
@@ -1028,8 +1052,9 @@ void ArkWidget::window_close()
 }
 
 
-void ArkWidget::closeEvent( QCloseEvent * )
+void ArkWidget::closeEvent( QCloseEvent *e )
 {
+    KTMainWindow::closeEvent(e);
     window_close();
 }
 
@@ -1053,25 +1078,30 @@ void ArkWidget::edit_select()
       if (!reg_exp.isValid())
 	kdError(1601) <<
 	  "ArkWidget::edit_select: regular expression is not valid." << endl;
-      
-      FileLVI * flvi = (FileLVI*)archiveContent->firstChild();
-
-      // don't call the slot for each selection!
-      disconnect( archiveContent, SIGNAL( selectionChanged()),
-		  this, SLOT( slotSelectionChanged() ) );
-    
-      while (flvi)
+      else
 	{
-	  if ( reg_exp.match(flvi->text(0))==0 )
+	  // first deselect everything
+	  archiveContent->clearSelection();
+	  FileLVI * flvi = (FileLVI*)archiveContent->firstChild();
+	  
+
+	  // don't call the slot for each selection!
+	  disconnect( archiveContent, SIGNAL( selectionChanged()),
+		      this, SLOT( slotSelectionChanged() ) );
+    
+	  while (flvi)
 	    {
-	      archiveContent->setSelected(flvi, true);
+	      if ( reg_exp.match(flvi->text(0))==0 )
+		{
+		  archiveContent->setSelected(flvi, true);
+		}
+	      flvi = (FileLVI*)flvi->itemBelow();
 	    }
-	  flvi = (FileLVI*)flvi->itemBelow();
+	  // restore the behavior
+	  connect( archiveContent, SIGNAL( selectionChanged()),
+		   this, SLOT( slotSelectionChanged() ) );
+	  updateStatusSelection();
 	}
-      // restore the behavior
-      connect( archiveContent, SIGNAL( selectionChanged()),
-	       this, SLOT( slotSelectionChanged() ) );
-      updateStatusSelection();	
     }
 }
 
@@ -1344,27 +1374,124 @@ void ArkWidget::slotOpenWith()
       fullname += m_settings->getTmpDir();
       fullname += name;
 
-      QStringList list;
-      list.append(name);
+      m_extractList = new QStringList;
+      m_extractList->append(name);
       archiveContent->setUpdatesEnabled(false);
       m_bOpenWithInProgress = true;
       m_strFileToView = fullname;
       QApplication::setOverrideCursor( waitCursor );
       disableAll();
-      arch->unarchFile( &list, m_settings->getTmpDir() );
+      arch->unarchFile(m_extractList, m_settings->getTmpDir());
     }
 }
 
+bool ArkWidget::getOverwrite(ArchType _archtype)
+{
+  // returns true if Overwrite is set on this particular archive type
+  switch (_archtype)
+    {
+    case ZIP_FORMAT:
+      return m_settings->getZipExtractOverwrite();
+    case TAR_FORMAT:
+      return m_settings->getTarOverwriteFiles();
+    case RAR_FORMAT:
+      return m_settings->getRarOverwriteFiles();
+    case ZOO_FORMAT:
+      return m_settings->getZooOverwriteFiles();
+    case LHA_FORMAT:
+    case AA_FORMAT:
+    case COMPRESSED_FORMAT:
+      return true;
+    case UNKNOWN_FORMAT:
+      ASSERT(0); // never happens;
+    }
+  return false;
+}
+
+bool ArkWidget::reportExtractFailures(const QString & _dest,
+				      QStringList *_list)
+{
+  // reports extract failures when Overwrite = False and the file
+  // exists already in the destination directory.
+  // If list is null, it means we are extracting all files.
+  // Otherwise the list contains the files we are to extract.
+
+  QString strFilename, tmp;
+  struct stat statbuffer;
+  bool bRedoExtract = false;
+
+  QApplication::restoreOverrideCursor();
+
+  ASSERT(_list != NULL);
+  QString strDestDir = _dest;
+
+  // make sure the destination directory has a / at the end.
+  if (strDestDir.right(1) != '/')
+    strDestDir += "/";
+
+  if (_list->isEmpty())
+  {
+    // make the list
+    FileListView *flw = fileList();
+    FileLVI *flvi = (FileLVI*)flw->firstChild();
+    while (flvi)
+      {
+	tmp = flvi->getFileName().local8Bit();
+	_list->append(tmp);
+	flvi = (FileLVI*)flvi->itemBelow();
+      }
+  }
+  QStringList existingFiles;
+  // now the list contains all the names we must verify.
+  for (QStringList::Iterator it = _list->begin(); it != _list->end(); ++it)
+    {
+      strFilename = *it;
+      QString strFullName = strDestDir + strFilename;
+      if (stat((const char *)strFullName, &statbuffer) != -1)
+	existingFiles.append(strFilename);
+    }
+  
+  int numFilesToReport = existingFiles.count();
+  
+  kdDebug(1601) << "There are " << numFilesToReport << " files to report existing already." << endl;
+
+  // now report on the contents
+  if (numFilesToReport == 1)  
+    {
+      kdDebug(1601) << "One to report" << endl;
+      strFilename = *(existingFiles.at(0));
+      QString message = strFilename + i18n(" was not extracted because it would overwrite an existing file.\nGo back to Extract Dialog?");
+      bRedoExtract =
+	KMessageBox::questionYesNo(this, message) == KMessageBox::Yes;
+    }
+  else if (numFilesToReport != 0)
+    {
+      ExtractFailureDlg *fDlg = new ExtractFailureDlg(&existingFiles,
+						      this);
+      bRedoExtract = !fDlg->exec();
+    }
+  return bRedoExtract;
+}
+
+
 void ArkWidget::action_extract()
 {
-  ExtractDlg *dlg = new ExtractDlg(getArchType(m_strArchName),
-				   m_settings);
+  ArchType archtype = getArchType(m_strArchName);
+  ExtractDlg *dlg = new ExtractDlg(archtype, m_settings);
 
   // if they choose pattern, we have to tell arkwidget to select
   // those files... once we're in the dialog code it's too late.
   connect(dlg, SIGNAL(pattern(const QString &)), 
 	  this, SLOT(selectByPattern(const QString &)));
+  bool bRedoExtract = false;
 
+  if (m_nNumSelectedFiles == 0)
+    dlg->disableSelectedFilesOption();
+  if (archiveContent->currentItem() == NULL)
+    dlg->disableCurrentFileOption();
+
+  // list of files to be extracted
+  m_extractList = new QStringList;
   if (dlg->exec())
     {
       int extractOp = dlg->extractOp();
@@ -1373,48 +1500,57 @@ void ArkWidget::action_extract()
       QApplication::setOverrideCursor( waitCursor );
       disableAll();
 
+      // if overwrite is false, then we need to check for failure of
+      // extractions.
+      bool bOvwrt = getOverwrite(archtype); 
+
       switch(extractOp)
 	{
 	case ExtractDlg::All:
-	  arch->unarchFile(0);
+	  if (!bOvwrt)  // send empty list to indicate we're extracting all
+	    bRedoExtract = reportExtractFailures(m_settings->getExtractDir(),
+						 m_extractList);
+	  if (!bRedoExtract) // if the user's OK with those failures, go ahead
+	    arch->unarchFile(0);
 	  break;
 	case ExtractDlg::Pattern:
 	case ExtractDlg::Selected:
-	  {
-	    // make a list to send to unarchFile
-	    QStringList *list = new QStringList;
-	    FileListView *flw = fileList();
-	    FileLVI *flvi = (FileLVI*)flw->firstChild();
-	    QString tmp;
-	    while (flvi)
-	      {
-		if ( flw->isSelected(flvi) )
-		  {
-		    kdDebug(1601) << "unarching " << flvi->getFileName() << endl;
-		    tmp = flvi->getFileName().local8Bit();
-		    list->append(tmp.local8Bit());
-		  }
-		flvi = (FileLVI*)flvi->itemBelow();
-	      }
-	    arch->unarchFile(list); // extract selected files
-	    delete list;
-	    break;
-	  }
 	case ExtractDlg::Current:
-	  {
-	    FileLVI *pItem = archiveContent->currentItem();
-	    if (pItem == 0)
-	      kdDebug(1601) << "Can't seem to figure out which is current!" << endl;
-	    else
-	      {
-		QString tmp = pItem->text(0);  // get the name
-		QStringList *list = new QStringList;
-		list->append(tmp.local8Bit());
-		arch->unarchFile(list) ;
-		delete list;
-	      }
-	    break;
-	  }
+	  if (extractOp != ExtractDlg::Current )
+	    {
+	      // make a list to send to unarchFile
+	      FileListView *flw = fileList();
+	      FileLVI *flvi = (FileLVI*)flw->firstChild();
+	      QString tmp;
+	      while (flvi)
+		{
+		  if ( flw->isSelected(flvi) )
+		    {
+		      kdDebug(1601) << "unarching " << flvi->getFileName() << endl;
+		      tmp = flvi->getFileName().local8Bit();
+		      m_extractList->append(tmp);
+		    }
+		  flvi = (FileLVI*)flvi->itemBelow();
+		}
+	    }
+	  else
+	    {
+	      FileLVI *pItem = archiveContent->currentItem();
+	      if (pItem == 0)
+		{
+		  kdDebug(1601) << "Can't seem to figure out which is current!" << endl;
+		  return;
+		}
+	      QString tmp = pItem->text(0);  // get the name
+	      m_extractList->append(tmp.local8Bit());
+	    }
+	  if (!bOvwrt)
+	    bRedoExtract =
+	      reportExtractFailures(m_settings->getExtractDir(),
+				    m_extractList);
+	  if (!bRedoExtract)
+	    arch->unarchFile(m_extractList); // extract selected files
+	  break;
 	default:
 	  ASSERT(0);
 	  // never happens
@@ -1423,6 +1559,10 @@ void ArkWidget::action_extract()
       
       delete dlg;
     }
+
+  // user might want to change some options or the selection...
+  if (bRedoExtract)
+    action_extract();
 }
 
 void ArkWidget::action_edit()
@@ -1457,26 +1597,19 @@ void ArkWidget::showFile( FileLVI *_pItem )
   fullname += m_settings->getTmpDir();
   fullname += name;
 
-  QStringList list;
-  list.append(name);
+  m_extractList = new QStringList;
+  m_extractList->append(name);
 
   archiveContent->setUpdatesEnabled(false);
   m_bViewInProgress = true;
   m_strFileToView = fullname;
   QApplication::setOverrideCursor( waitCursor );
   disableAll();
-  arch->unarchFile( &list, m_settings->getTmpDir() );
+  arch->unarchFile(m_extractList, m_settings->getTmpDir() );
 }
 
 // Options menu //////////////////////////////////////////////////////
 
-void ArkWidget::options_general()
-{
-  GeneralDlg *gd = new GeneralDlg( m_settings, this );
-  gd->exec();
-  delete gd;
-}
-
 void ArkWidget::options_dirs()
 {
   DirDlg *dd = new DirDlg( m_settings, this );
@@ -1567,14 +1700,11 @@ void ArkWidget::updateStatusSelection()
     }
   if (m_nNumSelectedFiles != 1)
     {
-      strInfo = i18n("%1 Files Selected %1 KB")
-	.arg(KGlobal::locale()->formatNumber(m_nNumSelectedFiles, 0))
-	.arg(KGlobal::locale()->formatNumber(m_nSizeOfSelectedFiles, 0));
+      strInfo = i18n("%1 Files Selected %1 KB").arg(KGlobal::locale()->formatNumber(m_nNumSelectedFiles, 0)).arg(KGlobal::locale()->formatNumber(m_nSizeOfSelectedFiles, 0));
     }
   else
     {
-    strInfo = i18n("1 File Selected %1 KB")
-      .arg(KGlobal::locale()->formatNumber(m_nSizeOfSelectedFiles, 0));
+    strInfo = i18n("1 File Selected %1 KB").arg(KGlobal::locale()->formatNumber(m_nSizeOfSelectedFiles, 0));
     }
   m_pStatusLabelSelect->setText(strInfo);
   fixEnables();
@@ -1663,9 +1793,18 @@ void ArkWidget::dropAction(QStringList *list)
     {
       str = *it;
       kdDebug(1601) << (const char *)str << endl;
-      if (str.left(5) != QString("file:"))
+      if (str.left(5) != QString("file:") )
 	{
-	  str = "file:" + str;
+	  if (str.left(7) == "http://" ||
+	      str.left(6) == "ftp://")
+	    {
+	      KURL url = str;
+	      KIO::NetAccess::download(url, str); 
+	    }
+	  else
+	    {
+	      str = "file:" + str;
+	    }
 	}
       urls.append(str);
     }
@@ -1697,6 +1836,12 @@ void ArkWidget::dropAction(QStringList *list)
     str = urls.first();
     if (str.left(5) == "file:")
       str = str.right(str.length()-5);  // get rid of "file:" part of url
+    else if (str.left(7) == "http://" ||
+	     str.left(6) == "ftp://")
+      {
+	KURL url = str;
+	KIO::NetAccess::download(url, str); 
+      }
     file_open(str);
   }
   else
@@ -1820,7 +1965,7 @@ void ArkWidget::clearStatusBar()
 
 void ArkWidget::arkWarning(const QString& msg)
 {
-        KMessageBox::information(this, msg);
+  KMessageBox::information(this, msg);
 }
 
 #if 0
@@ -1903,6 +2048,9 @@ bool ArkWidget::badBzipName(const QString & _filename)
 
 void ArkWidget::createArchive( const QString & _filename )
 {
+
+  // make sure we can write there
+
   Arch * newArch = 0;
   switch( getArchType( _filename ) )
     {
@@ -1943,6 +2091,7 @@ void ArkWidget::createArchive( const QString & _filename )
   archiveContent->setUpdatesEnabled(false);
   QApplication::setOverrideCursor( waitCursor );
   newArch->create();
+  recent->addURL(_filename);
 }
 
 void ArkWidget::openArchive(const QString & _filename )
