@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
-  $Id: arkwidget.h,v 1.50 2000/05/04 21:20:47 ezust Exp $
+  $Id: arkwidget.h,v 1.52 2000/05/30 21:09:46 ezust Exp $
 
   ark -- archiver for the KDE project
 
@@ -112,7 +112,7 @@ public slots:
   void toggleToolBar();
   void toggleStatusBar();
   void toggleMenuBar();
-
+  void edit_view_last_shell_output();
 protected slots:
   void file_new();
   void file_open();
@@ -125,7 +125,6 @@ protected slots:
   void edit_selectAll();
   void edit_deselectAll();
   void edit_invertSel();
-  void edit_view_last_shell_output();
     
   void action_add();
   void action_add_dir();
@@ -136,7 +135,6 @@ protected slots:
   void action_edit();
   void options_dirs();
   void options_keys();
-  void options_general();
   //  void options_saveOnExit();
   void options_saveNow();
   void setHeader();
@@ -186,7 +184,10 @@ private: // methods
 
   // complains if the filename has capital letters or is tbz or tbz2
   bool badBzipName(const QString & _filename);
+  bool getOverwrite(ArchType _archtype);
 
+  bool reportExtractFailures(const QString & _dest,
+			     QStringList *_list);
 protected:
   void arkWarning(const QString& msg);
   void arkError(const QString& msg);
@@ -277,6 +278,9 @@ private: // data
 
   KRun *m_pKRunPtr;
   QStringList mDragFiles; // to be able to access the drag/extract files
+
+  // the list of files being extracted. Needs to be deleted in slotExtractDone
+  QStringList *m_extractList;
 };
 
 #endif /* ARKWIDGET_H*/
