@@ -1,5 +1,7 @@
 /*
 
+  $Id: filelistview.cpp,v 1.17 2000/06/02 19:37:34 ezust Exp $
+
   ark -- archiver for the KDE project
 
   Copyright (C)
@@ -32,6 +34,7 @@
 #include <qheader.h>
 #include <qpixmap.h>
 #include <qstringlist.h>
+#include <qwhatsthis.h>
 
 // KDE includes
 #include <klocale.h>
@@ -93,6 +96,8 @@ FileListView::FileListView(QWidget *parent, const char* name)
 {
   sortColumn = 0;
   increasing = TRUE;
+  QWhatsThis::add(this, i18n("This area is for displaying information about the files contained within an archive."));
+
   setMouseTracking(false);
 }
 
@@ -190,7 +195,10 @@ void FileListView::contentsMouseMoveEvent(QMouseEvent *e)
   kdDebug(1601) << "Drag Starting..." << endl;
   m_pParent->unarchFile(&dragFiles);
 }
-#endif
+#endif // end of stuff that doesn't quite work
+
+
+
 
 void FileListView::contentsMousePressEvent(QMouseEvent *e)
 {
