@@ -1,6 +1,6 @@
 /*
 
- $Id: shellOutputDlg.cpp,v 1.3 2000/03/09 19:38:14 ezust Exp $
+ $Id: shellOutputDlg.cpp,v 1.4 2000/06/01 19:31:21 ezust Exp $
 
  ark -- archiver for the KDE project
 
@@ -42,7 +42,7 @@ ShellOutputDlg::ShellOutputDlg( ArkSettings *_data, QWidget *_parent,
 				const char *_name )
 	: QDialog( _parent, _name, true )
 {
-  setCaption( i18n("ark - Last shell output") );
+  setCaption( i18n("Shell Output") );
   QVBoxLayout *mainLayout = new QVBoxLayout( this, 10 );
 
   QMultiLineEdit *l1 = new QMultiLineEdit( this );
@@ -58,7 +58,7 @@ ShellOutputDlg::ShellOutputDlg( ArkSettings *_data, QWidget *_parent,
 
   mainLayout->addWidget( l1 );
 
-  QPushButton *close = new QPushButton( i18n("Dismiss"), this );
+  QPushButton *close = new QPushButton( i18n("Close"), this );
   close->setFixedSize( close->sizeHint() );
   connect( close, SIGNAL( clicked() ), SLOT( accept() ) );
   mainLayout->addWidget( close );
