@@ -20,7 +20,7 @@
  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
  
- * $Revision: 1.21 $
+ * $Revision: 1.28 $
  */
 
 #include "kab_topwidget.h"
@@ -33,6 +33,8 @@
 #include <kmenubar.h>
 #include <kmessagebox.h>
 #include <klocale.h>
+#include <kiconloader.h>
+#include <kcombobox.h>
 #include <kapp.h>
 #include <kstdaccel.h>
 #include <kstddirs.h>
@@ -46,16 +48,19 @@
 
 TopLevelWidget::TopLevelWidget()
   : KTMainWindow(),
+    viewFrame(0),
     view(0),
     currentView(NoView),
     current(0),
+    hasEmailAddresses(false),
+    hasURLs(false),
     timer(new QTimer(this)),
     messages(new QStringList),
     modified(false),
     closingdown(false)
 {
   bool GUARD; GUARD=true;
-  kDebugInfo(GUARD, 0, "TopLevelWidget ctor: called.");
+  kdDebug() << "TopLevelWidget ctor: called.";
   // -----
   // WORK_TO_DO: remember last selected view
   createView(BusinessCard);
@@ -72,7 +77,7 @@ TopLevelWidget::TopLevelWidget()
   makeToolbar();
   makeStatusbar();
   // -----
-  connect(nav, SIGNAL(itemSelected(int)), SLOT(entrySelected(int)));
+  // connect(nav, SIGNAL(itemSelected(int)), SLOT(entrySelected(int)));
   connect(api, SIGNAL(setStatus(const QString&)),
 	  SLOT(setStatus(const QString&)));
   connect(timer, SIGNAL(timeout()), SLOT(statusbarTimeOut()));
@@ -90,7 +95,7 @@ TopLevelWidget::TopLevelWidget()
   entriesChanged();
   // -----
   setStatus(i18n("Welcome to kab 2.0"));
-  kDebugInfo(GUARD, 0, "TopLevelWidget ctor: done.");
+  kdDebug() << "TopLevelWidget ctor: done.";
 }
 
 void TopLevelWidget::makeMenu()
@@ -109,20 +114,25 @@ void TopLevelWidget::makeMenu()
 		   SLOT(loadDatabaseFile()), KStdAccel::open());
   file->insertItem(i18n("Open default &database"), this,
 		   SLOT(loadDefaultDatabase()));
-  file->insertItem(i18n("&Save"), this,
-		   SLOT(save()), KStdAccel::save());
+  idFileSave=file->insertItem(i18n("&Save"), this,
+			      SLOT(save()), KStdAccel::save());
   file->insertSeparator();
   file->insertItem(i18n("&Import..."), import);
   file->insertSeparator();
   file->insertItem(i18n("&Quit"), this, SLOT(quit()), KStdAccel::quit());
+  connect(kapp, SIGNAL(shutDown()), SLOT(quit()));
   // ----- the edit menu:
   edit=new QPopupMenu;
   edit->insertItem(i18n("&Add entry"), this, SLOT(add()), CTRL+Key_A);
-  edit->insertItem(i18n("&Edit entry"), this, SLOT(editEntry()), CTRL+Key_E);
-  edit->insertItem(i18n("&Remove entry"), this, SLOT(remove()), CTRL+Key_R);
+  idEditEdit=edit->insertItem
+    (i18n("&Edit entry"), this, SLOT(editEntry()), CTRL+Key_E);
+  idEditRemove=edit->insertItem
+    (i18n("&Remove entry"), this, SLOT(remove()), CTRL+Key_R);
   edit->insertSeparator();
-  idEditMail=edit->insertItem(i18n("Send an e&mail"), this, SLOT(mail()), CTRL+Key_M);
-  idEditBrowse=edit->insertItem(i18n("&Browse"), this, SLOT(browse()), CTRL+Key_B);
+  idEditMail=edit->insertItem
+    (i18n("Send an e&mail"), this, SLOT(mail()), CTRL+Key_M);
+  idEditBrowse=edit->insertItem
+    (i18n("&Browse"), this, SLOT(browse()), CTRL+Key_B);
   edit->insertSeparator();
   edit->insertItem(i18n("Enable all &messages"), this,
 		   SLOT(enableAllMessages()));
@@ -146,16 +156,75 @@ void TopLevelWidget::makeMenu()
 
 void TopLevelWidget::makeToolbar()
 {
-  int id;
+  QStringList dummy;
   // -----
-  nav=new KDataNavigator(toolBar());
-  nav->setFrameStyle(QFrame::NoFrame);
-  nav->setMode(KDataNavigator::List);
-  id=toolBar()->insertWidget(0, 100, nav);
-  toolBar()->setItemAutoSized(id);
-  connect(nav, SIGNAL(newItem()), SLOT(add()));
+  toolBar()->insertButton(BarIcon("filenew"), NewEntry, true,
+			  i18n("New entry"));
+  toolBar()->insertButton(BarIcon("pencil"), EditEntry, true,
+			  i18n("Edit entry"));
+  toolBar()->insertButton(BarIcon("eraser"), DeleteEntry, true,
+			  i18n("Delete entry"));
+  toolBar()->insertLineSeparator();
+  toolBar()->insertButton(BarIcon("start"), FirstEntry, true,
+			  i18n("First entry"));
+  toolBar()->insertButton(BarIcon("back"), PrevEntry, true,
+			  i18n("Previous entry"));
+  toolBar()->insertCombo(dummy, Entries, false,
+			 SIGNAL(activated(int)),
+			 this, SLOT(entrySelected(int)));
+  toolBar()->setItemAutoSized(Entries);
+  toolBar()->insertButton(BarIcon("forward"), NextEntry, true,
+			  i18n("Next entry"));
+  toolBar()->alignItemRight(NextEntry);
+  toolBar()->insertButton(BarIcon("finish"), LastEntry, true,
+			  i18n("Last entry"));
+  toolBar()->alignItemRight(LastEntry);
+  connect(toolBar(), SIGNAL(clicked(int)), SLOT(action(int)));
 }
 
+void TopLevelWidget::action(int i)
+{
+  QComboBox *combo=toolBar()->getCombo(Entries);
+  CHECK_PTR(combo);
+  int index;
+  // -----
+  switch(i)
+    {
+    case NewEntry: // add
+      add();
+      break;
+    case EditEntry: // edit
+      editEntry();
+      break;
+    case DeleteEntry: // delete
+      remove();
+      break;
+    case FirstEntry:
+      index=0;
+      combo->setCurrentItem(index);
+      entrySelected(index);
+      break;
+    case PrevEntry:
+      index=QMAX(0, combo->currentItem()-1);
+      combo->setCurrentItem(index);
+      entrySelected(index);
+      break;
+    case NextEntry:
+      index=QMIN(combo->count()-1, combo->currentItem()+1);
+      combo->setCurrentItem(index);
+      entrySelected(index);
+      break;
+    case LastEntry:
+      index=combo->count()==0 ? 0 : combo->count()-1;
+      combo->setCurrentItem(index);
+      entrySelected(index);
+      break;
+    default:
+      debug("TopLevelWidget::action: unknown action %i", i);
+    };
+}
+
+
 void TopLevelWidget::makeStatusbar()
 {
   //statusBar()->setInsertOrder(KStatusBar::RightToLeft);
@@ -181,7 +250,7 @@ bool TopLevelWidget::initializeInterface()
 void TopLevelWidget::entrySelected(int index)
 {
   bool GUARD; GUARD=true;
-  kDebugInfo(GUARD, 0, "TopLevelWidget::entrySelected: called (%i).", index);
+  kdDebug() << "TopLevelWidget::entrySelected: called ( " << index << ")";
   // -----
   AddressBook::Entry entry;
   KabKey key;
@@ -205,20 +274,20 @@ void TopLevelWidget::entrySelected(int index)
     }
   // -----
   number=api->addressbook()->noOfEntries();
+  kdDebug() << "TopLevelWidget::entrySelected: " << number <<" entries.";
   if(number!=0)
     {
       view->setEnabled(true);
       if(api->addressbook()->getKey(index, key)!=AddressBook::NoError)
 	{
-	  kDebugInfo("TopLevelWidget::entrySelected: no such entry (%i).",
-		     index);
+	  kdDebug() << "TopLevelWidget::entrySelected: no such entry " << index;
 	}
       if(api->addressbook()->getEntry(key, entry)!=AddressBook::NoError)
 	{
-	  kDebugInfo("TopLevelWidget::entrySelected: cannot access existing entry.");
+	  kdDebug() << "TopLevelWidget::entrySelected: cannot access existing entry.";
 	}
     } else {
-      kDebugInfo("TopLevelWidget::entrySelected: no entries.");
+      kdDebug() << "TopLevelWidget::entrySelected: no entries.";
       view->setEnabled(false);
     }
   // -----
@@ -231,31 +300,69 @@ void TopLevelWidget::entrySelected(int index)
   statusBar()->changeItem(text, Number);
   // -----
   view->setEntry(entry);
+  hasEmailAddresses=entry.emails.count()>0;
+  hasURLs=entry.URLs.count()>0;
   modified=false; // finally reset modification mark
   if(current!=0)
     { // make sure the old key is deleted:
       delete current; current=0;
     }
   current=new KabKey(key);
-  kDebugInfo(GUARD, 0, "TopLevelWidget::entrySelected: done (%i).", index);
+  // ----- enable/disable buttons:
+  if(number<2)
+    {
+      toolBar()->setItemEnabled(FirstEntry, false);
+      toolBar()->setItemEnabled(PrevEntry, false);
+      toolBar()->setItemEnabled(LastEntry, false);
+      toolBar()->setItemEnabled(NextEntry, false);
+    } else {
+      if(index==0)
+	{
+	  toolBar()->setItemEnabled(FirstEntry, false);
+	  toolBar()->setItemEnabled(PrevEntry, false);
+	} else {
+	  toolBar()->setItemEnabled(FirstEntry, true);
+	  toolBar()->setItemEnabled(PrevEntry, true);
+	}
+      if(index==number-1)
+	{
+	  toolBar()->setItemEnabled(LastEntry, false);
+	  toolBar()->setItemEnabled(NextEntry, false);
+	} else {
+	  toolBar()->setItemEnabled(LastEntry, true);
+	  toolBar()->setItemEnabled(NextEntry, true);
+	}
+    }
+  enableButtons();
+  // -----
+  kdDebug() << "TopLevelWidget::entrySelected: done " << index << ".";
 }
 
 void TopLevelWidget::entriesChanged()
 { // this signal is emitted from AddressBook::updateEntriesMap
   bool GUARD; GUARD=true;
-  kDebugInfo(GUARD, 0, "TopLevelWidget::entriesChanged: called.");
+  kdDebug() << "TopLevelWidget::entriesChanged: called.";
   // -----
+  int current;
+  QComboBox *combo=toolBar()->getCombo(Entries);
   QStringList headlines;
   // -----
+  if(combo==0) return;
   if(api->addressbook()->getListOfNames(&headlines, true, false)
      !=AddressBook::NoError)
     {
       return;
     }
-  nav->setList(&headlines);
-  entrySelected(0); // WORK_TO_DO: remember the visible entry like in kab 1
+  current=combo->currentItem();
+  if(current<0) current=0;
+  combo->clear();
+  combo->insertStringList(headlines);
+  current=QMAX(combo->count()-1, current);
+  combo->setCurrentItem(current);
+  entrySelected(current); // WORK_TO_DO: remember the visible entry like in kab 1
+  enableButtons();
   // -----
-  kDebugInfo(GUARD, 0, "TopLevelWidget::entriesChanged: done.");  
+  kdDebug() << "TopLevelWidget::entriesChanged: done.";  
 }
 
 void TopLevelWidget::importKab1Addressbook()
@@ -319,6 +426,7 @@ void TopLevelWidget::loadDefaultDatabase()
 	}
     }
   modified=false;
+  enableButtons();
   // ###########################################################################
 }
 
@@ -462,6 +570,15 @@ void TopLevelWidget::createView(View v, bool recreate)
   bool modificationstate=modified;
   // ----- avoid deleting and creating:
   if(v==currentView && !recreate) return;
+  // ----- create view frame if needed:
+  if(viewFrame==0)
+    { // this should be called only once:
+      viewFrame=new QFrame(this);
+      QBoxLayout *viewLayout=new QBoxLayout
+	(viewFrame, QBoxLayout::TopToBottom);
+      viewLayout->setAutoAdd(true);
+      setView(viewFrame, true);
+    }
   // -----
   AddressBook::Entry entry;
   // -----
@@ -475,21 +592,21 @@ void TopLevelWidget::createView(View v, bool recreate)
   switch(v)
     {
     case BusinessCard:
-      view=new KABBusinessCard(api, this);
+      view=new KABBusinessCard(api, viewFrame);
       break;
     case Editing:
-      view=new KABEditLook(api, this);
+      view=new KABEditLook(api, viewFrame);
       connect(view, SIGNAL(entryChanged()), SLOT(entryChangedSlot()));
       break;
     default:
-      kDebugWarning("TopLevelWidget::createView: unknown kind of view.");
-      view=new KABBusinessCard(api, this);
+      kdDebug() << "TopLevelWidget::createView: unknown kind of view.";
+      view=new KABBusinessCard(api, viewFrame);
     }
   connect(view, SIGNAL(sendEmail(const QString&)), SLOT(mail(const QString&)));
   connect(view, SIGNAL(browse(const QString&)), SLOT(browse(const QString&)));
   view->setEntry(entry);
-  view->setMinimumSize(320, 200);
-  setView(view, true);
+  viewFrame->setMinimumSize(320, 200);
+  //  setView(view, true);
   view->show();
   currentView=v;
   modified=modificationstate;
@@ -499,13 +616,15 @@ void TopLevelWidget::createView(View v, bool recreate)
 void TopLevelWidget::entryChangedSlot()
 {
   register bool GUARD; GUARD=false;
-  kDebugInfo(GUARD, 0,
-	     "TopLevelWidget::entryChangedSlot: current entry has been changed.");
+  kdDebug() << "TopLevelWidget::entryChangedSlot: current entry has been changed.";
   modified=true;
 }
 
 void TopLevelWidget::quit()
 {
+  register bool GUARD; GUARD=false;
+  kdDebug() << "TopLevelWidget::quit: quitting.";  
+  save();
   closingdown=true;
   kapp->quit();
 }
@@ -523,8 +642,7 @@ void TopLevelWidget::showAboutApplication(void)
   path=locate("appdata", "pics/addressbook_logo.png");
   if(path.isEmpty())
     {
-      kDebugWarning
-	(0, "TopLevelWidget::aboutKAB: cannot locate ressources.");
+      kdDebug() << "TopLevelWidget::aboutKAB: cannot locate ressources.";
     } else {
       if(logo.load(path))
 	{
@@ -543,9 +661,39 @@ void TopLevelWidget::mail()
   mail(QString::null);
 }
 
-void TopLevelWidget::mail(const QString& url)
-{
-  kdDebug() << "TopLevelWidget::mail: called with url " << url << "." << endl;
+void TopLevelWidget::mail(const QString&)
+{ // the given URL is ignored!
+  AddressBook::Entry entry;
+  int x;
+  KDialogBase dialog
+    (this, 0, true, i18n("Send an email"), KDialogBase::Ok|KDialogBase::Cancel,
+     KDialogBase::Ok, true);
+  QListBox lb(&dialog);
+  dialog.setMainWidget(&lb);
+  // ----- get the entry:
+  if(api->addressbook()->getEntry(*current, entry)==AddressBook::NoError)
+    {
+      if(entry.emails.count()==0)
+	{
+	  emit(setStatus(i18n("No email addresses.")));
+	  kapp->beep();
+	  return;
+	}
+      lb.insertStringList(entry.emails);
+      lb.setCurrentItem(0);
+      x=QMAX((int)(lb.maxItemWidth()*1.10), lb.sizeHint().width());
+      lb.setMinimumSize(x, QMAX(x/2, lb.sizeHint().height()));
+      if(dialog.exec())
+	{ // ----- open the composer:
+	  kapp->invokeMailer(lb.currentText(), QString::null);
+	} else {
+	  emit(setStatus(i18n("Rejected.")));
+	  kapp->beep();
+	  return;
+	}
+    } else {
+      kdDebug() << "TopLevelWidget::mail: cannot find current entry.";
+    }
 }
 
 void TopLevelWidget::browse()
@@ -553,7 +701,53 @@ void TopLevelWidget::browse()
   browse(QString::null);
 }
 
-void TopLevelWidget::browse(const QString& url)
-{
-  kdDebug() << "TopLevelWidget::browse: called with url " << url << "." << endl;
+void TopLevelWidget::browse(const QString&)
+{ // the given URL is ignored!
+  AddressBook::Entry entry;
+  int x;
+  KDialogBase dialog
+    (this, 0, true, i18n("Browse to ..."), KDialogBase::Ok|KDialogBase::Cancel,
+     KDialogBase::Ok, true);
+  QListBox lb(&dialog);
+  dialog.setMainWidget(&lb);
+  // ----- get the entry:
+  if(api->addressbook()->getEntry(*current, entry)==AddressBook::NoError)
+    {
+      if(entry.emails.count()==0)
+	{
+	  emit(setStatus(i18n("No URLs.")));
+	  kapp->beep();
+	  return;
+	}
+      lb.insertStringList(entry.URLs);
+      lb.setCurrentItem(0);
+      x=QMAX((int)(lb.maxItemWidth()*1.10), lb.sizeHint().width());
+      lb.setMinimumSize(x, QMAX(x/2, lb.sizeHint().height()));
+      if(dialog.exec())
+	{ // ----- open the composer:
+	  kapp->invokeBrowser(lb.currentText());
+	} else {
+	  emit(setStatus(i18n("Rejected.")));
+	  kapp->beep();
+	  return;
+	}
+    } else {
+      debug("TopLevelWidget::browse: cannot find current entry.");
+    }
 }
+
+void TopLevelWidget::enableButtons()
+{
+  int entries;
+  // ----- menu items:
+  entries=api->addressbook()->noOfEntries();
+  edit->setItemEnabled
+    (idEditEdit, currentView!=Editing && entries>0);
+  edit->setItemEnabled(idEditRemove, entries>0);
+  edit->setItemEnabled(idEditMail, hasEmailAddresses && entries>0);
+  edit->setItemEnabled(idEditBrowse, hasURLs && entries>0);
+  // ----- toolbar buttons:
+  toolBar()->setItemEnabled(EditEntry, entries>0);
+  toolBar()->setItemEnabled(DeleteEntry, entries>0);
+}
+
