@@ -20,12 +20,14 @@
  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
  
- * $Revision: 1.2 $
+ * $Revision: 1.3 $
  */
 
+#include <kabapi.h>
 #include "look_edit_basictab.h"
 
-TabBasic::TabBasic(QWidget *parent, const char* name)
-  : QWidget(parent, name)
+TabBasic::TabBasic(KabAPI *api_, QWidget *parent, const char* name)
+  : QWidget(parent, name),
+    api(api_)
 {
 }
