@@ -4,6 +4,8 @@
 #include <qwidget.h>
 #include <kabapi.h>
 
+class KabAPI;
+
 /* This class is used to create a common method in all tabs that
    stores all values (attributes of an entry) in an entry handed over
    by reference. This makes it much easier to add tabs or values
@@ -14,7 +16,7 @@ class TabBasic : public QWidget
 {
   Q_OBJECT
 public:
-  TabBasic(QWidget *parent=0, const char* name=0);
+  TabBasic(KabAPI *api_, QWidget *parent=0, const char* name=0);
   /** Store the values in this tab into the entry.
    *  A pure virtual method that transfers the values in the tab into
    *  the entry given by reference.
@@ -27,6 +29,8 @@ public:
 signals:
   /** Emitted when attributes in this tab are changed. */
   void changed();
+protected:
+  KabAPI *api;
 };
 
 #endif // defined KAB_LOOK_EDIT_BASICTAB_H
