@@ -14,25 +14,28 @@ class KarmWindow : public KTMainWindow
   Q_OBJECT
 
   private:
-    QPopupMenu	*_fileMenu;
-    QPopupMenu	*_clockMenu;
-    QPopupMenu	*_taskMenu;
     KAccel		*_accel;
     KAccelMenuWatch	*_watcher;
     Karm		*_karm;
     long		_totalTime;
-    char		*_sessionTimeBuffer;
 
   public:
     KarmWindow();
     virtual ~KarmWindow();
 
+  public slots:
+	void updateTime( long difference );
+
   protected slots:
     void prefs();
     void resetSessionTime(); 
     void updateTime();
+	void updateStatusBar();
     void clockStartMsg();
     void clockStopMsg();
+    void quit();
+    void print();
+	
 
   protected:
     virtual void saveProperties( KConfig* );
@@ -40,8 +43,6 @@ class KarmWindow : public KTMainWindow
     //	virtual void writeSettings( KConfig * );
 
   private:
-    void initAccelItems();
-    void connectAccels();
     void makeMenus();
 };
 
