@@ -1,5 +1,5 @@
 /*
-    $Id: kcalc.cpp,v 1.36 2000/04/28 13:54:59 pbrown Exp $
+    $Id: kcalc.cpp,v 1.37 2000/05/24 09:04:49 kulow Exp $
 
     kCalculator, a simple scientific calculator for KDE
     
@@ -817,7 +817,7 @@ void QtCalculator::Gra_Selected()
 
 void QtCalculator::helpclicked()
 {
-  kapp->invokeHTMLHelp( "kcalc/index.html", "" );
+  kapp->invokeHelp( );
 }
 
 
