@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: sshdlg.cpp,v 1.1 2000/03/15 11:22:55 jansen Exp $
+ * $Id: sshdlg.cpp,v 1.2 2000/05/20 14:29:29 jansen Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -45,7 +45,8 @@ bool KDEsshDialog::checkPassword(const char *password)
 {
     SshProcess proc(m_Host, m_User);
     int ret = proc.checkInstall(password);
-    if (ret != 0) {
+    if (ret != 0) 
+    {
         KMessageBox::sorry(this, i18n("Incorrect password! Please try again."));
 	return false;
     }
