@@ -1,7 +1,7 @@
 /*
  * kdfwidget.cpp
  *
- * $Id: kdfwidget.cpp,v 1.18 2000/05/02 01:04:06 waba Exp $
+ * $Id: kdfwidget.cpp,v 1.19 2000/05/24 09:04:49 kulow Exp $
  *
  * Copyright (c) 1998 Michael Kropfberger <michael.kropfberger@gmx.net>
  *
@@ -557,9 +557,9 @@ void KDFWidget::columnSizeChanged( int column, int, int newSize )
 }
 
 
-void KDFWidget::invokeHTMLHelp()
+void KDFWidget::invokeHelp()
 {
-  kapp->invokeHTMLHelp("kcontrol/kdf/index.html","");
+  kapp->invokeHelp("", "kcontrol/kdf");
 }
 
 #include "kdfwidget.moc"
