@@ -1,7 +1,7 @@
 /*
   kwikdisk.cpp - KDiskFree
 
-  $Id: kwikdisk.cpp,v 1.20 2000/04/02 22:53:24 jansen Exp $
+  $Id: kwikdisk.cpp,v 1.22 2000/05/24 11:42:45 hoelzer Exp $
 
   written 1999 by Michael Kropfberger <michael.kropfberger@gmx.net>
   
@@ -391,7 +391,7 @@ void DockWidget::updateDFDone( void )
 
   mPopupMenu->insertItem(
     BarIcon( "help" ),
-    i18n("&Help"), this, SLOT(invokeHTMLHelp()),0);
+    i18n("&Help"), this, SLOT(invokeHelp()),0);
 
   mPopupMenu->insertSeparator();
 
@@ -447,9 +447,9 @@ void DockWidget::settingsBtnClicked( void )
 }
 
 
-void DockWidget::invokeHTMLHelp( void ) 
+void DockWidget::invokeHelp( void ) 
 {
-  kapp->invokeHTMLHelp("kcontrol/kdf/index.html","");
+  kapp->invokeHelp("", "kcontrol/kdf" );
 }
 
 
