@@ -1,6 +1,6 @@
    /*
 
-    $Id: kedit.cpp,v 1.116 2000/05/07 22:06:23 espen Exp $
+    $Id: kedit.cpp,v 1.120 2000/06/08 03:15:48 rwilliam Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -64,6 +64,7 @@
 
 #include <kaction.h>
 #include <kstdaction.h>
+#include <kdebug.h>
 
 QList<TopLevel> TopLevel::windowList;
 
@@ -108,7 +109,7 @@ TopLevel::~TopLevel ()
 QString TopLevel::name()
 {
   if (location.isEmpty())
-     return "[New Document]";
+     return i18n("[New Document]");
   return location;
 }
 
@@ -371,7 +372,7 @@ void TopLevel::spellcheck()
 
   if (kspell) return; // In progress
 
-  statusBar()->changeItem("Spellcheck:  Started.", ID_GENERAL);
+  statusBar()->changeItem(i18n("Spellcheck:  Started."), ID_GENERAL);
 
   kspell = new KSpell(this, i18n("Spellcheck"), this,
 	SLOT( spell_started(KSpell *)), &mOptionState.spell.config);
@@ -756,7 +757,7 @@ void TopLevel::fancyprint(){
 
 void TopLevel::helpselected(){
 
-  kapp->invokeHTMLHelp( "" , "" );
+  kapp->invokeHelp( );
 
 }
 
@@ -1068,7 +1069,7 @@ void TopLevel::print()
 	.arg(command).arg(location);
       setGeneralStatusField(string);
     }
-    //kdebug(0, 0, com.ascii());
+    //kdDebug(0) << com.ascii() << endl;
   }
 }
 
@@ -1309,8 +1310,8 @@ int TopLevel::saveFile( const QString& _url, bool backup )
 
 void TopLevel::openURL( const KURL& _url, int _mode )
 {
-    qDebug("TopLevel::openURL: %s", _url.url().ascii());
     QString netFile = _url.url();
+    kdDebug() << "TopLEvel::openUrl: " << netFile << endl;
     if ( _url.isMalformed() )
     {
         QString string;
