@@ -521,7 +521,7 @@ QString KfindTabWidget::createQuery() {
     str += quote(foo + nameBox->currentText() + "[^/]*$");
   }
 
-  kDebugInfo(1903, "QUERY=%s\n", str.ascii());
+  kdDebug() << "QUERY=" << str.ascii();
 
   return(str);
 }
@@ -680,3 +680,4 @@ static QString quote(const QString str) {
   else
     return '"' + str + '"';
 }
+
