@@ -45,12 +45,13 @@
 #include <stdio.h>
 
 #ifdef HAVE_LINUX_FS_H
-#include <linux/fs.h>
+#include <linux/kdev_t.h>
 #endif
 #include <linux/ext2_fs.h>
 #ifdef HAVE_LINUX_MAJOR_H
 #include <linux/major.h>
 #ifdef SCSI_DISK0_MAJOR
+#undef SCSI_DISK_MAJOR
 #define SCSI_DISK_MAJOR SCSI_DISK0_MAJOR
 #endif
 #endif
