@@ -1,7 +1,7 @@
 
 /*
 
-    $Id: floppy.cpp,v 1.20 2000/04/30 06:53:05 waba Exp $
+    $Id: floppy.cpp,v 1.21 2000/05/24 09:04:49 kulow Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben   
                        wuebben@math.cornell.edu
@@ -872,7 +872,7 @@ void FloppyData::about(){
 
 
 void FloppyData::help(){
-  kapp->invokeHTMLHelp("kfloppy/kfloppy.html","");
+  kapp->invokeHelp( );
 }
 
 
