@@ -77,20 +77,24 @@ CGotoDialog::CGotoDialog( QWidget *parent, const char *name, bool modal )
   mCheckVisible = new QCheckBox( i18n("&Stay visible"), group );
   gbox->addWidget( mCheckVisible, 2, 0 );
   gbox->setRowStretch( 3, 10 );
-  mCheckVisible->setChecked( true );
-  
-  /*
-  int w1 = group->fontMetrics().width( group->title() ) +
-    group->fontMetrics().maxWidth()*2;
-  int w2 = group->sizeHint().width();
-  group->setMinimumWidth( QMAX( w1, w2 ) );
-  */
+
+  KConfig &config = *kapp->config();
+  config.setGroup("Goto Dialog");
+  mCheckFromCursor->setChecked( config.readBoolEntry( "FromCursor", false ) );
+  mCheckVisible->setChecked( config.readBoolEntry( "StayVisible", true ) );
+  mCheckBackward->setChecked( config.readBoolEntry( "Backwards", false ) );
 }
 
 
 
 CGotoDialog::~CGotoDialog( void )
 {
+  KConfig &config = *kapp->config();
+  config.setGroup("Goto Dialog");
+  config.writeEntry( "FromCursor", mCheckFromCursor->isChecked() );
+  config.writeEntry( "StayVisible", mCheckVisible->isChecked() );
+  config.writeEntry( "Backwards", mCheckBackward->isChecked() );
+  config.sync();
 }
 
 
@@ -228,14 +232,30 @@ CFindDialog::CFindDialog( QWidget *parent, const char *name, bool modal )
   gbox->addWidget( mCheckIgnoreCase, 3, 0 );
   gbox->setRowStretch( 4, 10 ); 
 
-  mCheckFromCursor->setChecked( true );
-  mCheckUseNavigator->setChecked( true );
+  KConfig &config = *kapp->config();
+  config.setGroup("Find Dialog");
+  mCheckFromCursor->setChecked( config.readBoolEntry( "FromCursor", true ) );
+  mCheckInSelection->setChecked( config.readBoolEntry( "InSelection", false) );
+  mCheckIgnoreCase->setChecked( config.readBoolEntry( "IgnoreCase", false ) );
+  mCheckBackward->setChecked( config.readBoolEntry( "Backwards", false ) );
+  mCheckUseNavigator->setChecked( config.readBoolEntry( "UseNavigator", true));
+  uint val = config.readUnsignedNumEntry( "Format", 0 );
+  mSelector->setCurrentItem(QMIN(4,val) );
+  selectorChanged( mSelector->currentItem() );
 }
 
 
 CFindDialog::~CFindDialog( void )
 {
-  delete mFindValidator;
+  KConfig &config = *kapp->config();
+  config.setGroup("Find Dialog");
+  config.writeEntry( "FromCursor", mCheckFromCursor->isChecked() );
+  config.writeEntry( "InSelection", mCheckInSelection->isChecked() );
+  config.writeEntry( "IgnoreCase", mCheckIgnoreCase->isChecked() );
+  config.writeEntry( "Backwards", mCheckBackward->isChecked() );
+  config.writeEntry( "UseNavigator", mCheckUseNavigator->isChecked() );
+  config.writeEntry( "Format", mSelector->currentItem() );
+  config.sync();
 }
 
 
@@ -243,7 +263,7 @@ void CFindDialog::selectorChanged( int index )
 {
   mFindValidator->setState( (CHexValidator::EState)index );
   mInput->setText( mFindString[ index ] );
-  mCheckIgnoreCase->setEnabled( index == 0 ? true : false );
+  mCheckIgnoreCase->setEnabled( index == 4 );
 }
 
 
@@ -557,15 +577,34 @@ CReplaceDialog::CReplaceDialog( QWidget *parent, const char *name, bool modal )
   gbox->addWidget( mCheckIgnoreCase, 3, 0 );
   gbox->setRowStretch( 4, 10 ); 
 
-  mCheckFromCursor->setChecked( true );
-  mCheckPrompt->setChecked( true );
+  KConfig &config = *kapp->config();
+  config.setGroup("Replace Dialog");
+  mCheckFromCursor->setChecked( config.readBoolEntry( "FromCursor", true ) );
+  mCheckInSelection->setChecked( config.readBoolEntry( "InSelection", false) );
+  mCheckIgnoreCase->setChecked( config.readBoolEntry( "IgnoreCase", false ) );
+  mCheckBackward->setChecked( config.readBoolEntry( "Backwards", false ) );
+  mCheckPrompt->setChecked( config.readBoolEntry( "Prompt", true));
+  uint val = config.readUnsignedNumEntry( "FindFormat", 0 );
+  mFindSelector->setCurrentItem(QMIN(4,val) );
+  findSelectorChanged( mFindSelector->currentItem() );
+  val = config.readUnsignedNumEntry( "ReplaceFormat", 0 );
+  mReplaceSelector->setCurrentItem(QMIN(4,val) );
+  replaceSelectorChanged( mReplaceSelector->currentItem() );
 }
 
 
 CReplaceDialog::~CReplaceDialog( void )
 {
-  delete mFindValidator;
-  delete mReplaceValidator;
+  KConfig &config = *kapp->config();
+  config.setGroup("Replace Dialog");
+  config.writeEntry( "FromCursor", mCheckFromCursor->isChecked() );
+  config.writeEntry( "InSelection", mCheckInSelection->isChecked() );
+  config.writeEntry( "IgnoreCase", mCheckIgnoreCase->isChecked() );
+  config.writeEntry( "Backwards", mCheckBackward->isChecked() );
+  config.writeEntry( "Prompt", mCheckPrompt->isChecked() );
+  config.writeEntry( "FindFormat", mFindSelector->currentItem() );
+  config.writeEntry( "ReplaceFormat", mReplaceSelector->currentItem() );
+  config.sync();
 }
 
 
@@ -573,7 +612,7 @@ void CReplaceDialog::findSelectorChanged( int index )
 {
   mFindValidator->setState( (CHexValidator::EState)index );
   mFindInput->setText( mFindString[ index ] );
-  mCheckIgnoreCase->setEnabled( index == 0 ? true : false );
+  mCheckIgnoreCase->setEnabled( index == 4 );
 }
 
 
@@ -1121,12 +1160,26 @@ CInsertDialog::CInsertDialog( QWidget *parent, const char *name, bool modal )
   gbox->addWidget( mCheckOnCursor, 2, 0 );
   connect( mCheckOnCursor, SIGNAL(clicked()), SLOT(cursorCheck()) );
   gbox->setRowStretch( 3, 10 ); 
+
+  KConfig &config = *kapp->config();
+  config.setGroup("Insert Pattern Dialog");
+  mCheckPattern->setChecked( config.readBoolEntry( "RepeatPattern", false ) );
+  mCheckOnCursor->setChecked( config.readBoolEntry( "InsertOnCursor", false) );
+  cursorCheck();
+  uint val = config.readUnsignedNumEntry( "Format", 0 );
+  mPatternSelector->setCurrentItem( QMIN(4,val) );
+  patternSelectorChanged( mPatternSelector->currentItem() );  
 }
 
 
 CInsertDialog::~CInsertDialog( void )
 {
-  delete mPatternValidator;
+  KConfig &config = *kapp->config();
+  config.setGroup("Insert Pattern Dialog");
+  config.writeEntry( "RepeatPattern", mCheckPattern->isChecked() );
+  config.writeEntry( "InsertOnCursor", mCheckOnCursor->isChecked() );
+  config.writeEntry( "Format", mPatternSelector->currentItem() );
+  config.sync();
 }
 
 
@@ -1360,10 +1413,11 @@ static const QStringList &formatStrings( void )
   static QStringList list;
   if( list.isEmpty() == true )
   {
-    list.append( i18n( "Regular text" ) );
     list.append( i18n( "Hexadecimal" ) );
+    list.append( i18n( "Decimal" ) );
     list.append( i18n( "Octal" ) );
     list.append( i18n( "Binary" ) );
+    list.append( i18n( "Regular text" ) );
   }
   return( list );
 }
