@@ -28,6 +28,7 @@
 #include <iostream.h>
 #include <time.h>
 
+#include <qbitarray.h> 
 #include <qdatetime.h> 
 #include <qfile.h>
 #include <qfont.h>
@@ -1088,6 +1089,8 @@ class CHexBuffer : public QByteArray
     void setDocumentSize( uint size );
     void setUndoLevel( uint level );
     void setSoundState( bool inputSound, bool fatalSound );
+    void setBookmarkVisibility( bool showInColumn, bool showInEditor ); 
+
     void setFont( const SDisplayFontInfo &fontInfo );
     int  setEncoding( CConversion::EMode mode, CProgress &p );
 
@@ -1136,6 +1139,7 @@ class CHexBuffer : public QByteArray
     bool redo( void );
     int  addBookmark( int position );
     bool removeBookmark( int position );
+    void updateBookmarkMap( bool resize );
 
     int  findFirst( SSearchControl &sc );
     int  findNext( SSearchControl &sc );
@@ -1228,13 +1232,16 @@ class CHexBuffer : public QByteArray
     void cursorReset( void );
  
   private:
+    enum { BookmarkOnLine = 0x01, BookmarkOnCursor = 0x02 };
+
     void computeLineWidth( void );
     void computeNumLines( void );
     void cursorCompute( void );
 
     void drawSelection( QPainter &paint, QColor &color, uint start, uint stop, 
 			int sx );
-    void drawCursor( QPainter &paint, uint line, int startx );
+    int  drawBookmarks(QPainter &paint, uint line, int startx);
+    void drawCursor( QPainter &paint, uint line, int startx, bool onBookmark );
 
     void recordStart( SCursor &cursor );
     void recordReplace( SCursor &cursor, uint size, char *data, uint dataSize);
@@ -1336,10 +1343,14 @@ class CHexBuffer : public QByteArray
     bool mInputErrorSound;
     bool mFatalErrorSound;
 
+    bool mShowBookmarkInOffsetColumn;
+    bool mShowBookmarkInEditor;
+
     uint mUndoLimit;
     uint mUndoIndex;
     QList<CHexActionGroup> mUndoList;
     QList<SCursorOffset> mBookmarkList;
+    QBitArray mBookmarkMap;
 
     PrintCellFunc   printCell;
     PrintOffsetFunc printOffset;
