@@ -23,14 +23,14 @@
 #include <unistd.h>
 
 #undef Unsorted
-#include <qdir.h> 
+#include <qdir.h>
 
 #include <kapp.h>
 #include <kfiledialog.h>
-#include <kglobal.h>
+#include <kglobalsettings.h>
 #include <kio/job.h>
 #include <klocale.h>
-#include <kmessagebox.h> 
+#include <kmessagebox.h>
 #include <kurl.h>
 
 #include "chartabledialog.h"
@@ -61,7 +61,7 @@ CHexEditorWidget::CHexEditorWidget( QWidget *parent, const char *name )
   if( mHexView == 0 || mHexView->widgetValid() == false ) { return; }
 
   connect( mHexView, SIGNAL(pleaseOpenNewFile()), SLOT( newFile()) );
-  connect( mHexView, SIGNAL(pleaseOpenFile( const QString&, bool, uint )), 
+  connect( mHexView, SIGNAL(pleaseOpenFile( const QString&, bool, uint )),
 	   SLOT( open(const QString&, bool, uint)) );
   connect( mHexView, SIGNAL(pleaseStepFile(bool)), SLOT( stepFile(bool)) );
   connect( kapp, SIGNAL( kdisplayFontChanged() ), SLOT( fontChanged() ) );
@@ -73,7 +73,7 @@ CHexEditorWidget::CHexEditorWidget( QWidget *parent, const char *name )
 
   mHexView->setFocus();
   setBackgroundColor( palette().normal().base() );
-   
+
   mProgressBusy    = false;
   mGotoDialog      = 0;
   mFindDialog      = 0;
@@ -114,7 +114,7 @@ CHexEditorWidget::~CHexEditorWidget( void )
 void CHexEditorWidget::initialize( void )
 {
   setColor( mDisplayState.color );
-  setFont( mDisplayState.font ); 
+  setFont( mDisplayState.font );
   mHexView->setMisc( mDisplayState.misc );
   mHexView->setCursor( mDisplayState.cursor, false );
   mHexView->setLayout( mDisplayState.layout );
@@ -178,6 +178,8 @@ void CHexEditorWidget::writeConfiguration( KConfig &config )
   config.writeEntry( "CursorBg",             color.cursorBg );
   config.writeEntry( "CursorFg",             color.cursorFg );
   config.writeEntry( "GridFg",               color.gridFg );
+  config.writeEntry( "BookmarkBg",           color.bookmarkBg );
+  config.writeEntry( "BookmarkFg",           color.bookmarkFg );
 
   SDisplayFont &font = mDisplayState.font;
   config.setGroup( "Display Font" );
@@ -210,12 +212,14 @@ void CHexEditorWidget::writeConfiguration( KConfig &config )
   config.writeEntry( "DiscardRecent",        misc.discardRecent );
   config.writeEntry( "GotoOnStartup",        misc.gotoOnStartup );
   config.writeEntry( "GotoOnReload",         misc.gotoOnReload );
+  config.writeEntry( "ShowBookmarkInOffsetColumn", misc.bookmarkOffsetColumn );
+  config.writeEntry( "ShowBookmarkInEditor", misc.bookmarkEditor );
 
   if( mPrintDialog != 0 )
   {
     mPrintDialog->writeConfiguration();
   }
-  
+
   if( mExportDialog != 0 )
   {
     mExportDialog->writeConfiguration();
@@ -229,31 +233,31 @@ void CHexEditorWidget::readConfiguration( KConfig &config )
   layout.setPrimaryMode( config.readEntry("PrimaryMode") );
   layout.setSecondaryMode( config.readEntry("SecondaryMode") );
   layout.setOffsetMode( config.readEntry("OffsetMode") );
-  layout.offsetVisible = config.readBoolEntry( 
+  layout.offsetVisible = config.readBoolEntry(
     "OffsetVisible", layout.offsetVisible );
-  layout.primaryUpperCase = config.readBoolEntry( 
+  layout.primaryUpperCase = config.readBoolEntry(
     "PrimaryUpperCase", layout.primaryUpperCase );
-  layout.offsetUpperCase = config.readBoolEntry( 
+  layout.offsetUpperCase = config.readBoolEntry(
     "OffsetUpperCase", layout.offsetUpperCase );
-  layout.lineSize = config.readNumEntry( 
+  layout.lineSize = config.readNumEntry(
     "LineSize", layout.lineSize );
   layout.columnSize = config.readNumEntry(
     "ColumnSize", layout.columnSize );
   layout.lockLine = config.readBoolEntry(
     "LockLine", layout.lockLine );
-  layout.lockColumn = config.readBoolEntry( 
+  layout.lockColumn = config.readBoolEntry(
     "LockColumn", layout.lockColumn );
-  layout.columnCharSpace = config.readBoolEntry( 
+  layout.columnCharSpace = config.readBoolEntry(
     "ColumnCharSpace", layout.columnCharSpace );
-  layout.columnSpacing = config.readNumEntry( 
+  layout.columnSpacing = config.readNumEntry(
     "ColumnSpacing", layout.columnSpacing );
-  layout.separatorMarginWidth = config.readNumEntry( 
+  layout.separatorMarginWidth = config.readNumEntry(
     "SeparatorMarginWidth", layout.separatorMarginWidth );
-  layout.edgeMarginWidth = config.readNumEntry( 
+  layout.edgeMarginWidth = config.readNumEntry(
     "EdgeMarginWidth", layout.edgeMarginWidth );
-  layout.leftSeparatorWidth = config.readNumEntry( 
+  layout.leftSeparatorWidth = config.readNumEntry(
     "LeftSeparatorWidth", layout.leftSeparatorWidth );
-  layout.rightSeparatorWidth = config.readNumEntry( 
+  layout.rightSeparatorWidth = config.readNumEntry(
     "RightSeparatorWidth", layout.rightSeparatorWidth );
   layout.setGridMode( config.readEntry("GridMode") );
 
@@ -283,93 +287,101 @@ void CHexEditorWidget::readConfiguration( KConfig &config )
 
   SDisplayFont &font = mDisplayState.font;
   config.setGroup( "Display Font" );
-  font.useSystemFont = config.readBoolEntry( 
+  font.useSystemFont = config.readBoolEntry(
     "UseSystemFont", font.useSystemFont );
-  font.localFont = config.readFontEntry( 
+  font.localFont = config.readFontEntry(
     "LocalFont", &font.localFont );
-  font.nonPrintChar = config.readNumEntry( 
+  font.nonPrintChar = config.readNumEntry(
     "NonPrintChar", font.nonPrintChar );
 
   SDisplayColor &color = mDisplayState.color;
   config.setGroup( "Display Colors" );
-  color.useSystemColor = config.readBoolEntry( 
+  color.useSystemColor = config.readBoolEntry(
     "UseSystemColor", color.useSystemColor );
-  color.textBg = config.readColorEntry( 
+  color.textBg = config.readColorEntry(
     "TextBg", &color.textBg );
-  color.secondTextBg = config.readColorEntry( 
+  color.secondTextBg = config.readColorEntry(
     "SecondTextBg", &color.secondTextBg );
-  color.offsetBg = config.readColorEntry( 
+  color.offsetBg = config.readColorEntry(
     "OffsetBg", &color.offsetBg );
-  color.inactiveBg = config.readColorEntry( 
+  color.inactiveBg = config.readColorEntry(
     "InactiveBg", &color.inactiveBg );
   color.primaryFg[0] = config.readColorEntry(
     "PrimaryFg1", &color.primaryFg[0] );
-  color.primaryFg[1] = config.readColorEntry( 
+  color.primaryFg[1] = config.readColorEntry(
     "PrimaryFg2", &color.primaryFg[1] );
-  color.offsetFg = config.readColorEntry( 
+  color.offsetFg = config.readColorEntry(
     "OffsetFg", &color.offsetFg );
   color.secondaryFg = config.readColorEntry(
     "SecondaryFg", &color.secondaryFg );
   color.markBg = config.readColorEntry(
     "MarkBg", &color.markBg );
-  color.markFg = config.readColorEntry( 
+  color.markFg = config.readColorEntry(
     "MarkFg", &color.markFg );
-  color.cursorBg = config.readColorEntry( 
+  color.cursorBg = config.readColorEntry(
     "CursorBg", &color.cursorBg );
-  color.cursorFg = config.readColorEntry( 
+  color.cursorFg = config.readColorEntry(
     "CursorFg", &color.cursorFg );
-  color.leftSeparatorFg = config.readColorEntry( 
+  color.leftSeparatorFg = config.readColorEntry(
     "LeftSeparatorFg", &color.leftSeparatorFg );
-  color.rightSeparatorFg = config.readColorEntry( 
+  color.rightSeparatorFg = config.readColorEntry(
     "RightSeparatorFg", &color.rightSeparatorFg );
-  color.nonPrintFg = config.readColorEntry( 
+  color.nonPrintFg = config.readColorEntry(
     "NonPrintFg", &color.nonPrintFg );
-  color.gridFg = config.readColorEntry( 
+  color.gridFg = config.readColorEntry(
     "GridFg", &color.gridFg );
+  color.bookmarkBg = config.readColorEntry(
+    "BookmarkBg", &color.bookmarkBg );
+  color.bookmarkFg = config.readColorEntry(
+    "BookmarkFg", &color.bookmarkFg );
 
   SDisplayCursor &cursor = mDisplayState.cursor;
   config.setGroup( "Display Cursor" );
-  cursor.alwaysVisible = config.readBoolEntry( 
+  cursor.alwaysVisible = config.readBoolEntry(
     "NeverBlink", cursor.alwaysVisible );
-  cursor.alwaysBlockShape = config.readBoolEntry( 
+  cursor.alwaysBlockShape = config.readBoolEntry(
     "AlwaysBlockShape", cursor.alwaysBlockShape );
-  cursor.thickInsertShape = config.readBoolEntry( 
+  cursor.thickInsertShape = config.readBoolEntry(
     "ThickInsertShape", cursor.thickInsertShape );
   cursor.setFocusMode( config.readEntry("FocusMode") );
-  cursor.interval = config.readNumEntry( 
+  cursor.interval = config.readNumEntry(
     "Interval", cursor.interval );
 
   SDisplayMisc &misc = mDisplayState.misc;
   config.setGroup( "Display Misc" );
-  misc.undoLevel = config.readNumEntry( 
+  misc.undoLevel = config.readNumEntry(
     "UndoLevel", misc.undoLevel );
   misc.setOpenFile( config.readEntry("OpenFile") );
-  misc.inputSound = config.readBoolEntry( 
+  misc.inputSound = config.readBoolEntry(
     "InputSound", misc.inputSound );
-  misc.fatalSound = config.readBoolEntry( 
+  misc.fatalSound = config.readBoolEntry(
     "FatalSound", misc.fatalSound );
-  misc.autoCopyToClipboard = config.readBoolEntry( 
+  misc.autoCopyToClipboard = config.readBoolEntry(
     "AutoCopyToClipboard", misc.autoCopyToClipboard );
-  misc.insertMode = config.readBoolEntry( 
+  misc.insertMode = config.readBoolEntry(
     "InsertMode", misc.insertMode );
-  misc.writeProtect = config.readBoolEntry( 
+  misc.writeProtect = config.readBoolEntry(
     "WriteProtect", misc.writeProtect );
-  misc.confirmWrap = config.readBoolEntry( 
+  misc.confirmWrap = config.readBoolEntry(
     "ConfirmWrap", misc.confirmWrap );
-  misc.cursorJump = config.readBoolEntry( 
+  misc.cursorJump = config.readBoolEntry(
     "CursorJump", misc.cursorJump );
-  misc.makeBackup = config.readBoolEntry( 
+  misc.makeBackup = config.readBoolEntry(
     "MakeBackup", misc.makeBackup );
-  misc.confirmThreshold = config.readBoolEntry( 
+  misc.confirmThreshold = config.readBoolEntry(
     "ConfirmThreshold", misc.confirmThreshold );
-  misc.thresholdValue = config.readNumEntry( 
+  misc.thresholdValue = config.readNumEntry(
     "ThresholdValue", misc.thresholdValue );
-  misc.discardRecent = config.readBoolEntry( 
+  misc.discardRecent = config.readBoolEntry(
     "DiscardRecent", misc.discardRecent );
-  misc.gotoOnStartup = config.readBoolEntry( 
+  misc.gotoOnStartup = config.readBoolEntry(
     "GotoOnStartup", misc.gotoOnStartup );
-  misc.gotoOnReload = config.readBoolEntry( 
+  misc.gotoOnReload = config.readBoolEntry(
     "GotoOnReload", misc.gotoOnReload );
+  misc.bookmarkOffsetColumn = config.readBoolEntry(
+    "ShowBookmarkInOffsetColumn", misc.bookmarkOffsetColumn );
+  misc.bookmarkEditor = config.readBoolEntry(
+    "ShowBookmarkInEditor", misc.bookmarkEditor );
 }
 
 
@@ -434,7 +446,7 @@ void CHexEditorWidget::setLayout( const SDisplayLayout &layout )
 
   mHexView->setLayout( mDisplayState.layout );
 }
-  
+
 void CHexEditorWidget::setCursor( const SDisplayCursor &cursor )
 {
   mDisplayState.cursor = cursor;
@@ -446,7 +458,7 @@ void CHexEditorWidget::setColor( const SDisplayColor &color )
   mDisplayState.color = color;
 
   //
-  // The selection colors can not be chosen. 
+  // The selection colors can not be chosen.
   //
   mDisplayState.color.selectBg = kapp->palette().normal().highlight();
   mDisplayState.color.selectFg = kapp->palette().normal().highlightedText();
@@ -468,11 +480,15 @@ void CHexEditorWidget::setColor( const SDisplayColor &color )
     c.cursorBg         = kapp->palette().normal().text();
     c.cursorFg         = kapp->palette().normal().base();
     c.gridFg           = kapp->palette().normal().text();
-    mHexView->setColor( c, true ); 
+    SDisplayColor defaultColor;
+    c.bookmarkBg       = defaultColor.bookmarkBg;
+    c.bookmarkFg       = defaultColor.bookmarkFg;
+
+    mHexView->setColor( c, true );
   }
   else
   {
-    mHexView->setColor( mDisplayState.color, true ); 
+    mHexView->setColor( mDisplayState.color, true );
   }
 }
 
@@ -484,7 +500,7 @@ void CHexEditorWidget::setFont( const SDisplayFont &font )
   SDisplayFontInfo fontInfo;
   if( mDisplayState.font.useSystemFont == true )
   {
-    fontInfo.font = KGlobal::fixedFont();
+    fontInfo.font = KGlobalSettings::fixedFont();
   }
   else
   {
@@ -561,7 +577,7 @@ void CHexEditorWidget::saveWorkingDirectory( const QString &url )
     mWorkDir = url.left( index+1 );
   }
 }
-  
+
 
 
 void CHexEditorWidget::newFile( void )
@@ -572,17 +588,17 @@ void CHexEditorWidget::newFile( void )
   }
 
   QString url = i18n("Untitled %1").arg( mUntitledCount );
-  
+
   //
-  // If the url is already present in the document list (should not happen), 
-  // then this document is "raised". 
+  // If the url is already present in the document list (should not happen),
+  // then this document is "raised".
   //
   bool success = selectDocument( url, false );
   if( success == true )
   {
     return;
   }
-  
+
   //
   // Prepare a new buffer we can load the document into
   //
@@ -596,7 +612,7 @@ void CHexEditorWidget::newFile( void )
   if( errCode != Err_Success )
   {
     QString msg = i18n("Unable to create new document.");
-    KMessageBox::sorry( topLevelWidget(), msg, i18n("Operation failed") ); 
+    KMessageBox::sorry( topLevelWidget(), msg, i18n("Operation failed") );
     return;
   }
 
@@ -618,12 +634,12 @@ void CHexEditorWidget::newFile( const QByteArray &data )
 void CHexEditorWidget::open()
 {
   KURL file = KFileDialog::getOpenURL( mWorkDir, "*" ,topLevelWidget() );
-  
+
   if( file.isEmpty() )
     return;
-  
+
   QString url = file.url();
-  
+
   saveWorkingDirectory( url );
 
   if( busy( true ) )
@@ -631,7 +647,7 @@ void CHexEditorWidget::open()
 
   //
   // If the url is already present in the document list, then this
-  // document is "raised". 
+  // document is "raised".
   //
   if( selectDocument( url, true ) )
     return;
@@ -647,7 +663,7 @@ void CHexEditorWidget::open()
   {
     emit errorLoadFile( url );
     removeBuffer();
-  }  
+  }
   else if( errCode == Err_Success )
   {
     defaultWriteProtection();
@@ -666,14 +682,14 @@ void CHexEditorWidget::open( const QString &url, bool reloadWhenChanged,
 
   //
   // If the url is already present in the document list, then this
-  // document is "raised". 
+  // document is "raised".
   //
   bool success = selectDocument( url, reloadWhenChanged );
   if( success == true )
   {
     return;
   }
-  
+
   //
   // Prepare a new buffer we can load the document into
   //
@@ -700,7 +716,7 @@ void CHexEditorWidget::open( const QString &url, bool reloadWhenChanged,
 void CHexEditorWidget::stepFile( bool next )
 {
   //
-  // The buffer list is is reverse when compared with the visible 
+  // The buffer list is is reverse when compared with the visible
   // document list in the menu so I toggle the flag.
   //
   next = next == true ? false : true;
@@ -730,7 +746,7 @@ bool CHexEditorWidget::isOpen( const QString &url, uint &offset )
 }
 
 
-bool CHexEditorWidget::selectDocument( const QString &url, 
+bool CHexEditorWidget::selectDocument( const QString &url,
 				       bool reloadWhenChanged )
 {
   CHexBuffer *hexBuffer = documentItem( url );
@@ -756,7 +772,7 @@ bool CHexEditorWidget::selectDocument( const QString &url,
 void CHexEditorWidget::insertFile( void )
 {
   KURL file = KFileDialog::getOpenURL( mWorkDir, "*", topLevelWidget());
-  
+
   if( file.isEmpty() )
     return;
 
@@ -767,7 +783,7 @@ void CHexEditorWidget::insertFile( void )
   }
 
   QString url = file.path();
-  
+
   saveWorkingDirectory( url );
 
   if( busy( true ) )
@@ -910,7 +926,7 @@ bool CHexEditorWidget::save( void )
 
   if( mHexView->urlValid() == false )
   {
-    saveAs();
+    return( saveAs() );
   }
   else
   {
@@ -932,41 +948,47 @@ bool CHexEditorWidget::save( void )
     {
       backup();
     }
-    writeURL( mHexView->url() ); 
+    writeURL( mHexView->url() );
   }
 
   return( true );
 }
 
 
-void CHexEditorWidget::saveAs( void )
-{ 
+//
+// Returns false if operation was canceled
+//
+bool CHexEditorWidget::saveAs( void )
+{
   if( mHexView->documentPresent() == false )
   {
-    return;
+    return( true );
   }
 
   KURL url;
   while( 1 )
   {
     url = KFileDialog::getSaveURL( mHexView->url(), "*", this );
-    
-    if( url.isEmpty() )
-      return;
-    
-    saveWorkingDirectory( url.url() );
+    if( url.isEmpty() == true )
+    {
+      return( false );
+    }
+    else
+    {
+      saveWorkingDirectory( url.url() );
+    }
 
-    if( url.isLocalFile() ) 
+    if( url.isLocalFile() )
     {
       QString name( url.path() );
       QFileInfo info( name );
 
-      if( info.exists() ) 
+      if( info.exists() )
       {
 	QString msg = i18n(""
           "A document with this name already exists.\n"
           "Do you want to overwrite it?" );
-	int reply = KMessageBox::warningYesNo( topLevelWidget(), msg, 
+	int reply = KMessageBox::warningYesNo( topLevelWidget(), msg,
 					       i18n("Save As") );
 	if( reply == KMessageBox::Yes )
 	  break;
@@ -974,13 +996,14 @@ void CHexEditorWidget::saveAs( void )
       else
 	break;
     }
-  } 
+  }
 
   QString symbolicName( url.url() );
-  KURL::decode( symbolicName );
+//  KURL::decode( symbolicName );
 
   mHexView->setUrl( symbolicName );
-  writeURL( mHexView->url() ); 
+  writeURL( mHexView->url() );
+  return( true );
 }
 
 
@@ -1017,7 +1040,7 @@ void CHexEditorWidget::reload( void )
     {
       msg += i18n( "Current document contains unsaved modifications.\n" );
     }
-    
+
     msg += i18n(""
       "If you reload now, the modifications will be lost.\n"
       "Proceed?" );
@@ -1066,7 +1089,7 @@ void CHexEditorWidget::printPostscript( CHexPrinter &printer )
   }
 
   //
-  // No i18n() on this one! 
+  // No i18n() on this one!
   // Constants come from config.h
   //
   QString creator( PACKAGE );
@@ -1080,13 +1103,13 @@ void CHexEditorWidget::printPostscript( CHexPrinter &printer )
   {
     errCode = mHexView->print( printer, mProgressData );
   }
- 
+
   QString msg = i18n("Could not print data.\n");
   msg += hexError( errCode );
 
   if( errCode != Err_Success )
   {
-    KMessageBox::sorry( topLevelWidget(), msg, i18n("Print") ); 
+    KMessageBox::sorry( topLevelWidget(), msg, i18n("Print") );
   }
 }
 
@@ -1132,7 +1155,7 @@ void CHexEditorWidget::printText( CHexPrinter &printer )
   {
     errCode = mHexView->exportText( ex, mProgressData );
   }
- 
+
   if( errCode != Err_Success )
   {
     QString msg = i18n("Unable to write data.\n");
@@ -1150,7 +1173,7 @@ bool CHexEditorWidget::confirmPrintPageNumber( CHexPrinter &printer )
     uint numPage = mHexView->numPage( printer );
     if( numPage > mDisplayState.misc.thresholdValue )
     {
-      QString msg = i18n( 
+      QString msg = i18n(
         "Print threshold excceded.\n"
         "You are about to print %1 pages.\n"
 	"Procceed?").arg( numPage );
@@ -1192,7 +1215,7 @@ void CHexEditorWidget::exportText( const SExportText &ex )
   {
     errCode = mHexView->exportText( ex, mProgressData );
   }
- 
+
   if( errCode != Err_Success )
   {
     QString msg = i18n("Unable to export data.\n");
@@ -1209,7 +1232,7 @@ void CHexEditorWidget::exportHtml( const SExportHtml &ex )
   {
     errCode = mHexView->exportHtml( ex, mProgressData );
   }
- 
+
   if( errCode != Err_Success )
   {
     QString msg = i18n("Unable to export data.\n");
@@ -1226,7 +1249,7 @@ void CHexEditorWidget::exportCArray( const SExportCArray &ex )
   {
     errCode = mHexView->exportCArray( ex, mProgressData );
   }
- 
+
   if( errCode != Err_Success )
   {
     QString msg = i18n("Unable to export data.\n");
@@ -1281,14 +1304,14 @@ void CHexEditorWidget::redo( void )
 
 void CHexEditorWidget::toggleWriteProtection( void )
 {
-  mDisplayState.input.readOnly = mDisplayState.input.readOnly == true ? 
+  mDisplayState.input.readOnly = mDisplayState.input.readOnly == true ?
     false : true;
   mHexView->setInputMode( mDisplayState.input );
 }
 
 void CHexEditorWidget::defaultWriteProtection( void )
 {
-  mDisplayState.input.readOnly = mDisplayState.misc.writeProtect; 
+  mDisplayState.input.readOnly = mDisplayState.misc.writeProtect;
   mHexView->setInputMode( mDisplayState.input );
 }
 
@@ -1319,14 +1342,14 @@ void CHexEditorWidget::toggleOffsetColumnVisibility( void )
 
 void CHexEditorWidget::toggleTextColumnVisibility( void )
 {
-  layout().secondaryMode = layout().secondaryMode == SDisplayLayout::hide ? 
+  layout().secondaryMode = layout().secondaryMode == SDisplayLayout::hide ?
     SDisplayLayout::textOnly : SDisplayLayout::hide;
   mHexView->setLayout( layout() );
 }
 
 void CHexEditorWidget::toggleOffsetAsDecimal( void )
 {
-  layout().offsetMode = layout().offsetMode == SDisplayLayout::hexadecimal ? 
+  layout().offsetMode = layout().offsetMode == SDisplayLayout::hexadecimal ?
     SDisplayLayout::decimal : SDisplayLayout::hexadecimal;
   mHexView->setLayout( layout() );
 }
@@ -1404,7 +1427,7 @@ void CHexEditorWidget::removeBookmark( void )
   {
     mHexView->removeBookmark( false );
   }
-}      
+}
 
 
 void CHexEditorWidget::removeAllBookmark( void )
@@ -1412,7 +1435,7 @@ void CHexEditorWidget::removeAllBookmark( void )
   if( mHexView->bookmarkCount() > 0 )
   {
     QString msg = i18n(""
-      "Deleted bookmarks can not be restored.\n" 
+      "Deleted bookmarks can not be restored.\n"
       "Proceed?" );
     int reply = KMessageBox::warningYesNo( topLevelWidget(), msg );
     if( reply != KMessageBox::Yes )
@@ -1427,14 +1450,23 @@ void CHexEditorWidget::removeAllBookmark( void )
 void CHexEditorWidget::replaceBookmark( void )
 {
   mHexView->replaceBookmark();
-}      
+}
 
 
 void CHexEditorWidget::gotoBookmark( int position )
 {
   mHexView->gotoBookmark( (uint)position );
-}   
+}
 
+void CHexEditorWidget::gotoNextBookmark( void )
+{
+  mHexView->gotoNextBookmark(true);
+}
+
+void CHexEditorWidget::gotoPrevBookmark( void )
+{
+  mHexView->gotoNextBookmark(false);
+}
 
 void CHexEditorWidget::gotoOffset( void )
 {
@@ -1442,7 +1474,7 @@ void CHexEditorWidget::gotoOffset( void )
   {
     mGotoDialog = new CGotoDialog( topLevelWidget(), 0, false );
     if( mGotoDialog == 0 ) { return; }
-    connect( mGotoDialog, SIGNAL(gotoOffset( uint, uint, bool, bool )), 
+    connect( mGotoDialog, SIGNAL(gotoOffset( uint, uint, bool, bool )),
 	     mHexView, SLOT(gotoOffset( uint, uint, bool, bool )) );
   }
   mGotoDialog->show();
@@ -1460,7 +1492,7 @@ void CHexEditorWidget::find( void )
   {
     mFindDialog = new CFindDialog( topLevelWidget(), 0, false );
     if( mFindDialog == 0 ) { return; }
-    connect( mFindDialog, 
+    connect( mFindDialog,
 	     SIGNAL(findData(SSearchControl &, uint, bool)),
 	     SLOT(findData(SSearchControl &, uint, bool)) );
   }
@@ -1510,7 +1542,7 @@ void CHexEditorWidget::findData( SSearchControl &sc, uint mode, bool navigator)
       {
 	return;
       }
-      
+
       sc.fromCursor = false;
       mode = Find_First;
     }
@@ -1572,7 +1604,7 @@ bool CHexEditorWidget::askWrap( bool fwd, const QString &header )
       "Beginning of document reached.\n"
       "Continue from the end?" );
   }
- 
+
   int reply = KMessageBox::questionYesNo( topLevelWidget(), msg, header );
   return( reply == KMessageBox::Yes ? true : false );
 }
@@ -1608,10 +1640,10 @@ void CHexEditorWidget::findNavigator( SSearchControl &sc )
   {
     mFindNavigatorDialog = new CFindNavigatorDialog(topLevelWidget(),0,false);
     if( mFindNavigatorDialog == 0 ) { return; }
-    connect( mFindNavigatorDialog, 
+    connect( mFindNavigatorDialog,
 	     SIGNAL(findData(SSearchControl &, uint, bool)),
 	     SLOT(findData(SSearchControl &, uint, bool)) );
-    connect( mFindNavigatorDialog, SIGNAL(makeKey(void)), 
+    connect( mFindNavigatorDialog, SIGNAL(makeKey(void)),
 	     SLOT(find()) );
   }
   if( mFindNavigatorDialog->isVisible() == false )
@@ -1631,7 +1663,7 @@ void CHexEditorWidget::replace( void )
   {
     mReplaceDialog = new CReplaceDialog( topLevelWidget(), 0, false );
     if( mReplaceDialog == 0 ) { return; }
-    connect( mReplaceDialog, 
+    connect( mReplaceDialog,
 	     SIGNAL( replaceData( SSearchControl &, uint)),
 	     SLOT( replaceData( SSearchControl &, uint)));
   }
@@ -1701,7 +1733,7 @@ void CHexEditorWidget::replaceData( SSearchControl &sc, uint mode )
     {
       break;
     }
-    
+
     if( mode == Replace_All || mode == Replace_AllInit )
     {
       mode = Replace_All;
@@ -1721,7 +1753,7 @@ void CHexEditorWidget::replacePrompt( SSearchControl &sc )
   {
     mReplacePromptDialog = new CReplacePromptDialog(topLevelWidget(), 0,false);
     if( mReplacePromptDialog == 0 ) { return; }
-    connect( mReplacePromptDialog, 
+    connect( mReplacePromptDialog,
 	     SIGNAL( replaceData( SSearchControl &, uint)),
 	     SLOT( replaceData( SSearchControl &, uint)));
   }
@@ -1786,7 +1818,7 @@ void CHexEditorWidget::insertPattern( void )
   {
     mInsertDialog = new CInsertDialog( topLevelWidget(), 0, false );
     if( mInsertDialog == 0 ) { return; }
-    connect( mInsertDialog, SIGNAL(execute( SInsertData & )), 
+    connect( mInsertDialog, SIGNAL(execute( SInsertData & )),
 	     mHexView, SLOT(insert( SInsertData & )) );
   }
   mInsertDialog->show();
@@ -1798,7 +1830,7 @@ void CHexEditorWidget::encoding( void )
   QString msg = i18n(""
     "Not available yet!\n"
     "Define your own encoding" );
-  KMessageBox::sorry( topLevelWidget(), msg, i18n("Encoding") ); 
+  KMessageBox::sorry( topLevelWidget(), msg, i18n("Encoding") );
 }
 
 
@@ -1808,10 +1840,10 @@ void CHexEditorWidget::strings( void )
   {
     mStringDialog = new CStringDialog( topLevelWidget(), 0, false );
     if( mStringDialog == 0 ) { return; }
-    connect( mStringDialog, SIGNAL(markText( uint, uint, bool )), 
+    connect( mStringDialog, SIGNAL(markText( uint, uint, bool )),
 	     mHexView, SLOT(setMark( uint, uint, bool )) );
     connect( mStringDialog, SIGNAL(collect()), SLOT(collectStrings()) );
-    connect( mHexView, SIGNAL(fileName( const QString &, bool ) ), 
+    connect( mHexView, SIGNAL(fileName( const QString &, bool ) ),
 	     mStringDialog, SLOT( removeList() ) );
     connect( mHexView, SIGNAL(dataChanged()),
 	     mStringDialog, SLOT(setDirty()) );
@@ -1826,7 +1858,7 @@ void CHexEditorWidget::collectStrings( void )
   if( errCode == Err_Success )
   {
     mHexView->collectStrings( mStringDialog->stringData() );
-    errCode = mStringDialog->updateList( mProgressData ); 
+    errCode = mStringDialog->updateList( mProgressData );
   }
 
   if( errCode != Err_Success && errCode != Err_Stop )
@@ -1843,7 +1875,7 @@ void CHexEditorWidget::collectStrings( void )
 void CHexEditorWidget::recordView( void )
 {
   QString msg = i18n(""
-   "Not available yet!\n"     
+   "Not available yet!\n"
    "Define a record (structure) and fill it with data from document" );
   KMessageBox::sorry( topLevelWidget(), msg, i18n("Record viewer") );
 }
@@ -1854,7 +1886,7 @@ void CHexEditorWidget::filter( void )
   {
     mFilterDialog = new CFilterDialog( topLevelWidget(), 0, false );
     if( mFilterDialog == 0 ) { return; }
-    connect( mFilterDialog, SIGNAL(filterData( SFilterControl & )), 
+    connect( mFilterDialog, SIGNAL(filterData( SFilterControl & )),
 	     mHexView, SLOT(filter( SFilterControl & )) );
   }
   mFilterDialog->show();
@@ -1867,7 +1899,7 @@ void CHexEditorWidget::chart( void )
   {
     mCharTableDialog = new CCharTableDialog( topLevelWidget(), 0, false );
     if( mCharTableDialog == 0 ) { return; }
-    connect( mCharTableDialog, SIGNAL(assign( const QByteArray & )), 
+    connect( mCharTableDialog, SIGNAL(assign( const QByteArray & )),
 	     mHexView, SLOT(insert( const QByteArray & )) );
   }
   mCharTableDialog->show();
@@ -1884,7 +1916,7 @@ void CHexEditorWidget::converter( void )
   }
   mConverterDialog->show();
 }
-  
+
 
 void CHexEditorWidget::statistics( void )
 {
@@ -1892,7 +1924,7 @@ void CHexEditorWidget::statistics( void )
   {
     mFileInfoDialog = new CFileInfoDialog( topLevelWidget(), 0, false );
     if( mFileInfoDialog == 0 ) { return; }
-    connect( mFileInfoDialog, SIGNAL(collectStatistic(SStatisticControl &)), 
+    connect( mFileInfoDialog, SIGNAL(collectStatistic(SStatisticControl &)),
 	     SLOT(collectStatistics(SStatisticControl &)));
     connect( mHexView, SIGNAL(dataChanged()),
 	     mFileInfoDialog, SLOT(setDirty()) );
@@ -1919,10 +1951,10 @@ void CHexEditorWidget::collectStatistics( SStatisticControl &sc )
 
     QString msg = i18n("Could not collect document statistics.\n");
     msg += hexError( errCode );
-    KMessageBox::sorry( topLevelWidget(), msg, 
+    KMessageBox::sorry( topLevelWidget(), msg,
 			i18n("Collect document statistics") );
   }
-  
+
 }
 
 
@@ -2008,7 +2040,7 @@ int CHexEditorWidget::readURL( const QString &url, bool insert )
   if( kurl.isLocalFile() == true )
   {
     QString symbolicName( kurl.url() );
-    KURL::decode( symbolicName );
+//    KURL::decode( symbolicName );
 
     bool success = readFile( kurl.path(), symbolicName, insert );
     return( success == true ? Err_Success : Err_ReadFailed );
@@ -2037,15 +2069,15 @@ int CHexEditorWidget::readURL( const QString &url, bool insert )
 }
 
 
-void CHexEditorWidget::writeURL( QString &url ) 
+void CHexEditorWidget::writeURL( QString &url )
 {
   KURL kurl( url );
   if( kurl.isLocalFile() == true )
   {
     QString path( kurl.path() );
     writeFile( path );
-  } 
-  else 
+  }
+  else
   {
     QString tmpFileName = createTemporaryFileName();
     KIO::Job *job = KIO::copy( tmpFileName, kurl );
@@ -2057,7 +2089,7 @@ void CHexEditorWidget::writeURL( QString &url )
       return;
     }
     //job->setGUImode ( KIOJob::NONE );
-    
+
     mKioRemote.insert( job, new QString(kurl.url()) );
     mKioLocal.insert( job, new QString(tmpFileName) );
 
@@ -2078,7 +2110,7 @@ void CHexEditorWidget::kioReadFinished( KIO::Job * job )
   if( tmpFileName != 0 && url != 0 && insert != 0 )
   {
     QString symbolicName( *url );
-    KURL::decode( symbolicName );
+//    KURL::decode( symbolicName );
     bool success = !job->error() &&
               readFile( *tmpFileName, symbolicName, *insert );
     if( success == true )
@@ -2104,7 +2136,7 @@ void CHexEditorWidget::kioReadFinished( KIO::Job * job )
   }
   mKioRemote.remove( job );
   mKioLocal.remove( job );
-  mKioFlag.remove( job ); 
+  mKioFlag.remove( job );
 }
 
 
@@ -2120,7 +2152,7 @@ void CHexEditorWidget::kioWriteFinished( KIO::Job * job )
   }
   mKioRemote.remove( job );
   mKioLocal.remove( job );
-  mKioFlag.remove( job ); 
+  mKioFlag.remove( job );
 }
 
 
@@ -2130,7 +2162,7 @@ QString CHexEditorWidget::createTemporaryFileName( void )
 }
 
 
-bool CHexEditorWidget::modifiedByAlien( const QString &url ) 
+bool CHexEditorWidget::modifiedByAlien( const QString &url )
 {
   KURL kurl( url );
   if( kurl.isLocalFile() == false )
@@ -2143,7 +2175,7 @@ bool CHexEditorWidget::modifiedByAlien( const QString &url )
   {
     return( false );
   }
-  
+
   if( fileInfo.lastModified() == mHexView->diskModifyTime() )
   {
     return( false );
@@ -2155,7 +2187,7 @@ bool CHexEditorWidget::modifiedByAlien( const QString &url )
 
 
 bool CHexEditorWidget::readFile( const QString &diskPath, const QString &url,
-				 bool insert ) 
+				 bool insert )
 {
 
   QFileInfo info( diskPath );
@@ -2167,7 +2199,7 @@ bool CHexEditorWidget::readFile( const QString &diskPath, const QString &url,
     return( false );
   }
 
-  if( info.isDir() == true ) 
+  if( info.isDir() == true )
   {
     QString msg = i18n("You have specified a directory.");
     msg += "\n" + diskPath;
@@ -2175,7 +2207,7 @@ bool CHexEditorWidget::readFile( const QString &diskPath, const QString &url,
     return( false );
   }
 
-  if( info.isReadable() == false ) 
+  if( info.isReadable() == false )
   {
     QString msg = i18n("You do not have read permission to this file.");
     msg += "\n" + diskPath;
@@ -2184,7 +2216,7 @@ bool CHexEditorWidget::readFile( const QString &diskPath, const QString &url,
   }
 
   QFile file( diskPath );
-  if( file.open( IO_ReadOnly | IO_Raw ) == false ) 
+  if( file.open( IO_ReadOnly | IO_Raw ) == false )
   {
     QString msg = i18n("An error occured while trying to open file.");
     msg += "\n" + diskPath;
@@ -2192,16 +2224,16 @@ bool CHexEditorWidget::readFile( const QString &diskPath, const QString &url,
     return( false );
   }
 
-  if( mHexView->documentPresent() == false ) 
-  { 
+  if( mHexView->documentPresent() == false )
+  {
     //
     // Can not insert if there is no document present.
     //
-    insert = false; 
+    insert = false;
   }
 
   int errCode = prepareProgressData( insert == true ? pg_insert: pg_read );
-  if( errCode == Err_Success ) 
+  if( errCode == Err_Success )
   {
     if( insert == true )
     {
@@ -2228,19 +2260,19 @@ bool CHexEditorWidget::readFile( const QString &diskPath, const QString &url,
 
 
 
-bool CHexEditorWidget::writeFile( QString &diskPath ) 
+bool CHexEditorWidget::writeFile( QString &diskPath )
 {
   QFileInfo info( diskPath );
   if( info.exists() == true )
-  { 
-    if( info.isDir() == true ) 
+  {
+    if( info.isDir() == true )
     {
       QString msg = i18n("You have specified a directory.");
       KMessageBox::sorry( topLevelWidget(), msg, i18n("Write failure") );
       return( false );
     }
 
-    if( info.isWritable() == false ) 
+    if( info.isWritable() == false )
     {
       QString msg = i18n("You do not have write permission.");
       KMessageBox::sorry( topLevelWidget(), msg, i18n("Write failure") );
@@ -2249,7 +2281,7 @@ bool CHexEditorWidget::writeFile( QString &diskPath )
   }
 
   QFile file( diskPath );
-  if( file.open( IO_WriteOnly | IO_Raw | IO_Truncate ) == false ) 
+  if( file.open( IO_WriteOnly | IO_Raw | IO_Truncate ) == false )
   {
     QString msg = i18n("An error occured while trying to open file.");
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Write failure") );
@@ -2274,11 +2306,11 @@ bool CHexEditorWidget::writeFile( QString &diskPath )
 
 
 CHexBuffer *CHexEditorWidget::documentItem( const QString &url )
-{ 
+{
   QString symbolicName( url );
-  KURL::decode( symbolicName );
- 
-  for( CHexBuffer *hexBuffer = mDocumentList.first(); hexBuffer != 0; 
+//  KURL::decode( symbolicName );
+
+  for( CHexBuffer *hexBuffer = mDocumentList.first(); hexBuffer != 0;
        hexBuffer = mDocumentList.next() )
   {
     if( hexBuffer->url() == symbolicName )
@@ -2286,20 +2318,20 @@ CHexBuffer *CHexEditorWidget::documentItem( const QString &url )
       return( hexBuffer );
     }
   }
-  
+
   return( 0 );
 }
 
 
 CHexBuffer *CHexEditorWidget::documentItem( const QString &url, bool next )
-{ 
+{
   if( mDocumentList.count() <= 1 )
   {
     return( 0 );
   }
 
   QString symbolicName( url );
-  KURL::decode( symbolicName );
+//  KURL::decode( symbolicName );
 
   if( next == true )
   {
@@ -2325,7 +2357,7 @@ CHexBuffer *CHexEditorWidget::documentItem( const QString &url, bool next )
       }
     }
   }
-  
+
   return( 0 );
 }
 
@@ -2336,21 +2368,21 @@ bool CHexEditorWidget::createBuffer( void )
   if( mHexView->documentPresent() == false )
   {
     //
-    // The document is not valid, i.e. the buffer contains no data 
+    // The document is not valid, i.e. the buffer contains no data
     // so we can use this one without destroying anything.
     //
     return( true );
   }
 
   CHexBuffer *hexBuffer = new CHexBuffer;
-  if( hexBuffer == 0 ) 
-  { 
+  if( hexBuffer == 0 )
+  {
     QString msg = i18n( "Can not create text buffer.\n" );
     msg += hexError( Err_NoMemory );
     KMessageBox::error( topLevelWidget(), msg, i18n("Loading failed" ) );
-    return( false ); 
+    return( false );
   }
-  
+
   mDocumentList.append( hexBuffer );
   mHexView->setBuffer( hexBuffer );
 
@@ -2387,7 +2419,7 @@ void CHexEditorWidget::removeBuffer( void )
 
 bool CHexEditorWidget::modified( void )
 {
-  for( CHexBuffer *hexBuffer = mDocumentList.first(); hexBuffer != 0; 
+  for( CHexBuffer *hexBuffer = mDocumentList.first(); hexBuffer != 0;
        hexBuffer = mDocumentList.next() )
   {
     if( hexBuffer->modified() == true )
@@ -2395,7 +2427,7 @@ bool CHexEditorWidget::modified( void )
       return( true );
     }
   }
-  
+
   return( false );
 }
 
@@ -2420,7 +2452,7 @@ int CHexEditorWidget::prepareProgressData( EProgressMode mode )
   mProgressStop = false;
   enableInputLock( true );
 
-  static QString names[] = 
+  static QString names[] =
   {
     i18n("Reading"),
     i18n("Writing"),
@@ -2516,7 +2548,7 @@ int CHexEditorWidget::progressParse( const SProgressData &pd )
       header = i18n("Collect strings");
       msg = i18n("Do you really want to cancel string scanning?");
     break;
-    
+
     case pg_export:
       header = i18n("Export");
       msg = i18n("Do you really want to cancel exporting?");
@@ -2530,9 +2562,9 @@ int CHexEditorWidget::progressParse( const SProgressData &pd )
     default:
       return( Err_Success );
     break;
-      
+
   }
-  
+
   int reply = KMessageBox::warningYesNo( topLevelWidget(), msg, header );
   mProgressStop = false;
   return( reply == KMessageBox::Yes ? Err_Stop : Err_Success );
