@@ -749,7 +749,6 @@ void CHexViewWidget::setCursor( const SDisplayCursor &cursor,
 				      cursor.thickInsertShape );
   setupCursorTimer();
   redrawFromOffset( mHexBuffer->cursorOffset(), false );
-
 }
 
 void CHexViewWidget::setColor( const SDisplayColor &color, 
@@ -782,6 +781,12 @@ void CHexViewWidget::setMisc( SDisplayMisc &misc )
   mMisc = misc;
   mHexBuffer->setUndoLevel( misc.undoLevel );
   mHexBuffer->setSoundState( misc.inputSound, misc.fatalSound );
+  mHexBuffer->setBookmarkVisibility( misc.bookmarkOffsetColumn, 
+				     misc.bookmarkEditor );
+  if( mHexBuffer->documentPresent() == true )
+  {
+    QWidget::update();
+  }
 }  
 
 
@@ -1076,6 +1081,7 @@ void CHexViewWidget::addBookmark( int position )
     }
     return;
   }
+  redrawFromOffset( mHexBuffer->cursorOffset(), false );
  
   emit bookmarkChanged( mHexBuffer->bookmarkList() );
 }
@@ -1120,6 +1126,7 @@ void CHexViewWidget::removeBookmark( bool all )
     {
       return;
     }
+    QWidget::update(); // Redraw visisble area.
   }
   else
   {
@@ -1128,11 +1135,17 @@ void CHexViewWidget::removeBookmark( bool all )
     {
       return;
     }
+    
+    const SCursorOffset *p = mHexBuffer->bookmarkList().at(position);
+    uint offset = p ? p->offset : 0;
+
     bool success = mHexBuffer->removeBookmark( position );
     if( success == false )
     {
       return;
     }
+
+    redrawFromOffset( offset, false );
   }
 
   emit bookmarkChanged( mHexBuffer->bookmarkList() );
