@@ -43,9 +43,8 @@
 #include <kcolordrag.h>
 #include <kconfig.h>
 #include <kfontdialog.h> // For KFontChooser
-#include <klocale.h>
-
 #include <kiconloader.h>
+#include <klocale.h>
 
 
 #include "optiondialog.h"
@@ -105,7 +104,7 @@ void COptionDialog::setupLayoutPage( void )
 {
   QString text;
   QFrame *page = addPage( i18n("Layout"), i18n("Data layout in editor"),
-			  BarIcon("layout") );
+			  BarIcon("khexedit", KIcon::SizeMedium ) );
   
   QGridLayout *gbox = new QGridLayout( page, 15, 2, 0, spacingHint() );
   gbox->setColStretch( 1, 10 );
@@ -233,7 +232,8 @@ void COptionDialog::setupCursorPage( void )
 {
   QString text;
   QFrame *page = addPage( i18n("Cursor"),
-    i18n("Cursor behavior. Only valid for editor"), UserIcon("mouse") );
+    i18n("Cursor behavior. Only valid for editor"), 
+    BarIcon("mouse", KIcon::SizeMedium ) );
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
 
   QVButtonGroup *group = new QVButtonGroup( i18n("Blinking"), page );
@@ -285,7 +285,7 @@ void COptionDialog::setupColorPage( void )
   QString text;
   QFrame *page = addPage( i18n("Colors"), 
     i18n("Editor colors. System selection color is always used"), 
-			  UserIcon("colors") );
+    BarIcon("colors", KIcon::SizeMedium ) );
 
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
 
@@ -313,12 +313,14 @@ void COptionDialog::setupColorPage( void )
   modeList.append( i18n("Marked text") );
   modeList.append( i18n("Cursor background") );
   modeList.append( i18n("Cursor text (block shape)") );
+  modeList.append( i18n("Bookmark background") );
+  modeList.append( i18n("Bookmark text") );
   modeList.append( i18n("Separator") );
   modeList.append( i18n("Grid lines") );
 
   mColor.colorList = new CColorListBox( page );
   topLayout->addWidget( mColor.colorList, 10 );
-  for( uint i=0; i<15; i++ )
+  for( uint i=0; i<17; i++ )
   {
     CColorListItem *listItem = new CColorListItem( modeList[i] );
     mColor.colorList->insertItem( listItem );
@@ -332,7 +334,7 @@ void COptionDialog::setupFontPage( void )
   QString text;
   QFrame *page = addPage( i18n("Font"), 
     i18n("Font selection. Editor can only use a fixed font"),
-    UserIcon("fonts") );
+    BarIcon("fonts", KIcon::SizeMedium ) );
 
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
 
@@ -381,7 +383,7 @@ void COptionDialog::setupFilePage( void )
 {
   QString text;
   QFrame *page = addPage( i18n("Files"), i18n("File management"),
-			  UserIcon("files") );
+			  BarIcon("files", KIcon::SizeMedium ) );
 
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
 
@@ -441,15 +443,20 @@ void COptionDialog::setupFilePage( void )
 }
 
 
+#include <kinstance.h>
+#include <kglobal.h>
+
 void COptionDialog::setupMiscPage( void )
 {
   QString text;
   QLabel *label;
-
+  
   QFrame *page = addPage( i18n("Miscellaneous"), i18n("Various properties"),
-			  UserIcon("misc") );
+			  BarIcon("misc", KIcon::SizeMedium ) );
+
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
 
+
   text = i18n("Auto&matic copy to clipboard when selection is ready");
   mMisc.autoCheck = new QCheckBox( text, page );
   topLayout->addWidget( mMisc.autoCheck, 0, AlignLeft );
@@ -474,6 +481,13 @@ void COptionDialog::setupMiscPage( void )
   text = i18n("Make sound on &fatal failure");
   mMisc.fatalCheck = new QCheckBox( text, group );
 
+  group = new QVButtonGroup( i18n("Bookmark visibility"), page );
+  group->layout()->setMargin( spacingHint() );
+  topLayout->addWidget( group );
+  text = i18n("Use visible bookmarks in the offset column");
+  mMisc.bookmarkColumnCheck = new QCheckBox( text, group );
+  text = i18n("Use visible bookmarks in the editor fields");
+  mMisc.bookmarkEditorCheck = new QCheckBox( text, group );
 
   text = i18n("Confirm when number of printed pages will e&xceed limit");
   mMisc.thresholdCheck = new QCheckBox( text, page );
@@ -510,7 +524,6 @@ void COptionDialog::setupMiscPage( void )
   glay->addWidget( label, 2, 0 );
   glay->addWidget( mMisc.undoSpin, 2, 1 );
 
-
   topLayout->addStretch(10);
 }
 
@@ -722,6 +735,8 @@ void COptionDialog::slotApply( void )
       c.cursorFg  = mColor.colorList->color( SColorWidgets::CursorFg );
       c.leftSeparatorFg = mColor.colorList->color(SColorWidgets::SeparatorFg);
       c.rightSeparatorFg = mColor.colorList->color(SColorWidgets::SeparatorFg);
+      c.bookmarkBg = mColor.colorList->color( SColorWidgets::BookmarkBg );
+      c.bookmarkFg = mColor.colorList->color( SColorWidgets::BookmarkFg );
       c.nonPrintFg  = mColor.colorList->color( SColorWidgets::NonPrintFg );
       c.gridFg = mColor.colorList->color( SColorWidgets::GridFg );
       emit colorChoice( mDisplayState.color );
@@ -761,6 +776,8 @@ void COptionDialog::slotApply( void )
       m.fatalSound = mMisc.fatalCheck->isChecked();
       m.confirmThreshold = mMisc.thresholdCheck->isChecked();
       m.thresholdValue = mMisc.thresholdSpin->value();
+      m.bookmarkOffsetColumn = mMisc.bookmarkColumnCheck->isChecked();
+      m.bookmarkEditor = mMisc.bookmarkEditorCheck->isChecked();
 
       m.openFile  = (SDisplayMisc::EOpenFile)mFile.openCombo->currentItem();
       m.gotoOnStartup = mFile.gotoOffsetCheck->isChecked();
@@ -844,6 +861,8 @@ void COptionDialog::setColor( SDisplayColor &color )
   mColor.colorList->setColor( SColorWidgets::CursorBg, color.cursorBg );
   mColor.colorList->setColor( SColorWidgets::CursorFg, color.cursorFg );
   mColor.colorList->setColor(SColorWidgets::SeparatorFg,color.leftSeparatorFg);
+  mColor.colorList->setColor( SColorWidgets::BookmarkBg, color.bookmarkBg );
+  mColor.colorList->setColor( SColorWidgets::BookmarkFg, color.bookmarkFg );
   mColor.colorList->setColor( SColorWidgets::NonPrintFg, color.nonPrintFg );
   mColor.colorList->setColor( SColorWidgets::GridFg, color.gridFg );
 }
@@ -862,29 +881,33 @@ void COptionDialog::setFont( SDisplayFont &font )
 
 void COptionDialog::setMisc( SDisplayMisc &misc )
 {
-  mDisplayState.misc.undoLevel           = misc.undoLevel;
-  mDisplayState.misc.inputSound          = misc.inputSound;
-  mDisplayState.misc.fatalSound          = misc.fatalSound;
-  mDisplayState.misc.autoCopyToClipboard = misc.autoCopyToClipboard;
-  mDisplayState.misc.insertMode          = misc.insertMode;
-  mDisplayState.misc.confirmWrap         = misc.confirmWrap;
-  mDisplayState.misc.cursorJump          = misc.cursorJump;
-  mDisplayState.misc.confirmThreshold    = misc.confirmThreshold; 
-  mDisplayState.misc.thresholdValue      = misc.thresholdValue;
-
-
-  mMisc.undoSpin->setValue( misc.undoLevel );
-  mMisc.inputCheck->setChecked( misc.inputSound );
-  mMisc.fatalCheck->setChecked( misc.fatalSound );
+  mDisplayState.misc.undoLevel            = misc.undoLevel;
+  mDisplayState.misc.inputSound           = misc.inputSound;
+  mDisplayState.misc.fatalSound           = misc.fatalSound;
+  mDisplayState.misc.autoCopyToClipboard  = misc.autoCopyToClipboard;
+  mDisplayState.misc.insertMode           = misc.insertMode;
+  mDisplayState.misc.confirmWrap          = misc.confirmWrap;
+  mDisplayState.misc.cursorJump           = misc.cursorJump;
+  mDisplayState.misc.confirmThreshold     = misc.confirmThreshold; 
+  mDisplayState.misc.thresholdValue       = misc.thresholdValue;
+  mDisplayState.misc.bookmarkOffsetColumn = misc.bookmarkOffsetColumn;
+  mDisplayState.misc.bookmarkEditor       = misc.bookmarkEditor;
 
   mMisc.autoCheck->setChecked( misc.autoCopyToClipboard );
   mMisc.insertCheck->setChecked( misc.insertMode );
   mMisc.confirmWrapCheck->setChecked( misc.confirmWrap );
   mMisc.cursorJumpCheck->setChecked( misc.cursorJump );
 
+  mMisc.inputCheck->setChecked( misc.inputSound );
+  mMisc.fatalCheck->setChecked( misc.fatalSound );
+  mMisc.bookmarkColumnCheck->setChecked( misc.bookmarkOffsetColumn );
+  mMisc.bookmarkEditorCheck->setChecked( misc.bookmarkEditor );
+
   mMisc.thresholdCheck->setChecked( misc.confirmThreshold );
   mMisc.thresholdSpin->setValue( misc.thresholdValue );
   slotThresholdConfirm();
+
+  mMisc.undoSpin->setValue( misc.undoLevel );
 }
 
 void COptionDialog::setFile( SDisplayMisc &misc )
