@@ -22,7 +22,7 @@
 
 #include <qpixmap.h>
 #include <qtimer.h>
-#include <qtooltip.h> 
+#include <qtooltip.h>
 
 #include <kaction.h>
 #include <kapp.h>
@@ -34,6 +34,7 @@
 #include <kstdaccel.h>
 #include <kstdaction.h>
 #include <ktoolbarbutton.h>
+#include <kpopupmenu.h>
 
 #include "aboutdialog.h"
 #include "dialog.h"
@@ -56,7 +57,7 @@ KHexEdit::KHexEdit( void )
   setView( mManager );
 
   //
-  // I use an eventfilter to catch all drag/drop events for the 
+  // I use an eventfilter to catch all drag/drop events for the
   // area outside the editor window. It will only accept QUriDrag.
   // (The editor window will catch QUriDrag, QTextDrag and CHexDrag)
   //
@@ -90,20 +91,20 @@ KHexEdit::KHexEdit( void )
   connect( textView(), SIGNAL( fileRename( const QString &, const QString & )),
 	   this, SLOT( fileRename( const QString &, const QString & ) ) );
   connect( textView(), SIGNAL( fileClosed( const QString & ) ),
-	   this, SLOT( fileClosed( const QString & ) ) ); 
+	   this, SLOT( fileClosed( const QString & ) ) );
   connect( editor(), SIGNAL( errorLoadFile( const QString & ) ),
 	   this, SLOT( removeRecentFile( const QString & ) ) );
   connect( editor(), SIGNAL( operationChanged( bool ) ),
 	   this, SLOT( operationChanged( bool ) ) );
   connect( editor(), SIGNAL( removeRecentFiles() ),
 	   this, SLOT( removeRecentFiles() ) );
-  connect( mManager, SIGNAL( conversionClosed() ), 
+  connect( mManager, SIGNAL( conversionClosed() ),
 	   this, SLOT(conversionClosed()) );
-  connect( mManager, SIGNAL( searchBarClosed() ), 
+  connect( mManager, SIGNAL( searchBarClosed() ),
 	   this, SLOT(searchBarClosed()) );
 
   //
-  // Read configuration from file and set the default editor size.  
+  // Read configuration from file and set the default editor size.
   // Open files if this is the first toplevel window.
   //
   readConfiguration();
@@ -121,7 +122,7 @@ KHexEdit::~KHexEdit( void )
 
 void KHexEdit::setupActions( void )
 {
-  mAction.newFile    = KStdAction::openNew( editor(), SLOT(newFile()), this ); 
+  mAction.newFile    = KStdAction::openNew( editor(), SLOT(newFile()), this );
   mAction.open       = KStdAction::open( editor(), SLOT(open()), this );
   mAction.insert     = new KAction( i18n("&Insert..."), 0,
     editor(), SLOT(insertFile()), this );
@@ -138,15 +139,15 @@ void KHexEdit::setupActions( void )
   mAction.print      = KStdAction::print( editor(), SLOT(print()), this );
   mAction.exportData = new KAction( i18n("E&xport..."), 0,
     editor(), SLOT(exportDialog()), this );
-  mAction.cancel     = new KAction( i18n("&Cancel Operation"), 
+  mAction.cancel     = new KAction( i18n("&Cancel Operation"),
     "stop", 0, editor(), SLOT(stop()), this );
-  mAction.readOnly   = new KToggleAction( i18n("&Read only"), 
+  mAction.readOnly   = new KToggleAction( i18n("&Read only"),
     0, editor(), SLOT(toggleWriteProtection()),this);
-  mAction.resizeLock = new KToggleAction( i18n("&Allow Resize"), 
+  mAction.resizeLock = new KToggleAction( i18n("&Allow Resize"),
    0, editor(), SLOT(toggleResizeLock()),this);
-  mAction.newWindow  = new KAction( i18n("N&ew Window"), 
+  mAction.newWindow  = new KAction( i18n("N&ew Window"),
     0, this, SLOT(newWindow()),this);
-  mAction.closeWindow= new KAction( i18n("Close &Window"), 
+  mAction.closeWindow= new KAction( i18n("Close &Window"),
     0, this, SLOT(closeWindow()),this);
   mAction.quit       = KStdAction::quit( this, SLOT(closeProgram()), this );
 
@@ -178,15 +179,15 @@ void KHexEdit::setupActions( void )
   mAction.gotoOffset->setAccel( CTRL+Key_G );
   mAction.insertPattern->setAccel( KStdAccel::key(KStdAccel::Insert) );
 
-  mAction.hexadecimal = new KRadioAction( i18n("&Hexadecimal"), 
+  mAction.hexadecimal = new KRadioAction( i18n("&Hexadecimal"),
     0, this, SLOT(setDisplayMode()), this, "mode" );
-  mAction.decimal     = new KRadioAction( i18n("&Decimal"), 
+  mAction.decimal     = new KRadioAction( i18n("&Decimal"),
     0, this, SLOT(setDisplayMode()),this, "mode" );
-  mAction.octal       = new KRadioAction( i18n("&Octal"), 
+  mAction.octal       = new KRadioAction( i18n("&Octal"),
     0, this, SLOT(setDisplayMode()),this, "mode" );
-  mAction.binary      = new KRadioAction( i18n("&Binary"), 
+  mAction.binary      = new KRadioAction( i18n("&Binary"),
     0, this, SLOT(setDisplayMode()),this, "mode" );
-  mAction.textOnly    = new KRadioAction( i18n("&Text"), 
+  mAction.textOnly    = new KRadioAction( i18n("&Text"),
     0, this, SLOT(setDisplayMode()),this, "mode" );
   mAction.hexadecimal->setExclusiveGroup( "displayMode" );
   mAction.decimal->setExclusiveGroup( "displayMode" );
@@ -203,8 +204,8 @@ void KHexEdit::setupActions( void )
   mAction.dataUppercase = new KToggleAction( i18n("&Upper case (data)"),
     0, editor(), SLOT(toggleDataUppercase()),this);
   mAction.offsetUppercase = new KToggleAction( i18n("Upper &case (offset)"),
-    0, editor(), SLOT(toggleOffsetUppercase()),this); 
- 
+    0, editor(), SLOT(toggleOffsetUppercase()),this);
+
   mAction.defaultEncoding = new KRadioAction( i18n("&Default"),
     0, this, SLOT( setEncoding()), this );
   mAction.usAsciiEncoding = new KRadioAction( i18n("US-&ASCII (7 bit)"),
@@ -230,7 +231,7 @@ void KHexEdit::setupActions( void )
   mAction.statistics = new KAction( i18n("&Statistics..."), 0,
     editor(), SLOT(statistics()), this );
 
-  mAction.addBookmark = KStdAction::addBookmark( editor(), 
+  mAction.addBookmark = KStdAction::addBookmark( editor(),
     SLOT(addBookmark()), this );
   mAction.replaceBookmark = new KAction( i18n("&Replace Bookmark"), CTRL+Key_E,
     editor(), SLOT(replaceBookmark()), this );
@@ -238,13 +239,19 @@ void KHexEdit::setupActions( void )
     editor(), SLOT(removeBookmark()), this );
   mAction.removeAllBookmark = new KAction( i18n("Re&move All"), 0,
     editor(), SLOT(removeAllBookmark()), this );
+  mAction.nextBookmark = new KAction( i18n("Goto &Next Bookmark"),
+				      ALT+Key_Down, editor(),
+				      SLOT(gotoNextBookmark()), this );
+  mAction.prevBookmark = new KAction( i18n("Goto &Previous Bookmark"),
+				      ALT+Key_Up, editor(),
+				      SLOT(gotoPrevBookmark()), this );
 
   mAction.showToolBar = KStdAction::showToolbar( this, SLOT(showToolBar()),
     this);
   mAction.showStatusBar = KStdAction::showStatusbar(this,SLOT(showStatusBar()),
     this);
   mAction.showFullPath  = new KToggleAction( i18n("Show F&ull Path"),
-    0, this, SLOT(showFullPath()), this );  
+    0, this, SLOT(showFullPath()), this );
 
   mAction.tabHide = new KRadioAction( i18n("&Hide"),
     0, this, SLOT(showDocumentTabs()), this );
@@ -330,25 +337,25 @@ void KHexEdit::setupActions( void )
   mAction.fileMenu->insert( mAction.newFile );
   mAction.fileMenu->insert( mAction.open );
   mAction.fileMenu->insert( mAction.insert );
-  mAction.fileMenu->insert( mAction.openRecent );  
+  mAction.fileMenu->insert( mAction.openRecent );
   mAction.fileMenu->insert( mAction.revert );
   mAction.fileMenu->insert( mAction.separator );
   mAction.fileMenu->insert( mAction.save );
-  mAction.fileMenu->insert( mAction.saveAs );  
+  mAction.fileMenu->insert( mAction.saveAs );
   mAction.fileMenu->insert( mAction.close );
   mAction.fileMenu->insert( mAction.separator );
   mAction.fileMenu->insert( mAction.print );
-  mAction.fileMenu->insert( mAction.exportData );  
+  mAction.fileMenu->insert( mAction.exportData );
   mAction.fileMenu->insert( mAction.separator );
-  mAction.fileMenu->insert( mAction.cancel ); 
+  mAction.fileMenu->insert( mAction.cancel );
   // File-Permissions-Start
   mAction.permissionMenu->insert( mAction.readOnly );
   mAction.permissionMenu->insert( mAction.resizeLock );
   // File-Permissions-Stop
   mAction.fileMenu->insert( mAction.permissionMenu );
-  mAction.fileMenu->insert( mAction.separator );  
+  mAction.fileMenu->insert( mAction.separator );
   mAction.fileMenu->insert( mAction.newWindow );
-  mAction.fileMenu->insert( mAction.quit ); 
+  mAction.fileMenu->insert( mAction.quit );
 
   // Edit menu
   mAction.editMenu->insert( mAction.undo );
@@ -414,9 +421,12 @@ void KHexEdit::setupActions( void )
   mAction.bookmarkMenu->insert( mAction.replaceBookmark );
   mAction.bookmarkMenu->insert( mAction.removeBookmark );
   mAction.bookmarkMenu->insert( mAction.removeAllBookmark );
+  mAction.bookmarkMenu->insert( mAction.separator );
+  mAction.bookmarkMenu->insert( mAction.nextBookmark );
+  mAction.bookmarkMenu->insert( mAction.prevBookmark );
 
   // Documents menu
-  connect( mAction.documentsMenu->popupMenu(), SIGNAL(activated(int)), 
+  connect( mAction.documentsMenu->popupMenu(), SIGNAL(activated(int)),
 	   SLOT(documentMenuCB(int)) );
 
   mAction.settingsMenu->insert( mAction.showToolBar );
@@ -447,7 +457,7 @@ void KHexEdit::setupActions( void )
   mAction.settingsMenu->insert( mAction.preferences );
   mAction.settingsMenu->insert( mAction.favorites );
 
-  //  
+  //
   // Make the menubar.
   //
   mAction.fileMenu->plug( menuBar() );
@@ -458,7 +468,7 @@ void KHexEdit::setupActions( void )
   mAction.documentsMenu->plug( menuBar() );
   mAction.settingsMenu->plug( menuBar() );
   mAction.separator->plug( menuBar() );
-  menuBar()->insertItem( i18n("&Help"), helpMenu() );
+  menuBar()->insertItem( i18n("&Help"), customHelpMenu() );
 
   //
   // Make the toolbar
@@ -466,6 +476,7 @@ void KHexEdit::setupActions( void )
   mDragLabel = new CDragLabel( toolBar(0) );
   mDragLabel->setPixmap( UserIcon( "hexdrag" ) );
   mDragLabel->setDragMask( UserIcon( "hexmask" ) );
+  mDragLabel->setEnabled( false ); // Enabled once we open a document
   QToolTip::add( mDragLabel, i18n("Drag document") );
   toolBar(0)->insertWidget( -1, 22, mDragLabel );
 
@@ -486,10 +497,10 @@ void KHexEdit::setupActions( void )
   mAction.help->plug( toolBar(0) );
 
   int id = 100;
-  toolBar(0)->insertButton( UserIcon("lock"), id, SIGNAL(clicked()), editor(), 
+  toolBar(0)->insertButton( UserIcon("lock"), id, SIGNAL(clicked()), editor(),
     SLOT(toggleWriteProtection()), true, i18n("Toggle write protection") );
   toolBar(0)->alignItemRight( id );
-  mWriteProtectButton = toolBar(0)->getButton(id); 
+  mWriteProtectButton = toolBar(0)->getButton(id);
 }
 
 
@@ -507,7 +518,7 @@ void KHexEdit::setupStatusBar( void )
   connect( editor(), SIGNAL( setProgressText( const QString & ) ),
 	   progess, SLOT( setText( const QString & ) ) );
 
-  statusBar()->insertFixedItem( i18n("Selection: 0000:0000 0000:0000"), 
+  statusBar()->insertFixedItem( i18n("Selection: 0000:0000 0000:0000"),
 				status_Selection );
   statusBar()->insertFixedItem( i18n("M"), status_Modified );
   statusBar()->insertFixedItem( i18n("OVR"), status_Ovr );
@@ -516,7 +527,7 @@ void KHexEdit::setupStatusBar( void )
   statusBar()->insertFixedItem( i18n("FFF"), status_Layout );
   statusBar()->insertFixedItem( i18n("RW"), status_WriteProtect );
 
-  statusBar()->setItemAlignment( status_Selection, AlignLeft|AlignVCenter );  
+  statusBar()->setItemAlignment( status_Selection, AlignLeft|AlignVCenter );
   statusBar()->setItemAlignment( status_Size, AlignLeft|AlignVCenter );
   statusBar()->setItemAlignment( status_Offset, AlignLeft|AlignVCenter );
 
@@ -541,7 +552,7 @@ void KHexEdit::removeRecentFiles( void )
 void KHexEdit::initialize( bool openFiles )
 {
   mUndoState = CHexBuffer::UndoOk; // Reset in function below
-  setUndoState( 0 ); 
+  setUndoState( 0 );
 
   mSelectionOffset = 0;
   mSelectionSize   = 1;
@@ -551,7 +562,7 @@ void KHexEdit::initialize( bool openFiles )
   operationChanged( false );
 
   editor()->initialize();
- 
+
   mAction.showToolBar->setChecked( mShowToolBar );
   mAction.showStatusBar->setChecked( mShowStatusBar );
   mAction.showFullPath->setChecked( mShowFullPath );
@@ -594,7 +605,7 @@ void KHexEdit::initialize( bool openFiles )
   }
 
   //
-  // Open file(s) after editor has been displayed. 
+  // Open file(s) after editor has been displayed.
   // Main reason: If anything goes wrong and an error dialog box
   // is displayed, then the editor will not be visible until the error
   // is confirmed and the (modal) dialog is closed.
@@ -615,7 +626,7 @@ void KHexEdit::statusBarPressed( int id )
 {
   if( id == status_WriteProtect )
   {
-    mAction.readOnly->setChecked( !mAction.readOnly->isChecked() );
+    editor()->toggleWriteProtection();
   }
   else if( id == status_Offset )
   {
@@ -637,10 +648,10 @@ void KHexEdit::statusBarPressed( int id )
 void KHexEdit::open( QStringList &fileList, QStringList &offsetList )
 {
   //
-  // We load in reverse to allow the first document in 
-  // the list to become the active one. 
+  // We load in reverse to allow the first document in
+  // the list to become the active one.
   //
-  
+
   uint offset;
   for( uint i = fileList.count(); i>0; i-- )
   {
@@ -662,7 +673,7 @@ void KHexEdit::addRecentFile( const QString &fileName )
   {
     return;
   }
-  
+
   if( fileName.contains( i18n( "Untitled" ), false ) )
   {
     return;
@@ -676,20 +687,20 @@ void KHexEdit::addRecentFile( const QString &fileName )
     {
       continue;
     }
- 
+
     if( fileName == text )
     {
       mAction.openRecent->popupMenu()->removeItem(id);
     }
   }
-  
+
   while( mAction.openRecent->popupMenu()->count() >= 5 )
   {
     mAction.openRecent->popupMenu()->removeItemAt(4);
   }
 
   mAction.openRecent->popupMenu()->insertItem( fileName, 0, 0 );
-  for( uint i = 0; i < 5; i++ ) 
+  for( uint i = 0; i < 5; i++ )
   {
     mAction.openRecent->popupMenu()->setId( i, i );
   }
@@ -702,7 +713,7 @@ void KHexEdit::removeRecentFile( const QString &fileName )
   {
     return;
   }
-  
+
   if( fileName.contains( i18n( "Untitled" ), false ) )
   {
     return;
@@ -718,13 +729,13 @@ void KHexEdit::removeRecentFile( const QString &fileName )
     {
       continue;
     }
- 
+
     if( fileName == text )
-    { 
+    {
       mAction.openRecent->popupMenu()->removeItem(i);
     }
   }
-  for( i = 0; i < 5; i++ ) 
+  for( i = 0; i < 5; i++ )
   {
     mAction.openRecent->popupMenu()->setId( i, i );
   }
@@ -743,9 +754,9 @@ void KHexEdit::renameRecentFile(const QString &curName, const QString &newName)
     {
       const char *text = mAction.openRecent->popupMenu()->text(i);
       if( text == 0 ) { continue; }
- 
+
       if( curName == text )
-      { 
+      {
 	mAction.openRecent->popupMenu()->changeItem( newName, i );
 	break;
       }
@@ -758,8 +769,8 @@ void KHexEdit::recentFile( int id )
 {
   //
   // 2000-01-02 Espen Sand
-  // For some reason I sometimes get a segfault when I open the 
-  // file directly from this slot. It used to work, but at some 
+  // For some reason I sometimes get a segfault when I open the
+  // file directly from this slot. It used to work, but at some
   // point of Qt (2.x) upgrades this began to happen. To avoid
   // the problem I delay the opening until the program runs in
   // the main event loop.
@@ -838,8 +849,8 @@ void KHexEdit::closeProgram( void )
     }
 
     //
-    // Save the order in the Recent queue to a list. This list will be written 
-    // to disk. 
+    // Save the order in the Recent queue to a list. This list will be written
+    // to disk.
     //
     makeExitFileList();
 
@@ -849,7 +860,7 @@ void KHexEdit::closeProgram( void )
     queryExit();
 
     //
-    // Now we need to destroy the manager widget. The editor widget 
+    // Now we need to destroy the manager widget. The editor widget
     // (which is a child of the manager widget) will delete some
     // dialogs when destroyed. These dialogs have no parent (parent=0)
     // and sometimes their destructors are executed before the editor
@@ -866,15 +877,15 @@ void KHexEdit::closeProgram( void )
   {
     closeWindow();
   }
- 
+
 }
-    
+
 
 bool KHexEdit::queryClose( void )
 {
   //
-  // Save the order in the Recent queue to a list. This list will be written 
-  // to disk. 
+  // Save the order in the Recent queue to a list. This list will be written
+  // to disk.
   //
   makeExitFileList();
 
@@ -889,7 +900,7 @@ bool KHexEdit::queryClose( void )
 
 
 //
-// We will always return true here. 
+// We will always return true here.
 //
 bool KHexEdit::queryExit( void )
 {
@@ -901,14 +912,14 @@ bool KHexEdit::queryExit( void )
 void KHexEdit::makeExitFileList( void )
 {
   //
-  // Note: I append five names, even if they are empty because the recent 
-  // menu contains fewer. This is important because otherwise we may end up 
+  // Note: I append five names, even if they are empty because the recent
+  // menu contains fewer. This is important because otherwise we may end up
   // having duplicate entries in the config. file.
   //
 
   mExitFileList.clear();
   mExitOffsetList.clear();
- 
+
   if( editor()->discardRecentFiles() == true )
   {
     for( uint i=0; i < 5; i++ )
@@ -982,19 +993,19 @@ void KHexEdit::readConfiguration( KConfig &config )
   mShowToolBar    = config.readBoolEntry( "ShowToolBar", true );
   mShowStatusBar  = config.readBoolEntry( "ShowStatusBar", true );
   mShowFullPath   = config.readBoolEntry( "ShowFullPath", true );
-  int position    = config.readNumEntry( "ConversionPosition", 
+  int position    = config.readNumEntry( "ConversionPosition",
 					 CHexManagerWidget::Embed );
 
-  mAction.conversionHide->blockSignals(true); 
+  mAction.conversionHide->blockSignals(true);
   mAction.conversionFloat->blockSignals(true);
   mAction.conversionEmbed->blockSignals(true);
-  mAction.conversionHide->setChecked( 
+  mAction.conversionHide->setChecked(
     position == CHexManagerWidget::Hide );
-  mAction.conversionFloat->setChecked( 
-    position == CHexManagerWidget::Float ); 
-  mAction.conversionEmbed->setChecked( 
+  mAction.conversionFloat->setChecked(
+    position == CHexManagerWidget::Float );
+  mAction.conversionEmbed->setChecked(
     position == CHexManagerWidget::Embed );
-  mAction.conversionHide->blockSignals(false); 
+  mAction.conversionHide->blockSignals(false);
   mAction.conversionFloat->blockSignals(false);
   mAction.conversionEmbed->blockSignals(false);
   showConversionField();
@@ -1003,11 +1014,11 @@ void KHexEdit::readConfiguration( KConfig &config )
   mAction.tabHide->blockSignals(true);
   mAction.tabShowAboveEditor->blockSignals(true);
   mAction.tabShowBelowEditor->blockSignals(true);
-  mAction.tabHide->setChecked( 
+  mAction.tabHide->setChecked(
     position==CHexManagerWidget::Hide );
-  mAction.tabShowAboveEditor->setChecked( 
+  mAction.tabShowAboveEditor->setChecked(
     position==CHexManagerWidget::AboveEditor );
-  mAction.tabShowBelowEditor->setChecked( 
+  mAction.tabShowBelowEditor->setChecked(
     position==CHexManagerWidget::BelowEditor );
   mAction.tabHide->blockSignals(false);
   mAction.tabShowAboveEditor->blockSignals(false);
@@ -1019,22 +1030,22 @@ void KHexEdit::readConfiguration( KConfig &config )
   mAction.searchHide->blockSignals(true);
   mAction.searchShowAboveEditor->blockSignals(true);
   mAction.searchShowBelowEditor->blockSignals(true);
-  mAction.searchHide->setChecked( 
+  mAction.searchHide->setChecked(
     position==CHexManagerWidget::Hide );
-  mAction.searchShowAboveEditor->setChecked( 
+  mAction.searchShowAboveEditor->setChecked(
     position==CHexManagerWidget::AboveEditor );
-  mAction.searchShowBelowEditor->setChecked( 
+  mAction.searchShowBelowEditor->setChecked(
     position==CHexManagerWidget::BelowEditor );
   mAction.searchHide->blockSignals(false);
   mAction.searchShowAboveEditor->blockSignals(false);
   mAction.searchShowBelowEditor->blockSignals(false);
   showSearchBar();
 
-  for( uint i = 0; i < 5; i++ ) 
+  for( uint i = 0; i < 5; i++ )
   {
     QString fileName = config.readEntry( QString("Recent%1").arg(i+1) );
     if( fileName.isEmpty() == false )
-    { 
+    {
       int pos = mAction.openRecent->popupMenu()->count();
       mAction.openRecent->popupMenu()->insertItem( fileName, pos, pos );
     }
@@ -1104,7 +1115,7 @@ void KHexEdit::cursorChanged( SCursorState &state )
     }
     statusBar()->changeItem( offset, status_Offset );
   }
-  
+
   setUndoState( state.undoState );
   setSelectionState( state.selectionOffset, state.selectionSize );
 }
@@ -1165,7 +1176,9 @@ void KHexEdit::layoutChanged( const SDisplayLayout &layout )
   mAction.showOffsetColumn->setChecked( layout.offsetVisible );
   mAction.showTextColumn->setEnabled(
     layout.primaryMode != SDisplayLayout::textOnly );
-  mAction.offsetAsDecimal->setChecked( 
+  mAction.showTextColumn->setChecked(
+    layout.secondaryMode != SDisplayLayout::hide );
+  mAction.offsetAsDecimal->setChecked(
     layout.offsetMode != SDisplayLayout::hexadecimal);
   mAction.dataUppercase->setChecked( layout.primaryUpperCase );
   mAction.offsetUppercase->setChecked( layout.offsetUpperCase );
@@ -1174,26 +1187,26 @@ void KHexEdit::layoutChanged( const SDisplayLayout &layout )
   mAction.showTextColumn->blockSignals(false);
   mAction.offsetAsDecimal->blockSignals(false);
   mAction.dataUppercase->blockSignals(false);
-  mAction.offsetUppercase->blockSignals(false); 
+  mAction.offsetUppercase->blockSignals(false);
 
-  if( layout.primaryMode == SDisplayLayout::hexadecimal ) 
+  if( layout.primaryMode == SDisplayLayout::hexadecimal )
   {
     statusBar()->changeItem( i18n("Hex"), status_Layout );
   }
-  else if( layout.primaryMode == SDisplayLayout::decimal ) 
+  else if( layout.primaryMode == SDisplayLayout::decimal )
   {
     statusBar()->changeItem( i18n("Dec"), status_Layout );
   }
   else if( layout.primaryMode == SDisplayLayout::octal )
-  { 
+  {
     statusBar()->changeItem( i18n("Oct"), status_Layout );
   }
   else if( layout.primaryMode == SDisplayLayout::binary )
-  { 
+  {
     statusBar()->changeItem( i18n("Bin"), status_Layout );
   }
   else if( layout.primaryMode == SDisplayLayout::textOnly )
-  { 
+  {
     statusBar()->changeItem( i18n("Txt"), status_Layout );
   }
 }
@@ -1208,9 +1221,9 @@ void KHexEdit::inputModeChanged( const SDisplayInputMode &mode )
   mAction.readOnly->blockSignals(false);
   mAction.resizeLock->blockSignals(false);
 
-  statusBar()->changeItem( mode.readOnly == true ? 
+  statusBar()->changeItem( mode.readOnly == true ?
 			   i18n("R") : i18n("RW"), status_WriteProtect );
- 
+
   QPixmap pixmap;
   if( mode.readOnly == false )
   {
@@ -1241,6 +1254,10 @@ void KHexEdit::bookmarkChanged( QList<SCursorOffset> &list )
   mAction.bookmarkMenu->insert( mAction.replaceBookmark );
   mAction.bookmarkMenu->insert( mAction.removeBookmark );
   mAction.bookmarkMenu->insert( mAction.removeAllBookmark );
+  mAction.bookmarkMenu->insert( mAction.separator );
+  mAction.bookmarkMenu->insert( mAction.nextBookmark );
+  mAction.bookmarkMenu->insert( mAction.prevBookmark );
+
   if( list.count() == 0 )
   {
     return;
@@ -1321,7 +1338,7 @@ void KHexEdit::fileClosed( const QString &url )
 
 void KHexEdit::editMode( CHexBuffer::EEditMode editMode )
 {
-  statusBar()->changeItem( editMode == CHexBuffer::EditReplace ? 
+  statusBar()->changeItem( editMode == CHexBuffer::EditReplace ?
 			   i18n("OVR") : i18n("INS"), status_Ovr );
 }
 
@@ -1353,9 +1370,9 @@ void KHexEdit::encodingChanged( const SEncodeState &encodeState )
 
   if( mSelectionSize == 0 )
   {
-    statusBar()->changeItem( i18n("Encoding: %1").arg(encodeState.name), 
+    statusBar()->changeItem( i18n("Encoding: %1").arg(encodeState.name),
 			     status_Selection );
-  }  
+  }
 }
 
 
@@ -1497,7 +1514,7 @@ void KHexEdit::setEncoding( void )
 }
 
 
-void KHexEdit::setUndoState( uint undoState ) 
+void KHexEdit::setUndoState( uint undoState )
 {
   if( mUndoState != undoState )
   {
@@ -1532,20 +1549,20 @@ void KHexEdit::setSelectionText( uint selectionOffset, uint selectionSize )
     QString selection = i18n("Selection:");
     if( mSelectionAsHexadecimal == true )
     {
-      selection += QString().sprintf( " %04x:%04x %04x:%04x",  
+      selection += QString().sprintf( " %04x:%04x %04x:%04x",
         selectionOffset>>16, selectionOffset&0x0000FFFF,
         selectionSize>>16, selectionSize&0x0000FFFF );
     }
     else
     {
-      selection += QString().sprintf( " %08u %08u",  
+      selection += QString().sprintf( " %08u %08u",
         selectionOffset, selectionSize);
     }
     statusBar()->changeItem( selection, status_Selection );
   }
   else
   {
-    statusBar()->changeItem( 
+    statusBar()->changeItem(
       i18n("Encoding: %1").arg(textView()->encoding().name), status_Selection);
   }
 }
@@ -1595,7 +1612,7 @@ void KHexEdit::removeDocument( const QString &fileName )
       documentMenu->removeItemAt( mDocumentList.findIndex(*it) );
       mDocumentList.remove( it );
 
-      for( uint i=0; i < mDocumentList.count(); i++ ) 
+      for( uint i=0; i < mDocumentList.count(); i++ )
       {
 	documentMenu->setId( i, i );
 	int key = acceleratorNumKey( i );
@@ -1640,13 +1657,13 @@ void KHexEdit::setTickedDocument( const QString &fileName )
 
 
 void KHexEdit::conversionClosed( void )
-{ 
+{
   mAction.conversionHide->setChecked(true);
 }
 
 
 void KHexEdit::searchBarClosed( void )
-{ 
+{
   mAction.searchHide->setChecked(true);
 }
 
@@ -1686,7 +1703,7 @@ bool KHexEdit::eventFilter( QObject *, QEvent *event )
   {
     QMimeSource &m = *(QDropEvent*)event;
     textView()->setDropHighlight( false );
-    
+
     QStringList list, offset;
     if( QUriDrag::decodeToUnicodeUris( &m, list ) == true )
     {
@@ -1713,7 +1730,7 @@ void KHexEdit::resizeTest()
 
   int loop=400;
 
-  for( uint i=0; i< loop; i+=4 )
+  for( int i=0; i<loop; i+=4 )
   {
     resize( i+400, i+400 );
     //kapp->processOneEvent();
@@ -1721,10 +1738,7 @@ void KHexEdit::resizeTest()
 
   gettimeofday( &t2, 0 );
   uint last = (t2.tv_sec-t1.tv_sec) * 1000000 + (t2.tv_usec - t1.tv_usec);
- 
+
   debug( "Duration:      %f", (float)last/ 1000000.0 );
   debug( "Duration/loop: %f", (float)last/ (1000000.0*(float)loop) );
 }
-
-
-
