@@ -19,32 +19,38 @@
 //  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qapp.h>
-#include <qmenubar.h>
-#include <qpopmenu.h>
+
+//
+// 1999-11-07-Espen Sand:
+// Cleaned up layout, AskFileName based on KDialogBase,
+// new Option dialog, QMessageBox -> KMessageBox
+//
+
+
+#include <qpopupmenu.h>
 #include <qkeycode.h>
 #include <qfile.h>
-#include <qtstream.h>
+#include <qtextstream.h>
 #include <qdir.h>
-#include <qlined.h>
-#include <qdialog.h>
-#include <qmsgbox.h>
-#include <qmlined.h>
-#include <qfiledlg.h>
+#include <qlineedit.h>
+#include <qobjectlist.h>
 #include <qtooltip.h>
-#include <qscrbar.h>
-#include <qobjcoll.h>
-#include <qclipbrd.h>
+#include <qscrollbar.h>
+#include <qcollection.h>
+#include <qclipboard.h>
 
-#include <kapp.h>
-#include <ktabctl.h>
-#include <kmsgbox.h>
-#include <kmenubar.h>
-#include <ktoolbar.h>
-#include <kiconloader.h>
 #include <kaccel.h>
+#include <kaction.h>
+#include <kstdaction.h>
+#include <kapp.h>
 #include <kfiledialog.h>
+
+#include <kiconloader.h>
 #include <kkeydialog.h>
+#include <kmenubar.h>
+#include <kmessagebox.h>
+#include <kstddirs.h>
+#include <ktoolbar.h>
 
 extern "C" {
 #include <unistd.h>
@@ -54,7 +60,12 @@ extern "C" {
 #include "SubjList.h"
 #include "ReadListConf.h"
 #include "cpopmenu.h"
-#include "confdialog.h"
+#include "optiondialog.h"
+
+#include <klocale.h>
+#include <kconfig.h>
+
+#define KJOTSVERSION "0.4"
 
 const unsigned int HOT_LIST_SIZE = 8;
 const unsigned int BUTTON_WIDTH = 56;
@@ -62,53 +73,58 @@ const unsigned int BUTTON_WIDTH = 56;
 extern QString exec_http;
 extern QString exec_ftp;
 
-extern KIconLoader *global_pix_loader;
+#include <qvbox.h>
 
 //----------------------------------------------------------------------
 // ASKFILENAME
 //----------------------------------------------------------------------
-
 AskFileName::AskFileName(QWidget* parent, const char* name)
-  : QDialog(parent, name, TRUE)
+  : KDialogBase( parent, name, TRUE, i18n("New Book"), Ok|Cancel, Ok )
 {
-  initMetaObject();
-  resize(300, 80);
-  QLabel *l_name = new QLabel( klocale->translate("Book name:"), this );
-  i_name = new QLineEdit( this );
-  QPushButton *b_ok = new QPushButton(klocale->translate("OK"), this);
-  QPushButton *b_cancel = new QPushButton(klocale->translate("Cancel"), this);
+  QFrame *page = makeMainWidget();
+  QVBoxLayout *vlay = new QVBoxLayout( page, 0, spacingHint() );
 
-  l_name->setGeometry(10, 10, 80, 24);
-  i_name->setGeometry(100, 10, 190, 24);
-  b_ok->setGeometry(20, 44, 60, 24);
-  b_ok->setDefault(TRUE);
-  b_cancel->setGeometry(220, 44, 60, 24);
+  QLabel *label = new QLabel( i18n("Book name:"), page );
+  vlay->addWidget(label);
 
+  i_name = new QLineEdit( page );
+  i_name->setMinimumWidth( fontMetrics().maxWidth()*20 );
   i_name->setFocus();
-  connect( b_ok, SIGNAL(clicked()), this, SLOT(accept()) );
-  connect( b_cancel, SIGNAL(clicked()), this, SLOT(reject()) );
+  vlay->addWidget(i_name );
+  connect(i_name, SIGNAL(textChanged(const QString &)),
+	  this, SLOT(textChanged(const QString &)));
+
+  vlay->addStretch( 10 );
+
+  enableButtonOK( false );
 }
 
+void AskFileName::textChanged(const QString &s)
+{
+  enableButtonOK( s.length() > 0 );
+}
+
+
 //----------------------------------------------------------------------
 // MYMULTIEDIT
 //----------------------------------------------------------------------
-
 MyMultiEdit::MyMultiEdit (QWidget* parent, const char* name)
-  : QMultiLineEdit(parent, name)
+  : KEdit(parent, name)
 {
-  initMetaObject();
   web_menu = new CPopupMenu;
-  web_menu->insertItem(klocale->translate("Open URL"), this, SLOT(openUrl()) );
+  web_menu->insertItem(i18n("Open URL"), this, SLOT(openUrl()) );
 }
 
 void MyMultiEdit::keyPressEvent( QKeyEvent *e )
 {
   if( e->key() == Key_Tab )
     {
-      insertChar('\t');
+      int line, col;
+      cursorPosition(&line, &col);
+      KEdit::insertAt("\t", line, col);
       return;
     }
-  QMultiLineEdit::keyPressEvent(e);
+  KEdit::keyPressEvent(e);
   return;
 }
 
@@ -124,11 +140,10 @@ void MyMultiEdit::mousePressEvent( QMouseEvent *e )
 	      web_menu->popup(QCursor::pos());
 	      web_menu->grabMouse();
 	    }
-	}
       return;
+	}
     }
-  QMultiLineEdit::mousePressEvent(e);
-  return;
+  KEdit::mousePressEvent(e);
 }
 
 void MyMultiEdit::openUrl()
@@ -141,7 +156,7 @@ void MyMultiEdit::openUrl()
       if( marked.left(7) == "http://" )
 	{
 	  command = exec_http;
-	  command.detach();
+	
 	  if( (pos = exec_http.find("%u")) == -1 )
 	    {
 	      command += " " + marked + " &";
@@ -158,7 +173,7 @@ void MyMultiEdit::openUrl()
       else if( marked.left(6) == "ftp://" )
 	{
 	  command = exec_ftp;
-	  command.detach();
+	
 	  if( (pos = exec_ftp.find("%u")) == -1 )
 	    {
 	      command += " " + marked + " &";
@@ -190,12 +205,12 @@ void MyButtonGroup::resizeEvent( QResizeEvent * )
   int x = width()-2;
   QObjectList  *list = queryList( "QPushButton" );
   QObjectListIt it( *list );
-  while ( it.current() ) {  
+  while ( it.current() ) {
     x -= (BUTTON_WIDTH+4);
     ((QPushButton *) it.current())->move(x, 4);
     ++it;
   }
-  delete list;  
+  delete list;
 }
 
 //----------------------------------------------------------------------
@@ -203,103 +218,100 @@ void MyButtonGroup::resizeEvent( QResizeEvent * )
 //----------------------------------------------------------------------
 
 KJotsMain::KJotsMain(const char* name)
-  : KTopLevelWidget( name )
+  : KTMainWindow( name )
 {
-  //create widgets
+  mOptionDialog = 0;
+  folderOpen    = FALSE;
+  current       = 0;
+
+  //
+  // Main widget
+  //
   f_main = new QFrame( this, "Frame_0" );
-  f_main->move(0, 28);
-  f_main->setMinimumSize( 500, 180 );
-  f_main->setFrameStyle( 0 );
+  f_main->setFrameStyle( QFrame::NoFrame );
+  setView(f_main, FALSE);
 
+  //
+  // Text area
+  //
   f_text = new QFrame( f_main, "Frame_1" );
-  f_text->setGeometry( 8, 72, 452, 45 );
-  f_text->setFrameStyle( 50 );
-  
-  f_labels = new QFrame( f_main, "Frame_2" );
-  f_labels->setMinimumSize( 436, 24 );
-  f_labels->setFrameStyle( 0 );
-  
-  menubar = new KMenuBar( this, "MenuBar_1" );
-  // KMenubar is not a FRAME!!! (sven)
-  //menubar->setFrameStyle( 34 );
-  //menubar->setLineWidth( 2 );
+  f_text->setFrameStyle( QFrame::NoFrame );
 
+  //
+  // Status bar area
+  //
+  f_labels = new QFrame( f_main, "Frame_2" );
+  f_labels->setFrameStyle( QFrame::NoFrame );
+
+  //
+  // Data widgets.
+  //
   s_bar = new QScrollBar( f_main, "ScrollBar_1" );
-  s_bar->setMinimumSize( 452, 16 );
   s_bar->setOrientation( QScrollBar::Horizontal );
-  
+  s_bar->setRange(0,0);
+  s_bar->setValue(0);
+  s_bar->setSteps(1,1);
+  connect( s_bar, SIGNAL(valueChanged(int)), this, SLOT(barMoved(int)) );
+
   me_text = new MyMultiEdit( f_text, "me_text" );
-  me_text->setMinimumSize( 436, 30 );
-  me_text->insertLine( "" );
+  me_text->setMinimumWidth( fontMetrics().maxWidth()*40 );
+  me_text->setFocusPolicy(QWidget::StrongFocus);
+  me_text->setEnabled(FALSE);
 
   l_folder = new QLabel( f_labels, "Label_4" );
-  l_folder->setMinimumSize( 68, 20 );
   l_folder->setFrameStyle( QFrame::WinPanel | QFrame::Sunken );
-  l_folder->setText( "" );
-  
-  le_subject = new QLineEdit( f_labels, "le_subject" );
-  le_subject->setMinimumSize( 56, 20 );
-  le_subject->setText( "" );
-  le_subject->setFocusPolicy(QWidget::ClickFocus);
-  
-  bg_top = new MyButtonGroup( f_main, "ButtonGroup_2" );
-  bg_top->setMinimumSize( 452, 32 );
-  bg_top->setFrameStyle( 49 ); 
-  bg_top->setTitle( "" );
-  bg_top->setAlignment( 1 );
-  bg_top->lower();
-  
-  this->setMinimumSize(500, 211);
-  
-  KConfig *config = KApplication::getKApplication()->getConfig();
-
-  config->setGroup("kjots");
-  entrylist.setAutoDelete(TRUE);
-  button_list.setAutoDelete(TRUE);
-  folderOpen = FALSE;
-  entrylist.append(new TextEntry);
-  confdiag = NULL;
-  subj_list = new SubjList;
-  connect( this, SIGNAL(folderChanged(QList<TextEntry> *)), subj_list,
-	   SLOT(rebuildList( QList<TextEntry> *)) );
-  connect( this, SIGNAL(entryMoved(int)), subj_list, SLOT( select(int)) );
-  connect( subj_list, SIGNAL(entryMoved(int)), this, SLOT( barMoved(int)) );
-  connect( le_subject, SIGNAL(textChanged(const char *)), subj_list, 
-	   SLOT(entryChanged(const char*)) );
-  me_text->setEnabled(FALSE);
-  le_subject->setEnabled(FALSE);
-  current = 0;
-  connect( s_bar, SIGNAL(valueChanged(int)), this, SLOT(barMoved(int)) );
- 
-  top2bottom = new QGridLayout( f_main, 4, 1, 4 );
-  top2bottom->addWidget( f_text, 0, 0, AlignCenter );
-  top2bottom->setRowStretch( 0, 1 );
-  top2bottom->addWidget( s_bar, 1, 0, AlignCenter );
-  top2bottom->addWidget( bg_top, 2, 0, AlignCenter );
-  top2bottom->addWidget( f_labels, 3, 0, AlignCenter );
-  top2bottom->activate();
-
-  labels_layout = new QGridLayout( f_labels, 1, 2, 0 );
-  labels_layout->addWidget( l_folder, 0, 0, AlignVCenter | AlignLeft );
-  labels_layout->addWidget( le_subject, 0, 1, AlignVCenter | AlignLeft );
-  labels_layout->setColStretch( 1, 1 );
-  labels_layout->activate();
-
   QFont font_label(l_folder->fontInfo().family());
   font_label.setBold(TRUE);
   l_folder->setFont(font_label);
 
-  f_text_layout = new QGridLayout( f_text, 2, 1, 4 );
-  f_text_layout->addWidget( me_text, 0, 0, AlignCenter );
-  f_text_layout->setRowStretch( 0, 1 );
-  f_text_layout->activate();
+  le_subject = new QLineEdit( f_labels, "le_subject" );
+  le_subject->setFocusPolicy(QWidget::ClickFocus);
+  le_subject->setEnabled(FALSE);
 
-  s_bar->setRange(0,0);
-  s_bar->setValue(0);
-  s_bar->setSteps(1,1);
+  l_folder->setMinimumWidth( fontMetrics().maxWidth()*8 );
+  l_folder->setFixedHeight( le_subject->sizeHint().height() );
 
+  bg_top = new MyButtonGroup( f_main, "ButtonGroup_2" );
+  bg_top->setMinimumHeight( 32 ); // Bad!
+  bg_top->setFrameStyle( QFrame::Box | QFrame::Sunken );
   bg_top->setExclusive(TRUE);
-  me_text->setFocusPolicy(QWidget::StrongFocus);
+
+  //
+  // Put data widgets into layouts
+  //
+  QVBoxLayout *l1 = new QVBoxLayout(f_text, 0, 0);
+  l1->addWidget(me_text);
+
+  QHBoxLayout *l2 = new QHBoxLayout(f_labels);
+  l2->addWidget(l_folder);
+  l2->addWidget(le_subject, 1 );
+
+  QVBoxLayout *tl = new QVBoxLayout(f_main, 4);
+  tl->addWidget(f_text, 1);
+  tl->addWidget(s_bar);
+  tl->addWidget(bg_top);
+  tl->addWidget(f_labels);
+
+
+
+  entrylist.setAutoDelete(TRUE);
+  entrylist.append(new TextEntry);
+  button_list.setAutoDelete(TRUE);
+
+  subj_list = new SubjList( topLevelWidget(), 0, false );
+  connect( this, SIGNAL(folderChanged(QList<TextEntry> *)),
+	   subj_list, SLOT(rebuildList( QList<TextEntry> *)) );
+  connect( this, SIGNAL(entryMoved(int)),
+	   subj_list, SLOT( select(int)) );
+  connect( subj_list, SIGNAL(entryMoved(int)),
+	   this, SLOT( barMoved(int)) );
+  connect( le_subject, SIGNAL(textChanged(const QString &)),
+	   subj_list, SLOT(entryChanged(const QString &)) );
+
+
+
+  KConfig *config = kapp->config();
+  config->setGroup("kjots");
 
   // read hotlist
   config->readListEntry( "Hotlist", hotlist );
@@ -312,19 +324,20 @@ KJotsMain::KJotsMain(const char* name)
   folders = new QPopupMenu;
   int i = 0;
   QPushButton *temp_button;
-  for( temp = folder_list.first(); !temp.isEmpty(); temp = folder_list.next(), i++ )
-    { 
-      folders->insertItem(temp, i); 
-      if( hotlist.contains(temp) )
-	{
-	  temp_button = new QPushButton(temp, bg_top);
-	  temp_button->setFocusPolicy(QWidget::ClickFocus);
-	  temp_button->setToggleButton(TRUE);
-	  temp_button->setFixedSize(BUTTON_WIDTH,24);
-	  bg_top->insert(temp_button, i);
-	  button_list.append(temp_button);
-	}
+  for( temp=folder_list.first(); !temp.isEmpty(); temp=folder_list.next(), i++)
+  {
+    folders->insertItem(temp, i);
+    if( hotlist.contains(temp) )
+    {
+      temp_button = new QPushButton(temp, bg_top);
+      temp_button->setFocusPolicy(QWidget::ClickFocus);
+      temp_button->setToggleButton(TRUE);
+      temp_button->setFixedSize(BUTTON_WIDTH,24);
+      bg_top->insert(temp_button, i);
+      button_list.append(temp_button);
     }
+  }
+
   unique_id = i+1;
   connect( folders, SIGNAL(activated(int)), this, SLOT(openFolder(int)) );
   connect( bg_top, SIGNAL(clicked(int)), this, SLOT(openFolder(int)) );
@@ -338,23 +351,21 @@ KJotsMain::KJotsMain(const char* name)
   // CTRL+Key_A := add new page
   // CTRL+Key_M := move focus
 
-  keys = new KAccel( this ); 
+  keys = new KAccel( this );
+  keys->insertStdItem( KStdAccel::New, i18n("New Book") );
 
-
-  keys->insertStdItem( KAccel::New, klocale->translate("New Book") ); 
-
-
-  keys->connectItem( KAccel::New, this, SLOT(createFolder()) );
-  keys->connectItem( KAccel::Save , this, SLOT(saveFolder()) );
-  keys->connectItem( KAccel::Quit, qApp, SLOT(quit()) );
-  keys->connectItem( KAccel::Cut , me_text, SLOT(cut()) );
-  keys->connectItem( KAccel::Copy , me_text, SLOT(copyText()) );
-  keys->connectItem( KAccel::Paste , me_text, SLOT(paste()) );
+  keys->connectItem( KStdAccel::New, this, SLOT(createFolder()) );
+  keys->connectItem( KStdAccel::Save , this, SLOT(saveFolder()) );
+  keys->connectItem( KStdAccel::Quit, qApp, SLOT(quit()) );
+  keys->connectItem( KStdAccel::Cut , me_text, SLOT(cut()) );
+  keys->connectItem( KStdAccel::Copy , me_text, SLOT(copyText()) );
+  keys->connectItem( KStdAccel::Paste , me_text, SLOT(paste()) );
 
   keys->insertItem(i18n("PreviousPage"),    "PreviousPage",    CTRL+Key_J);
   keys->insertItem(i18n("NextPage"),        "NextPage",        CTRL+Key_K);
   keys->insertItem(i18n("ShowSubjectList"), "ShowSubjectList", CTRL+Key_L);
   keys->insertItem(i18n("AddNewPage"),      "AddNewPage",      CTRL+Key_A);
+  keys->insertItem(i18n("DelPage"),          "DelPage",        CTRL+Key_D);
   keys->insertItem(i18n("MoveFocus"),       "MoveFocus",       CTRL+Key_M);
   keys->insertItem(i18n("CopySelection"),   "CopySelection",   CTRL+Key_Y);
   keys->connectItem( "PreviousPage", this, SLOT(prevEntry()) );
@@ -365,134 +376,166 @@ KJotsMain::KJotsMain(const char* name)
   keys->connectItem( "CopySelection", this, SLOT(copySelection()) );
   keys->readSettings();
 
+  
   // create menu
   int id;
   QPopupMenu *file = new QPopupMenu;
-  id = file->insertItem(klocale->translate("&New Book"), this, SLOT(createFolder()));
-  keys->changeMenuAccel(file, id, KAccel::New); 
+  id = file->insertItem(i18n("&New Book"), this, SLOT(createFolder()));
+  keys->changeMenuAccel(file, id, KStdAccel::New);
 
   file->insertSeparator();
-  id = file->insertItem(klocale->translate("Save current book"), this, SLOT(saveFolder()) );
-  keys->changeMenuAccel(file, id, KAccel::Save); 
-  id = file->insertItem(klocale->translate("Save book to ascii file"), this, SLOT(writeBook()) );
-  id = file->insertItem(klocale->translate("Save page to ascii file"), this, SLOT(writePage()) );
+  id_f_save_book = file->insertItem(i18n("Save current book"),
+				    this, SLOT(saveFolder()) );
+  keys->changeMenuAccel(file, id_f_save_book, KStdAccel::Save);
+  id_f_save_book_ascii = file->insertItem(i18n("Save book to ascii file"),
+					  this, SLOT(writeBook()) );
+  id_f_save_page_ascii = file->insertItem(i18n("Save page to ascii file"),
+					  this, SLOT(writePage()) );
   file->insertSeparator();
-  id = file->insertItem(klocale->translate("Delete current book"), this, SLOT(deleteFolder()) );
+  id_f_del_book = file->insertItem(i18n("Delete current book"),
+				   this, SLOT(deleteFolder()) );
   file->insertSeparator();
-  id = file->insertItem(klocale->translate("&Quit"), qApp, SLOT( quit() ));
-  keys->changeMenuAccel(file, id, KAccel::Quit); 
+  id = file->insertItem(i18n("&Quit"),
+			qApp, SLOT(quit()));
+  keys->changeMenuAccel(file, id, KStdAccel::Quit);
 
   QPopupMenu *edit_menu = new QPopupMenu;
 
-  id = edit_menu->insertItem(klocale->translate("C&ut"),me_text, SLOT(cut()));
-  keys->changeMenuAccel(edit_menu, id, KAccel::Cut); 
-  id = edit_menu->insertItem(klocale->translate("&Copy") , me_text, SLOT(copyText()) );
-  keys->changeMenuAccel(edit_menu, id, KAccel::Copy); 
-  id = edit_menu->insertItem(klocale->translate("&Paste"), me_text, SLOT(paste()));
-  keys->changeMenuAccel(edit_menu, id, KAccel::Paste); 
+  id_e_cut = edit_menu->insertItem(i18n("C&ut"),
+				   me_text, SLOT(cut()));
+  keys->changeMenuAccel(edit_menu, id_e_cut, KStdAccel::Cut);
+  id_e_copy = edit_menu->insertItem(i18n("&Copy") ,
+				    me_text, SLOT(copyText()) );
+  keys->changeMenuAccel(edit_menu, id_e_copy, KStdAccel::Copy);
+  id_e_paste = edit_menu->insertItem(i18n("&Paste"),
+				     me_text, SLOT(paste()));
+  keys->changeMenuAccel(edit_menu, id_e_paste, KStdAccel::Paste);
   edit_menu->insertSeparator();
-  id = edit_menu->insertItem(klocale->translate("&New Page"), this, SLOT(newEntry()) );
-  keys->changeMenuAccel(edit_menu, id, "AddNewPage"); 
-  id = edit_menu->insertItem(klocale->translate("&Delete Page"), this, SLOT(deleteEntry()) );
+  
+  // added actionized items (pfeiffer)
+  KAction *action = KStdAction::find( this, SLOT( slotSearch() ), me_text );
+  action->plug( edit_menu );
+  action = KStdAction::findNext( this, SLOT( slotRepeatSearch() ), me_text );
+  action->plug( edit_menu );
+  action = KStdAction::replace( this, SLOT( slotReplace() ), me_text );
+  action->plug( edit_menu );
+  edit_menu->insertSeparator();
+  
+  id_e_new = edit_menu->insertItem(i18n("&New Page"),
+				   this, SLOT(newEntry()) );
+  keys->changeMenuAccel(edit_menu, id_e_new, "AddNewPage");
+  id_e_del = edit_menu->insertItem(i18n("&Delete Page"),
+				   this, SLOT(deleteEntry()) );
+  keys->changeMenuAccel(edit_menu, id_e_del, "DelPage");
 
   QPopupMenu *options = new QPopupMenu;
-  options->insertItem(klocale->translate("&Config"), this, SLOT(configure()) );
-  options->insertItem(klocale->translate("Configure &Keys"), this, SLOT(configureKeys()) );
+  options->insertItem(i18n("Configure &Key Bindings"),
+		      this, SLOT(configureKeys()) );
+  options->insertItem(i18n("&Configure %1...").arg(kapp->caption()),
+		      this, SLOT(configure()) );
 
   QPopupMenu *hotlist = new QPopupMenu;
-  hotlist->insertItem(klocale->translate("Add current book to hotlist"), 
-		      this, SLOT(addToHotlist()) );
-  hotlist->insertItem(klocale->translate("Remove current book from hotlist"),
-		      this, SLOT(removeFromHotlist()) );
+  id_fav_add = hotlist->insertItem(i18n("Add current book to hotlist"),
+				   this, SLOT(addToHotlist()) );
+  id_fav_del = hotlist->insertItem(i18n("Remove current book from hotlist"),
+				   this, SLOT(removeFromHotlist()) );
 
-  menubar->insertItem( klocale->translate("&File"), file );
-  menubar->insertItem( klocale->translate("&Edit"), edit_menu );
-  menubar->insertItem( klocale->translate("Hot&list"), hotlist );
-  menubar->insertItem( klocale->translate("&Options"), options );
-  menubar->insertItem( klocale->translate("&Books"), folders );
-  menubar->insertSeparator();
-  QString about = "KJots 0.3.1\n\r(C) ";
-  about += (QString) klocale->translate("by") +
+  menuBar()->insertItem( i18n("&File"), file );
+  menuBar()->insertItem( i18n("&Edit"), edit_menu );
+  menuBar()->insertItem( i18n("&Books"), folders );
+  menuBar()->insertItem( i18n("Hot&list"), hotlist );
+  menuBar()->insertItem( i18n("&Options"), options );
+  menuBar()->insertSeparator();
+  QString about = "KJots " KJOTSVERSION "\n\r(c) ";
+  about += (QString) i18n("by") +
     " Christoph Neerfeld\n\rChristoph.Neerfeld@home.ivm.de";
-  menubar->insertItem( klocale->translate("&Help"),
-		       KApplication::getKApplication()->getHelpMenu(TRUE, about ) );
+  menuBar()->insertItem( i18n("&Help"), helpMenu(about ) );
 
+  //
+  // Make toolbar
+  //
+  QPixmap temp_pix;
+  temp_pix = BarIcon("filenew");
+  toolBar(0)->insertButton(temp_pix, 0, SIGNAL(clicked()), this,
+			   SLOT(newEntry()), TRUE, i18n("New"));
+  temp_pix = BarIcon("filedel");
+  toolBar(0)->insertButton(temp_pix, 1, SIGNAL(clicked()), this,
+			   SLOT(deleteEntry()), TRUE, i18n("Delete"));
+  temp_pix = BarIcon("back");
+  toolBar(0)->insertButton(temp_pix, 2, SIGNAL(clicked()), this,
+			   SLOT(prevEntry()), TRUE, i18n("Previous"));
+  temp_pix = BarIcon("forward");
+  toolBar(0)->insertButton(temp_pix, 3, SIGNAL(clicked()), this,
+			   SLOT(nextEntry()), TRUE, i18n("Next"));
+  toolBar(0)->insertSeparator();
+  temp_pix = BarIcon("openbook");
+  toolBar(0)->insertButton(temp_pix, 4, SIGNAL(clicked()), this,
+			   SLOT(toggleSubjList()), TRUE, i18n("Subject List"));
+  toolBar(0)->insertSeparator();
+  temp_pix = BarIcon("exit");
 
   config->setGroup("kjots");
-  // create toolbar
-  toolbar = new KToolBar(this);
-  QPixmap temp_pix;
-  temp_pix = global_pix_loader->loadIcon("filenew.xpm");
-  toolbar->insertButton(temp_pix, 0, SIGNAL(clicked()), this,
-		      SLOT(newEntry()), TRUE, i18n("New"));
-  temp_pix = global_pix_loader->loadIcon("filedel.xpm");
-  toolbar->insertButton(temp_pix, 1, SIGNAL(clicked()), this,
-		      SLOT(deleteEntry()), TRUE, i18n("Delete"));
-  temp_pix = global_pix_loader->loadIcon("back.xpm");
-  toolbar->insertButton(temp_pix, 2, SIGNAL(clicked()), this,
-		      SLOT(prevEntry()), TRUE, i18n("Previous"));
-  temp_pix = global_pix_loader->loadIcon("forward.xpm");
-  toolbar->insertButton(temp_pix, 3, SIGNAL(clicked()), this,
-		      SLOT(nextEntry()), TRUE, i18n("Next"));
-  toolbar->insertSeparator();
-  temp_pix = global_pix_loader->loadIcon("openbook.xpm");
-  toolbar->insertButton(temp_pix, 4, SIGNAL(clicked()), this,
-		      SLOT(toggleSubjList()), TRUE, i18n("Subject List"));
-  toolbar->insertSeparator();
-  temp_pix = global_pix_loader->loadIcon("exit.xpm");
-  toolbar->setBarPos( (KToolBar::BarPosition) config->readNumEntry("ToolBarPos") );
-  addToolBar(toolbar);
-  setView(f_main, FALSE);
-  setMenu(menubar);
+  toolBar(0)->setBarPos(
+    (KToolBar::BarPosition)config->readNumEntry("ToolBarPos"));
   enableToolBar(KToolBar::Show);
 
-  QString last_folder = config->readEntry("LastOpenFolder");
-  int nr;
-  if( (nr = folder_list.find(last_folder)) >= 0 )
+
+  int nr = folder_list.find( config->readEntry("LastOpenFolder") );
+  if( nr >= 0 )
+  {
     openFolder(nr);
-  int width, height;
-  width = config->readNumEntry("Width");
-  height = config->readNumEntry("Height");
-  if( width < minimumSize().width() )
-    width = minimumSize().width();
-  if( height < minimumSize().height() )
-    height = minimumSize().height();
-  resize(width, height);
+  }
+
+  //
+  // Set minimum size of main widget
+  //
+  f_main->setMinimumSize( f_main->sizeHint() );
+
+  //
+  // Set startup size.
+  //
+  int w = config->readNumEntry("Width");
+  int h = config->readNumEntry("Height");
+  w = QMAX( w, sizeHint().width() );
+  h = QMAX( h, sizeHint().height() );
+  resize(w, h);
+
+  updateMenu();
 }
 
 
+
 KJotsMain::~KJotsMain()
 {
-  saveProperties( (KConfig *) 0 );
+  delete mOptionDialog;
+  saveProperties();
 }
 
-void KJotsMain::saveProperties(KConfig*)
+
+void KJotsMain::saveProperties( void )
 {
-  KConfig *config = KApplication::getKApplication()->getConfig();
-  config->setGroup("kjots");
+  KConfig &config = *kapp->config();
+  config.setGroup("kjots");
   button_list.clear();
   if( folderOpen )
-    {
-      QFileInfo fi(current_folder_name);
-      config->writeEntry("LastOpenFolder", fi.fileName());
-    }
+  {
+    QFileInfo fi(current_folder_name);
+    config.writeEntry("LastOpenFolder", fi.fileName());
+  }
   saveFolder();
-  config->writeEntry("Width", width());
-  config->writeEntry("Height", height());
-  config->writeEntry("ToolBarPos", (int) toolbar->barPos() );
-  config->sync();
+  config.writeEntry("Width", width());
+  config.writeEntry("Height", height());
+  config.writeEntry("ToolBarPos", (int)toolBar(0)->barPos() );
+  config.sync();
 }
 
-void KJotsMain::resizeEvent( QResizeEvent *e )
-{
-  KTopLevelWidget::resizeEvent( e );
-}
 
 int KJotsMain::readFile( QString name )
 {
   int pos;
   QString buf, subj;
   TextEntry *entry;
+
   entrylist.clear();
   QFile folder(name);
   if( !folder.open(IO_ReadWrite) )
@@ -527,11 +570,12 @@ int KJotsMain::readFile( QString name )
   while( entry->text.right(1) == "\n" )
     entry->text.truncate(entry->text.length() - 1);
   entry->text.append("\n");
+
+  updateMenu();
   return 0;
 }
 
-int KJotsMain::writeFile( QString name )
-{
+int KJotsMain::writeFile( QString name ) {
   int pos;
   TextEntry *entry;
   QString buf;
@@ -545,7 +589,7 @@ int KJotsMain::writeFile( QString name )
       st << entry->subject;
       st << "\n";
       buf = entry->text;
-      buf.detach();
+
       pos = 0;
       while( (pos = buf.find( '\\', pos )) != -1 )
 	{
@@ -560,18 +604,16 @@ int KJotsMain::writeFile( QString name )
   return 0;
 }
 
-void KJotsMain::openFolder(int id)
-{
+void KJotsMain::openFolder(int id) {
   QPushButton *but;
+
   for( but = button_list.first(); but != NULL; but = button_list.next() )
     but->setOn(FALSE);
   but = (QPushButton *) bg_top->find(id);
   if( but )
     but->setOn(TRUE);
-  //QDir dir = QDir::home();
-  //dir.cd(".kde/share/apps/kjots");
-  QDir dir = QDir( KApplication::localkdedir().data() );
-  dir.cd("share/apps/kjots");
+
+  QDir dir = QDir( locateLocal("appdata", "") );
   QString file_name = dir.absPath();
   file_name += '/';
   file_name += folder_list.at( folders->indexOf(id) );
@@ -580,12 +622,14 @@ void KJotsMain::openFolder(int id)
   if( folderOpen )
     saveFolder();
   current_folder_name = file_name;
+
   if( readFile(current_folder_name) < 0)
     {
       folderOpen = FALSE;
       debug("Kjots: Unable to open folder");
       return;
     }
+
   current = 0;
   me_text->deselect();
   me_text->setText(entrylist.first()->text);
@@ -599,22 +643,29 @@ void KJotsMain::openFolder(int id)
   me_text->setFocus();
   s_bar->setRange(0,entrylist.count()-1);
   s_bar->setValue(0);
+
+  updateMenu();
 }
 
+
 void KJotsMain::createFolder()
 {
   AskFileName *ask = new AskFileName(this);
   if( ask->exec() == QDialog::Rejected )
+  {
+    delete ask;
     return;
+  }
+
   QString name = ask->getName();
   delete ask;
   if( folder_list.contains(name) )
-    {
-      QMessageBox::message(klocale->translate("Warning"), 
-			   klocale->translate("A book with this name already exists."), 
-			   klocale->translate("OK"), this);
-      return;
-    }
+  {
+    QString msg = i18n("A book with this name already exists.");
+    KMessageBox::sorry( topLevelWidget(), msg );
+    return;
+  }
+
   saveFolder();
   entrylist.clear();
   folderOpen = TRUE;
@@ -634,17 +685,17 @@ void KJotsMain::createFolder()
   le_subject->setText(entrylist.first()->subject);
 
   folder_list.append(name);
-  if( folders->text(folders->idAt(0)) == 0 )
-    folders->removeItemAt(0);
+
+  // TODO: this does not work with qt 2.0. Why?
+//     if( folders->text(folders->idAt(0)) == 0 )
+//      folders->removeItemAt(0);
+
   folders->insertItem(name, unique_id++);
-  //QDir dir = QDir::home();
-  //dir.cd(".kde/share/apps/kjots");
-  QDir dir = QDir( KApplication::localkdedir().data() );
-  dir.cd("share/apps/kjots");
+  QDir dir = QDir( locateLocal("appdata", "") );
   current_folder_name = dir.absPath();
   current_folder_name += '/';
   current_folder_name += name;
-  KConfig *config = KApplication::getKApplication()->getConfig();
+  KConfig *config = KApplication::kApplication()->config();
   config->setGroup("kjots");
   config->writeEntry( "Folders", folder_list );
   config->sync();
@@ -652,16 +703,22 @@ void KJotsMain::createFolder()
   QPushButton *but;
   for( but = button_list.first(); but != 0; but = button_list.next() )
     but->setOn(FALSE);
+
+  updateMenu();
 }
 
 void KJotsMain::deleteFolder()
 {
   if( !folderOpen )
     return;
-  if( !QMessageBox::query(klocale->translate("Delete current book"),
-			  klocale->translate("Are you sure you want to delete the current book ?"),
-			  klocale->translate("Yes"), klocale->translate("No"), this) )
+
+  QString msg = i18n("Are you sure you want to delete the current book ?");
+  int result = KMessageBox::warningYesNo( topLevelWidget(), msg );
+  if( result != KMessageBox::Yes )
+  {
     return;
+  }
+
   QFileInfo fi(current_folder_name);
   QDir dir = fi.dir(TRUE);
   QString name = fi.fileName();
@@ -680,7 +737,7 @@ void KJotsMain::deleteFolder()
       button_list.remove( (QPushButton *) but );
       resize(size());
     }
-  KConfig *config = KApplication::getKApplication()->getConfig();
+  KConfig *config = KApplication::kApplication()->config();
   config->setGroup("kjots");
   config->writeEntry( "Folders", folder_list );
   config->writeEntry( "Hotlist", hotlist );
@@ -692,20 +749,22 @@ void KJotsMain::deleteFolder()
   me_text->clear();
   me_text->deselect();
   le_subject->setEnabled(FALSE);
-  le_subject->setText("");
+  le_subject->clear();
   emit folderChanged(&entrylist);
   s_bar->setRange(0,0);
   s_bar->setValue(0);
-  l_folder->setText("");
+  l_folder->clear();
   subj_list->repaint(TRUE);
+
+  updateMenu();
 }
 
 void KJotsMain::saveFolder()
 {
   if( !folderOpen )
     return;
-  entrylist.at(current)->text = me_text->text();  
-  entrylist.at(current)->subject = le_subject->text();  
+  entrylist.at(current)->text = me_text->text();
+  entrylist.at(current)->subject = le_subject->text();
   writeFile(current_folder_name);
 }
 
@@ -723,6 +782,8 @@ void KJotsMain::nextEntry()
   emit entryMoved(current);
   le_subject->setText( entrylist.at(current)->subject );
   s_bar->setValue(current);
+
+  updateMenu();
 }
 
 void KJotsMain::prevEntry()
@@ -739,16 +800,18 @@ void KJotsMain::prevEntry()
   emit entryMoved(current);
   le_subject->setText( entrylist.at(current)->subject );
   s_bar->setValue(current);
+
+  updateMenu();
 }
 
 void KJotsMain::newEntry()
 {
   if( !folderOpen )
     return;
-  entrylist.at(current)->text = me_text->text();  
+  entrylist.at(current)->text = me_text->text();
   entrylist.at(current)->subject = le_subject->text();
   me_text->clear();
-  le_subject->setText("");
+  le_subject->clear();
   TextEntry *new_entry = new TextEntry;
   entrylist.append(new_entry);
   new_entry->subject = "";
@@ -757,6 +820,8 @@ void KJotsMain::newEntry()
   s_bar->setValue(current);
   emit folderChanged(&entrylist);
   emit entryMoved(current);
+
+  updateMenu();
 }
 
 void KJotsMain::deleteEntry()
@@ -771,7 +836,7 @@ void KJotsMain::deleteEntry()
       entrylist.at(0)->subject = "";
       s_bar->setValue(0);
       me_text->clear();
-      le_subject->setText("");
+      le_subject->clear();
       return;
     }
   entrylist.remove(current);
@@ -787,6 +852,8 @@ void KJotsMain::deleteEntry()
   le_subject->setText( entrylist.at(current)->subject );
   s_bar->setRange(0, entrylist.count()-1 );
   emit folderChanged(&entrylist);
+
+  updateMenu();
 }
 
 void KJotsMain::barMoved( int new_value )
@@ -804,6 +871,8 @@ void KJotsMain::barMoved( int new_value )
   emit entryMoved(current);
   le_subject->setText( entrylist.at(current)->subject );
   s_bar->setValue(new_value);
+
+  updateMenu();
 }
 
 void KJotsMain::addToHotlist()
@@ -822,13 +891,13 @@ void KJotsMain::addToHotlist()
   QPushButton *but = new QPushButton(name, bg_top);
   button_list.append(but);
   bg_top->insert(but, id);
-  KConfig *config = KApplication::getKApplication()->getConfig();
+  KConfig *config = KApplication::kApplication()->config();
   config->setGroup("kjots");
   config->writeEntry( "Hotlist", hotlist );
   config->sync();
   but->setFocusPolicy(QWidget::ClickFocus);
   but->setToggleButton(TRUE);
-  but->setFixedSize(BUTTON_WIDTH,24);
+  but->setFixedSize(BUTTON_WIDTH, 24);
   but->show();
   but->setOn(TRUE);
   bg_top->forceResize();
@@ -848,7 +917,7 @@ void KJotsMain::removeFromHotlist()
   QButton *but = bg_top->find(id);
   bg_top->remove(but);
   button_list.remove( (QPushButton *) but );
-  KConfig *config = KApplication::getKApplication()->getConfig();
+  KConfig *config = KApplication::kApplication()->config();
   config->setGroup("kjots");
   config->writeEntry( "Hotlist", hotlist );
   config->sync();
@@ -858,43 +927,71 @@ void KJotsMain::removeFromHotlist()
 void KJotsMain::toggleSubjList()
 {
   if( subj_list->isVisible() )
-    {
-      subj_list->hide();
-    }
+  {
+    subj_list->hide();
+  }
   else
-    {
-      subj_list->resize(width() / 2, height() );
-      subj_list->show();
-    }
+  {
+    subj_list->setInitialSize( QSize(width()/2,height()) );
+   //subj_list->resize( QSize(width() / 2, height()) );
+    subj_list->show();
+  }
 }
 
 void KJotsMain::configure()
 {
-  if( confdiag )
-    return;
-  confdiag = new ConfDialog;
-  connect( confdiag, SIGNAL(confHide()), this, SLOT(configureHide()) );
-  connect( confdiag, SIGNAL(commitChanges()), this, SLOT(updateConfiguration()) );
-  confdiag->show();
+  if( mOptionDialog == 0 )
+  {
+    mOptionDialog = new ConfigureDialog( topLevelWidget(), 0, false );
+    if( mOptionDialog == 0 ) { return; }
+    connect( mOptionDialog, SIGNAL(hidden()),this,SLOT(configureHide()));
+    connect( mOptionDialog, SIGNAL(valueChanged()),
+	     this, SLOT(updateConfiguration()) );
+  }
+
+  mOptionDialog->show();
 }
 
 void KJotsMain::configureHide()
 {
-  if( !confdiag )
-    return;
-  delete confdiag;
-  confdiag = NULL;
+  QTimer::singleShot( 0, this, SLOT(configureDestroy()) );
+}
+
+void KJotsMain::configureDestroy()
+{
+  if( mOptionDialog != 0 && mOptionDialog->isVisible() == false )
+  {
+    delete mOptionDialog; mOptionDialog = 0;
+  }
+}
+
+void KJotsMain::slotSearch()
+{
+    me_text->search();
+}
+
+void KJotsMain::slotRepeatSearch()
+{
+    me_text->repeatSearch();
+}
+
+void KJotsMain::slotReplace()
+{
+    me_text->replace();
 }
 
 void KJotsMain::updateConfiguration()
 {
-  KConfig *config = KApplication::getKApplication()->getConfig();
-  config->setGroup("kjots");
-  exec_http = config->readEntry("execHttp");
-  exec_ftp = config->readEntry("execFtp");
-  QFont font( config->readEntry("EFontFamily"), config->readNumEntry("EFontSize"),
-	      config->readNumEntry("EFontWeight"), config->readNumEntry("EFontItalic"),
-	      (QFont::CharSet) config->readNumEntry("EFontCharset") );
+  KConfig &config = *kapp->config();
+
+  config.setGroup("kjots");
+  exec_http = config.readEntry("execHttp");
+  exec_ftp  = config.readEntry("execFtp");
+  QFont font( config.readEntry("EFontFamily"),
+	      config.readNumEntry("EFontSize"),
+	      config.readNumEntry("EFontWeight"),
+	      config.readNumEntry("EFontItalic"),
+	      (QFont::CharSet) config.readNumEntry("EFontCharset") );
   me_text->setFont(font);
 }
 
@@ -903,18 +1000,33 @@ void KJotsMain::writeBook()
   saveFolder();
   QString name;
   while( name.isNull() )
+  {
+    KURL url = KFileDialog::getSaveURL();
+
+    if ( url.isEmpty() )
+      return;
+
+    if ( !url.isLocalFile() )
     {
-      name =  KFileDialog::getSaveFileName();
-      if ( name.isNull() )
-	return;
-      QFileInfo f_info(name);
-      if( f_info.exists() )
-	{
-	  if( KMsgBox::yesNo(this, klocale->translate("File exists !"),
-			     klocale->translate("File already exists. \n Do you want to overwrite it ?")) == 2 )
-	    name = "";
-	}
+      KMessageBox::sorry( 0L, i18n( "Only local files supported yet." ) );
+      return;
     }
+
+    name = url.path();
+
+    QFileInfo f_info(name);
+    if( f_info.exists() )
+    {
+      QString msg = i18n(""
+        "File already exists.\n"
+	"Do you want to overwrite it ? ");
+      int result = KMessageBox::warningYesNo( topLevelWidget(), msg );
+      if( result != KMessageBox::Yes )
+      {
+	name = "";
+      }
+    }
+  }
   QFile ascii_file(name);
   if( !ascii_file.open(IO_WriteOnly | IO_Truncate) )
     return;
@@ -932,18 +1044,33 @@ void KJotsMain::writePage()
   saveFolder();
   QString name;
   while( name.isNull() )
+  {
+    KURL url = KFileDialog::getSaveURL();
+
+    if( url.isEmpty() )
+      return;
+
+    if( !url.isLocalFile() )
     {
-      name =  KFileDialog::getSaveFileName();
-      if ( name.isNull() )
-	return;
-      QFileInfo f_info(name);
-      if( f_info.exists() )
-	{
-	  if( KMsgBox::yesNo(this, klocale->translate("File exists !"),
-			     klocale->translate("File already exists. \n Do you want to overwrite it ?")) == 2 )
-	    name = "";
-	}
+      KMessageBox::sorry( 0L, i18n( "Only local files supported yet." ) );
+      return;
     }
+
+    name = url.path();
+
+    QFileInfo f_info(name);
+    if( f_info.exists() )
+    {
+      QString msg = i18n(""
+        "File already exists.\n"
+	"Do you want to overwrite it ? ");
+      int result = KMessageBox::warningYesNo( topLevelWidget(), msg );
+      if( result != KMessageBox::Yes )
+      {
+	name = "";
+      }
+    }
+  }
   QFile ascii_file(name);
   if( !ascii_file.open(IO_WriteOnly | IO_Truncate) )
     return;
@@ -967,7 +1094,7 @@ void KJotsMain::writeEntry( QTextStream &st, TextEntry *entry )
   st << '\n';
 }
 
-void KJotsMain::moveFocus( )
+void KJotsMain::moveFocus()
 {
   if( me_text->hasFocus() )
     le_subject->setFocus();
@@ -975,17 +1102,34 @@ void KJotsMain::moveFocus( )
     me_text->setFocus();
 }
 
-void KJotsMain::configureKeys( )
+void KJotsMain::configureKeys()
 {
-  //keys->configureKeys(this);
-  if( KKeyDialog::configureKeys( keys ) ) 
-    {
-      keys->writeSettings();
-    }
+  if( KKeyDialog::configureKeys( keys, true, topLevelWidget() ) )
+    keys->writeSettings();
 }
 
-void KJotsMain::copySelection( )
+void KJotsMain::copySelection()
 {
   me_text->copyText();
   le_subject->setText(QApplication::clipboard()->text());
 }
+
+
+void KJotsMain::updateMenu()
+{
+  bool activeBook = folderOpen;
+
+  menuBar()->setItemEnabled(id_f_save_book, activeBook);
+  menuBar()->setItemEnabled(id_f_save_book_ascii, activeBook);
+  menuBar()->setItemEnabled(id_f_save_page_ascii, activeBook);
+  menuBar()->setItemEnabled(id_f_del_book, activeBook);
+
+  menuBar()->setItemEnabled(id_e_cut, activeBook);
+  menuBar()->setItemEnabled(id_e_copy, activeBook);
+  menuBar()->setItemEnabled(id_e_paste, activeBook);
+  menuBar()->setItemEnabled(id_e_new, activeBook);
+  menuBar()->setItemEnabled(id_e_del, activeBook);
+
+  menuBar()->setItemEnabled(id_fav_add, activeBook);
+  menuBar()->setItemEnabled(id_fav_del, activeBook);
+}
