@@ -1,15 +1,15 @@
 #ifndef MYKAPP_H
 #define MYKAPP_H
 
-#include <kapp.h>
+#include <kuniqueapp.h>
 #include <kglobalaccel.h>
 
-class MyKApplication : public KApplication
+class MyKApplication : public KUniqueApplication
 {
 public:
 
-  MyKApplication( int &argc, char **argv, char *name ) :
-    KApplication( argc, argv, name ) { accel = 0L; }
+  MyKApplication() :
+    KUniqueApplication() { accel = 0L; }
   ~MyKApplication() {}
 
   void setGlobalKeys( KGlobalAccel *a ) { accel = a; }
@@ -18,7 +18,7 @@ private:
 
   KGlobalAccel *accel;
 
-  inline bool MyKApplication::x11EventFilter( XEvent *e )
+  inline bool x11EventFilter( XEvent *e )
   {
     if ( accel )
       {
