@@ -31,6 +31,7 @@
 #include <klocale.h>
 #include <kconfig.h>
 #include <kmessagebox.h>
+#include <kdebug.h>
 
 #include "queueview.h"
 #include "klpqspooler.h"
@@ -96,7 +97,7 @@ void Spooler::parseUpdate( QListView *lb_list,
 	    }
 	  else
 	    {
-	      qDebug("appending the following: %s",temp.latin1());
+	      kdDebug() << "appending the following: " << temp << endl;
 	      QStringList sl = QStringList::split(QRegExp("\\s"), temp);
 	      MyLVI *lvi = new MyLVI(lb_list, sl[0], sl[1], 
 				     sl[2].toInt(), sl[3], sl[4]);
