@@ -1,7 +1,7 @@
 /*
  *             KNotes
  *
- * $Id: docking.cpp,v 1.18 2000/05/02 01:04:07 waba Exp $
+ * $Id: docking.cpp,v 1.19 2000/05/24 09:04:50 kulow Exp $
  *
  *              Copyright (C) 1997 Bernd Johannes Wuebben
  *                      wuebben@math.cornell.edu
@@ -149,7 +149,7 @@ void DockWidget::configureKNotes(){
 
 void DockWidget::help( void )
 {
-  kapp->invokeHTMLHelp("","");
+  kapp->invokeHelp( );
 }
 
 
