@@ -1,6 +1,6 @@
 /*
 
- $Id: renamedlg.h,v 1.2 1997/12/12 16:43:46 denis Exp $
+ $Id: renamedlg.h,v 1.6 1999/12/30 14:05:10 espen Exp $
 
  KNotes -- Notes for the KDE project
 
@@ -24,40 +24,37 @@
 
  */
 
+//
+// 1999-12-28 Espen Sand
+// Changed to KDialogBase and Qlayouts
+//
+
+
 #ifndef __KPOSTIT_RENAME__
 #define __KPOSTIT_RENAME__
 
-#include <qlined.h>
-#include <qmsgbox.h>
-#include <qdatetm.h> 
-#include <qkeycode.h>
-#include <qgrpbox.h>
-#include <qpushbt.h> 
-#include <qstrlist.h>
+#include <kdialogbase.h>
+class QStringList;
 
-class RenameDlg : public QDialog
+
+class RenameDialog : public KDialogBase
 {
-	Q_OBJECT
+  Q_OBJECT
 
-public:
+  public:
+  
+    RenameDialog( QWidget *parent=0, const char *name=0, bool modal=true,
+	          QString *string=0, QStringList *list=0 );
+    ~RenameDialog( void );
+   
+  protected slots:
+    virtual void slotOk( void );
 
-	RenameDlg( QWidget *parent = 0, const char *name = 0 ,
-		   QString *string = NULL, QStrList *list= NULL);
-
-
-	QLineEdit *lineNum;
-
-private:
-	QString  *pstring;
-	QStrList *pstrlist;
-	QPushButton *ok, *cancel;
-	QGroupBox *frame;
-	void resizeEvent(QResizeEvent *);
-	void focusInEvent(QFocusEvent *);
-
-public slots:
-
-	void selected();
+  private:
+    QLineEdit   *lineNum;
+    QString     *pstring;
+    QStringList *pstrlist;
 };
 
 #endif
+
