@@ -33,7 +33,7 @@ int main(int argc, char **argv)
     KTimeMon *ktimemon = new KTimeMon();
     app->setMainWidget(ktimemon);
 
-    ktimemon->init(argc, argv);
+    ktimemon->dock("ktimemon");
 
     QObject::connect(app, SIGNAL(saveYourself()), ktimemon, SLOT(save()));
 
