@@ -342,7 +342,7 @@ void KSample::readSample()
 
     struct tbl_sysinfo sysinfo;
     if (table(TBL_SYSINFO, 0, &sysinfo, 1, sizeof(sysinfo)) != 1)
-        fatal(fmt.arg("TBL_SYSINFO"));
+        fatal(msg.arg("TBL_SYSINFO"));
 
     sample.user = sysinfo.si_user;
     sample.nice = sysinfo.si_nice;
@@ -351,7 +351,7 @@ void KSample::readSample()
 
     struct tbl_vmstats vmstats;
     if (table(TBL_VMSTATS, 0, &vmstats, 1, sizeof(vmstats)) != 1)
-        fatal(fmt.arg("TBL_VMSTATS"));
+        fatal(msg.arg("TBL_VMSTATS"));
 
     sample.mtotal = vmstats.free_count + vmstats.active_count +
         vmstats.inactive_count + vmstats.wire_count;
@@ -361,21 +361,21 @@ void KSample::readSample()
 
     struct tbl_swapinfo swapinfo;
     if (table(TBL_SWAPINFO, -1, &swapinfo, 1, sizeof(swapinfo)) != 1)
-        fatal(fmt.arg("TBL_SWAPINFO"));
+        fatal(msg.arg("TBL_SWAPINFO"));
 
     sample.stotal = swapinfo.size;
     sample.sfree = swapinfo.free;
 
     struct tbl_paging paging;
     if (table(TBL_PAGING, 0, &paging, 1, sizeof(paging)) != 1)
-        fatal(fmt.arg("TBL_PAGING"));
+        fatal(msg.arg("TBL_PAGING"));
 
     sample.pin = sample.swin = paging.v_pgpgin; // MM no separate swap
     sample.pout = sample.swout = paging.v_pgout;
 
     struct tbl_intr intr;
     if (table(TBL_INTR, 0, &intr, 1, sizeof(intr)) != 1)
-        fatal(fmt.arg("TBL_INTR"));
+        fatal(msg.arg("TBL_INTR"));
 
     sample.cswitches = intr.in_context;
 
