@@ -20,7 +20,7 @@
 	KTop is currently maintained by Chris Schlaeger <cs@kde.org>. Please do
 	not commit any changes without consulting me first. Thanks!
 
-	$Id: Workspace.h,v 1.2 1999/12/26 19:10:25 cschlaeg Exp $
+	$Id: Workspace.h,v 1.3 2000/06/01 19:40:41 cschlaeg Exp $
 */
 
 #ifndef _Workspace_h_
@@ -44,6 +44,9 @@ public:
 public slots:
 	void newWorkSheet();
 	void deleteWorkSheet();
+
+private:
+	int tabCount;
 } ;
 
 #endif
